
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/lite/tools/evaluation/proto/preprocessing_steps.proto', package='tflite.evaluation', syntax='proto2', serialized_options=b'\n\x11tflite.evaluationP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n@tensorflow/lite/tools/evaluation/proto/preprocessing_steps.proto\x12\x11tflite.evaluation"\xa8\x02\n\x1cImagePreprocessingStepParams\x12<\n\x0fcropping_params\x18\x01 \x01(\x0b2!.tflite.evaluation.CroppingParamsH\x00\x12<\n\x0fresizing_params\x18\x02 \x01(\x0b2!.tflite.evaluation.ResizingParamsH\x00\x12:\n\x0epadding_params\x18\x03 \x01(\x0b2 .tflite.evaluation.PaddingParamsH\x00\x12F\n\x14normalization_params\x18\x04 \x01(\x0b2&.tflite.evaluation.NormalizationParamsH\x00B\x08\n\x06params"*\n\tImageSize\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r"\x8c\x01\n\x0eCroppingParams\x12"\n\x11cropping_fraction\x18\x01 \x01(\x02:\x050.875H\x00\x123\n\x0btarget_size\x18\x02 \x01(\x0b2\x1c.tflite.evaluation.ImageSizeH\x00\x12\x17\n\x0fsquare_cropping\x18\x03 \x01(\x08B\x08\n\x06params"^\n\x0eResizingParams\x121\n\x0btarget_size\x18\x01 \x02(\x0b2\x1c.tflite.evaluation.ImageSize\x12\x19\n\x11aspect_preserving\x18\x02 \x02(\x08"\x7f\n\rPaddingParams\x123\n\x0btarget_size\x18\x01 \x01(\x0b2\x1c.tflite.evaluation.ImageSizeH\x00\x12\x18\n\x0esquare_padding\x18\x02 \x01(\x08H\x00\x12\x15\n\rpadding_value\x18\x03 \x02(\x05B\x08\n\x06params"\xe1\x01\n\x13NormalizationParams\x12\x1a\n\x10channelwise_mean\x18\x01 \x01(\x02H\x00\x12L\n\x05means\x18\x02 \x01(\x0b2;.tflite.evaluation.NormalizationParams.PerChannelMeanValuesH\x00\x12\x10\n\x05scale\x18\x03 \x02(\x02:\x011\x1aF\n\x14PerChannelMeanValues\x12\x0e\n\x06r_mean\x18\x01 \x02(\x02\x12\x0e\n\x06g_mean\x18\x02 \x02(\x02\x12\x0e\n\x06b_mean\x18\x03 \x02(\x02B\x06\n\x04meanB\x18\n\x11tflite.evaluationP\x01\xf8\x01\x01')
_IMAGEPREPROCESSINGSTEPPARAMS = _descriptor.Descriptor(name='ImagePreprocessingStepParams', full_name='tflite.evaluation.ImagePreprocessingStepParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cropping_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.cropping_params', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resizing_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.resizing_params', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.padding_params', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='normalization_params', full_name='tflite.evaluation.ImagePreprocessingStepParams.normalization_params', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params', full_name='tflite.evaluation.ImagePreprocessingStepParams.params', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=88, serialized_end=384)
_IMAGESIZE = _descriptor.Descriptor(name='ImageSize', full_name='tflite.evaluation.ImageSize', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='width', full_name='tflite.evaluation.ImageSize.width', index=0, number=1, type=13, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='height', full_name='tflite.evaluation.ImageSize.height', index=1, number=2, type=13, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=386, serialized_end=428)
_CROPPINGPARAMS = _descriptor.Descriptor(name='CroppingParams', full_name='tflite.evaluation.CroppingParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cropping_fraction', full_name='tflite.evaluation.CroppingParams.cropping_fraction', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=True, default_value=float(0.875), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target_size', full_name='tflite.evaluation.CroppingParams.target_size', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='square_cropping', full_name='tflite.evaluation.CroppingParams.square_cropping', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params', full_name='tflite.evaluation.CroppingParams.params', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=431, serialized_end=571)
_RESIZINGPARAMS = _descriptor.Descriptor(name='ResizingParams', full_name='tflite.evaluation.ResizingParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target_size', full_name='tflite.evaluation.ResizingParams.target_size', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='aspect_preserving', full_name='tflite.evaluation.ResizingParams.aspect_preserving', index=1, number=2, type=8, cpp_type=7, label=2, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=573, serialized_end=667)
_PADDINGPARAMS = _descriptor.Descriptor(name='PaddingParams', full_name='tflite.evaluation.PaddingParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target_size', full_name='tflite.evaluation.PaddingParams.target_size', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='square_padding', full_name='tflite.evaluation.PaddingParams.square_padding', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_value', full_name='tflite.evaluation.PaddingParams.padding_value', index=2, number=3, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='params', full_name='tflite.evaluation.PaddingParams.params', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=669, serialized_end=796)
_NORMALIZATIONPARAMS_PERCHANNELMEANVALUES = _descriptor.Descriptor(name='PerChannelMeanValues', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='r_mean', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues.r_mean', index=0, number=1, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='g_mean', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues.g_mean', index=1, number=2, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='b_mean', full_name='tflite.evaluation.NormalizationParams.PerChannelMeanValues.b_mean', index=2, number=3, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=946, serialized_end=1016)
_NORMALIZATIONPARAMS = _descriptor.Descriptor(name='NormalizationParams', full_name='tflite.evaluation.NormalizationParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='channelwise_mean', full_name='tflite.evaluation.NormalizationParams.channelwise_mean', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='means', full_name='tflite.evaluation.NormalizationParams.means', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='scale', full_name='tflite.evaluation.NormalizationParams.scale', index=2, number=3, type=2, cpp_type=6, label=2, has_default_value=True, default_value=float(1), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NORMALIZATIONPARAMS_PERCHANNELMEANVALUES], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='mean', full_name='tflite.evaluation.NormalizationParams.mean', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=799, serialized_end=1024)
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['cropping_params'].message_type = _CROPPINGPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['resizing_params'].message_type = _RESIZINGPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['padding_params'].message_type = _PADDINGPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['normalization_params'].message_type = _NORMALIZATIONPARAMS
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['cropping_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['cropping_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['resizing_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['resizing_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['padding_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['padding_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params'].fields.append(_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['normalization_params'])
_IMAGEPREPROCESSINGSTEPPARAMS.fields_by_name['normalization_params'].containing_oneof = _IMAGEPREPROCESSINGSTEPPARAMS.oneofs_by_name['params']
_CROPPINGPARAMS.fields_by_name['target_size'].message_type = _IMAGESIZE
_CROPPINGPARAMS.oneofs_by_name['params'].fields.append(_CROPPINGPARAMS.fields_by_name['cropping_fraction'])
_CROPPINGPARAMS.fields_by_name['cropping_fraction'].containing_oneof = _CROPPINGPARAMS.oneofs_by_name['params']
_CROPPINGPARAMS.oneofs_by_name['params'].fields.append(_CROPPINGPARAMS.fields_by_name['target_size'])
_CROPPINGPARAMS.fields_by_name['target_size'].containing_oneof = _CROPPINGPARAMS.oneofs_by_name['params']
_RESIZINGPARAMS.fields_by_name['target_size'].message_type = _IMAGESIZE
_PADDINGPARAMS.fields_by_name['target_size'].message_type = _IMAGESIZE
_PADDINGPARAMS.oneofs_by_name['params'].fields.append(_PADDINGPARAMS.fields_by_name['target_size'])
_PADDINGPARAMS.fields_by_name['target_size'].containing_oneof = _PADDINGPARAMS.oneofs_by_name['params']
_PADDINGPARAMS.oneofs_by_name['params'].fields.append(_PADDINGPARAMS.fields_by_name['square_padding'])
_PADDINGPARAMS.fields_by_name['square_padding'].containing_oneof = _PADDINGPARAMS.oneofs_by_name['params']
_NORMALIZATIONPARAMS_PERCHANNELMEANVALUES.containing_type = _NORMALIZATIONPARAMS
_NORMALIZATIONPARAMS.fields_by_name['means'].message_type = _NORMALIZATIONPARAMS_PERCHANNELMEANVALUES
_NORMALIZATIONPARAMS.oneofs_by_name['mean'].fields.append(_NORMALIZATIONPARAMS.fields_by_name['channelwise_mean'])
_NORMALIZATIONPARAMS.fields_by_name['channelwise_mean'].containing_oneof = _NORMALIZATIONPARAMS.oneofs_by_name['mean']
_NORMALIZATIONPARAMS.oneofs_by_name['mean'].fields.append(_NORMALIZATIONPARAMS.fields_by_name['means'])
_NORMALIZATIONPARAMS.fields_by_name['means'].containing_oneof = _NORMALIZATIONPARAMS.oneofs_by_name['mean']
DESCRIPTOR.message_types_by_name['ImagePreprocessingStepParams'] = _IMAGEPREPROCESSINGSTEPPARAMS
DESCRIPTOR.message_types_by_name['ImageSize'] = _IMAGESIZE
DESCRIPTOR.message_types_by_name['CroppingParams'] = _CROPPINGPARAMS
DESCRIPTOR.message_types_by_name['ResizingParams'] = _RESIZINGPARAMS
DESCRIPTOR.message_types_by_name['PaddingParams'] = _PADDINGPARAMS
DESCRIPTOR.message_types_by_name['NormalizationParams'] = _NORMALIZATIONPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ImagePreprocessingStepParams = _reflection.GeneratedProtocolMessageType('ImagePreprocessingStepParams', (_message.Message,), {'DESCRIPTOR': _IMAGEPREPROCESSINGSTEPPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(ImagePreprocessingStepParams)
ImageSize = _reflection.GeneratedProtocolMessageType('ImageSize', (_message.Message,), {'DESCRIPTOR': _IMAGESIZE, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(ImageSize)
CroppingParams = _reflection.GeneratedProtocolMessageType('CroppingParams', (_message.Message,), {'DESCRIPTOR': _CROPPINGPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(CroppingParams)
ResizingParams = _reflection.GeneratedProtocolMessageType('ResizingParams', (_message.Message,), {'DESCRIPTOR': _RESIZINGPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(ResizingParams)
PaddingParams = _reflection.GeneratedProtocolMessageType('PaddingParams', (_message.Message,), {'DESCRIPTOR': _PADDINGPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(PaddingParams)
NormalizationParams = _reflection.GeneratedProtocolMessageType('NormalizationParams', (_message.Message,), {'PerChannelMeanValues': _reflection.GeneratedProtocolMessageType('PerChannelMeanValues', (_message.Message,), {'DESCRIPTOR': _NORMALIZATIONPARAMS_PERCHANNELMEANVALUES, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'}), 'DESCRIPTOR': _NORMALIZATIONPARAMS, '__module__': 'tensorflow.lite.tools.evaluation.proto.preprocessing_steps_pb2'})
_sym_db.RegisterMessage(NormalizationParams)
_sym_db.RegisterMessage(NormalizationParams.PerChannelMeanValues)
DESCRIPTOR._options = None
