
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import device_attributes_pb2 as tensorflow_dot_core_dot_framework_dot_device__attributes__pb2
from ....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.protobuf import config_pb2 as tensorflow_dot_core_dot_protobuf_dot_config__pb2
from ....tensorflow.core.protobuf import error_codes_pb2 as tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2
from ....tensorflow.core.protobuf import named_tensor_pb2 as tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/master.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\x18DistributedRuntimeProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/core/protobuf/master.proto\x12\ntensorflow\x1a1tensorflow/core/framework/device_attributes.proto\x1a%tensorflow/core/framework/graph.proto\x1a&tensorflow/core/framework/tensor.proto\x1a%tensorflow/core/protobuf/config.proto\x1a*tensorflow/core/protobuf/error_codes.proto\x1a+tensorflow/core/protobuf/named_tensor.proto"x\n\x14CreateSessionRequest\x12\'\n\tgraph_def\x18\x01 \x01(\x0b2\x14.tensorflow.GraphDef\x12\'\n\x06config\x18\x02 \x01(\x0b2\x17.tensorflow.ConfigProto\x12\x0e\n\x06target\x18\x03 \x01(\t"F\n\x15CreateSessionResponse\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x15\n\rgraph_version\x18\x02 \x01(\x03"v\n\x14ExtendSessionRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\'\n\tgraph_def\x18\x02 \x01(\x0b2\x14.tensorflow.GraphDef\x12\x1d\n\x15current_graph_version\x18\x03 \x01(\x03"2\n\x15ExtendSessionResponse\x12\x19\n\x11new_graph_version\x18\x04 \x01(\x03"\xf3\x01\n\x0eRunStepRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12*\n\x04feed\x18\x02 \x03(\x0b2\x1c.tensorflow.NamedTensorProto\x12\r\n\x05fetch\x18\x03 \x03(\t\x12\x0e\n\x06target\x18\x04 \x03(\t\x12\'\n\x07options\x18\x05 \x01(\x0b2\x16.tensorflow.RunOptions\x12\x1a\n\x12partial_run_handle\x18\x06 \x01(\t\x12%\n\x1dstore_errors_in_response_body\x18\x07 \x01(\x08\x12\x12\n\nrequest_id\x18\x08 \x01(\x03"\xb5\x01\n\x0fRunStepResponse\x12,\n\x06tensor\x18\x01 \x03(\x0b2\x1c.tensorflow.NamedTensorProto\x12)\n\x08metadata\x18\x02 \x01(\x0b2\x17.tensorflow.RunMetadata\x12+\n\x0bstatus_code\x18\x03 \x01(\x0e2\x16.tensorflow.error.Code\x12\x1c\n\x14status_error_message\x18\x04 \x01(\t"q\n\x16PartialRunSetupRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x0c\n\x04feed\x18\x02 \x03(\t\x12\r\n\x05fetch\x18\x03 \x03(\t\x12\x0e\n\x06target\x18\x04 \x03(\t\x12\x12\n\nrequest_id\x18\x05 \x01(\x03"5\n\x17PartialRunSetupResponse\x12\x1a\n\x12partial_run_handle\x18\x01 \x01(\t"-\n\x13CloseSessionRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t"\x16\n\x14CloseSessionResponse"9\n\x0cResetRequest\x12\x11\n\tcontainer\x18\x01 \x03(\t\x12\x16\n\x0edevice_filters\x18\x02 \x03(\t"\x0f\n\rResetResponse",\n\x12ListDevicesRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t"~\n\x13ListDevicesResponse\x122\n\x0clocal_device\x18\x01 \x03(\x0b2\x1c.tensorflow.DeviceAttributes\x123\n\rremote_device\x18\x02 \x03(\x0b2\x1c.tensorflow.DeviceAttributes"o\n\x13MakeCallableRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12,\n\x07options\x18\x02 \x01(\x0b2\x1b.tensorflow.CallableOptions\x12\x12\n\nrequest_id\x18\x03 \x01(\x03"&\n\x14MakeCallableResponse\x12\x0e\n\x06handle\x18\x01 \x01(\x03"w\n\x12RunCallableRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x03\x12%\n\x04feed\x18\x03 \x03(\x0b2\x17.tensorflow.TensorProto\x12\x12\n\nrequest_id\x18\x04 \x01(\x03"h\n\x13RunCallableResponse\x12&\n\x05fetch\x18\x01 \x03(\x0b2\x17.tensorflow.TensorProto\x12)\n\x08metadata\x18\x02 \x01(\x0b2\x17.tensorflow.RunMetadata"@\n\x16ReleaseCallableRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x03"\x19\n\x17ReleaseCallableResponseB\x92\x01\n\x1aorg.tensorflow.distruntimeB\x18DistributedRuntimeProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_device__attributes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_config__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2.DESCRIPTOR])
_CREATESESSIONREQUEST = _descriptor.Descriptor(name='CreateSessionRequest', full_name='tensorflow.CreateSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_def', full_name='tensorflow.CreateSessionRequest.graph_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='config', full_name='tensorflow.CreateSessionRequest.config', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target', full_name='tensorflow.CreateSessionRequest.target', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=311, serialized_end=431)
_CREATESESSIONRESPONSE = _descriptor.Descriptor(name='CreateSessionResponse', full_name='tensorflow.CreateSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.CreateSessionResponse.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_version', full_name='tensorflow.CreateSessionResponse.graph_version', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=433, serialized_end=503)
_EXTENDSESSIONREQUEST = _descriptor.Descriptor(name='ExtendSessionRequest', full_name='tensorflow.ExtendSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.ExtendSessionRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_def', full_name='tensorflow.ExtendSessionRequest.graph_def', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_graph_version', full_name='tensorflow.ExtendSessionRequest.current_graph_version', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=505, serialized_end=623)
_EXTENDSESSIONRESPONSE = _descriptor.Descriptor(name='ExtendSessionResponse', full_name='tensorflow.ExtendSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='new_graph_version', full_name='tensorflow.ExtendSessionResponse.new_graph_version', index=0, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=625, serialized_end=675)
_RUNSTEPREQUEST = _descriptor.Descriptor(name='RunStepRequest', full_name='tensorflow.RunStepRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.RunStepRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='feed', full_name='tensorflow.RunStepRequest.feed', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch', full_name='tensorflow.RunStepRequest.fetch', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target', full_name='tensorflow.RunStepRequest.target', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='options', full_name='tensorflow.RunStepRequest.options', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='partial_run_handle', full_name='tensorflow.RunStepRequest.partial_run_handle', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='store_errors_in_response_body', full_name='tensorflow.RunStepRequest.store_errors_in_response_body', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RunStepRequest.request_id', index=7, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=678, serialized_end=921)
_RUNSTEPRESPONSE = _descriptor.Descriptor(name='RunStepResponse', full_name='tensorflow.RunStepResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.RunStepResponse.tensor', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.RunStepResponse.metadata', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_code', full_name='tensorflow.RunStepResponse.status_code', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_error_message', full_name='tensorflow.RunStepResponse.status_error_message', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=924, serialized_end=1105)
_PARTIALRUNSETUPREQUEST = _descriptor.Descriptor(name='PartialRunSetupRequest', full_name='tensorflow.PartialRunSetupRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.PartialRunSetupRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='feed', full_name='tensorflow.PartialRunSetupRequest.feed', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch', full_name='tensorflow.PartialRunSetupRequest.fetch', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target', full_name='tensorflow.PartialRunSetupRequest.target', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.PartialRunSetupRequest.request_id', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1107, serialized_end=1220)
_PARTIALRUNSETUPRESPONSE = _descriptor.Descriptor(name='PartialRunSetupResponse', full_name='tensorflow.PartialRunSetupResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='partial_run_handle', full_name='tensorflow.PartialRunSetupResponse.partial_run_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1222, serialized_end=1275)
_CLOSESESSIONREQUEST = _descriptor.Descriptor(name='CloseSessionRequest', full_name='tensorflow.CloseSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.CloseSessionRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1277, serialized_end=1322)
_CLOSESESSIONRESPONSE = _descriptor.Descriptor(name='CloseSessionResponse', full_name='tensorflow.CloseSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1324, serialized_end=1346)
_RESETREQUEST = _descriptor.Descriptor(name='ResetRequest', full_name='tensorflow.ResetRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='container', full_name='tensorflow.ResetRequest.container', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_filters', full_name='tensorflow.ResetRequest.device_filters', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1348, serialized_end=1405)
_RESETRESPONSE = _descriptor.Descriptor(name='ResetResponse', full_name='tensorflow.ResetResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1407, serialized_end=1422)
_LISTDEVICESREQUEST = _descriptor.Descriptor(name='ListDevicesRequest', full_name='tensorflow.ListDevicesRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.ListDevicesRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1424, serialized_end=1468)
_LISTDEVICESRESPONSE = _descriptor.Descriptor(name='ListDevicesResponse', full_name='tensorflow.ListDevicesResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='local_device', full_name='tensorflow.ListDevicesResponse.local_device', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remote_device', full_name='tensorflow.ListDevicesResponse.remote_device', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1470, serialized_end=1596)
_MAKECALLABLEREQUEST = _descriptor.Descriptor(name='MakeCallableRequest', full_name='tensorflow.MakeCallableRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.MakeCallableRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='options', full_name='tensorflow.MakeCallableRequest.options', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.MakeCallableRequest.request_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1598, serialized_end=1709)
_MAKECALLABLERESPONSE = _descriptor.Descriptor(name='MakeCallableResponse', full_name='tensorflow.MakeCallableResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='handle', full_name='tensorflow.MakeCallableResponse.handle', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1711, serialized_end=1749)
_RUNCALLABLEREQUEST = _descriptor.Descriptor(name='RunCallableRequest', full_name='tensorflow.RunCallableRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.RunCallableRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle', full_name='tensorflow.RunCallableRequest.handle', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='feed', full_name='tensorflow.RunCallableRequest.feed', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RunCallableRequest.request_id', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1751, serialized_end=1870)
_RUNCALLABLERESPONSE = _descriptor.Descriptor(name='RunCallableResponse', full_name='tensorflow.RunCallableResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='fetch', full_name='tensorflow.RunCallableResponse.fetch', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.RunCallableResponse.metadata', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1872, serialized_end=1976)
_RELEASECALLABLEREQUEST = _descriptor.Descriptor(name='ReleaseCallableRequest', full_name='tensorflow.ReleaseCallableRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.ReleaseCallableRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle', full_name='tensorflow.ReleaseCallableRequest.handle', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1978, serialized_end=2042)
_RELEASECALLABLERESPONSE = _descriptor.Descriptor(name='ReleaseCallableResponse', full_name='tensorflow.ReleaseCallableResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2044, serialized_end=2069)
_CREATESESSIONREQUEST.fields_by_name['graph_def'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_CREATESESSIONREQUEST.fields_by_name['config'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._CONFIGPROTO
_EXTENDSESSIONREQUEST.fields_by_name['graph_def'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_RUNSTEPREQUEST.fields_by_name['feed'].message_type = tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2._NAMEDTENSORPROTO
_RUNSTEPREQUEST.fields_by_name['options'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNOPTIONS
_RUNSTEPRESPONSE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2._NAMEDTENSORPROTO
_RUNSTEPRESPONSE.fields_by_name['metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNMETADATA
_RUNSTEPRESPONSE.fields_by_name['status_code'].enum_type = tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2._CODE
_LISTDEVICESRESPONSE.fields_by_name['local_device'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_LISTDEVICESRESPONSE.fields_by_name['remote_device'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_MAKECALLABLEREQUEST.fields_by_name['options'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._CALLABLEOPTIONS
_RUNCALLABLEREQUEST.fields_by_name['feed'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_RUNCALLABLERESPONSE.fields_by_name['fetch'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_RUNCALLABLERESPONSE.fields_by_name['metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNMETADATA
DESCRIPTOR.message_types_by_name['CreateSessionRequest'] = _CREATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateSessionResponse'] = _CREATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ExtendSessionRequest'] = _EXTENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['ExtendSessionResponse'] = _EXTENDSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['RunStepRequest'] = _RUNSTEPREQUEST
DESCRIPTOR.message_types_by_name['RunStepResponse'] = _RUNSTEPRESPONSE
DESCRIPTOR.message_types_by_name['PartialRunSetupRequest'] = _PARTIALRUNSETUPREQUEST
DESCRIPTOR.message_types_by_name['PartialRunSetupResponse'] = _PARTIALRUNSETUPRESPONSE
DESCRIPTOR.message_types_by_name['CloseSessionRequest'] = _CLOSESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CloseSessionResponse'] = _CLOSESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ResetRequest'] = _RESETREQUEST
DESCRIPTOR.message_types_by_name['ResetResponse'] = _RESETRESPONSE
DESCRIPTOR.message_types_by_name['ListDevicesRequest'] = _LISTDEVICESREQUEST
DESCRIPTOR.message_types_by_name['ListDevicesResponse'] = _LISTDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['MakeCallableRequest'] = _MAKECALLABLEREQUEST
DESCRIPTOR.message_types_by_name['MakeCallableResponse'] = _MAKECALLABLERESPONSE
DESCRIPTOR.message_types_by_name['RunCallableRequest'] = _RUNCALLABLEREQUEST
DESCRIPTOR.message_types_by_name['RunCallableResponse'] = _RUNCALLABLERESPONSE
DESCRIPTOR.message_types_by_name['ReleaseCallableRequest'] = _RELEASECALLABLEREQUEST
DESCRIPTOR.message_types_by_name['ReleaseCallableResponse'] = _RELEASECALLABLERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CreateSessionRequest = _reflection.GeneratedProtocolMessageType('CreateSessionRequest', (_message.Message,), {'DESCRIPTOR': _CREATESESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CreateSessionRequest)
CreateSessionResponse = _reflection.GeneratedProtocolMessageType('CreateSessionResponse', (_message.Message,), {'DESCRIPTOR': _CREATESESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CreateSessionResponse)
ExtendSessionRequest = _reflection.GeneratedProtocolMessageType('ExtendSessionRequest', (_message.Message,), {'DESCRIPTOR': _EXTENDSESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ExtendSessionRequest)
ExtendSessionResponse = _reflection.GeneratedProtocolMessageType('ExtendSessionResponse', (_message.Message,), {'DESCRIPTOR': _EXTENDSESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ExtendSessionResponse)
RunStepRequest = _reflection.GeneratedProtocolMessageType('RunStepRequest', (_message.Message,), {'DESCRIPTOR': _RUNSTEPREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunStepRequest)
RunStepResponse = _reflection.GeneratedProtocolMessageType('RunStepResponse', (_message.Message,), {'DESCRIPTOR': _RUNSTEPRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunStepResponse)
PartialRunSetupRequest = _reflection.GeneratedProtocolMessageType('PartialRunSetupRequest', (_message.Message,), {'DESCRIPTOR': _PARTIALRUNSETUPREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(PartialRunSetupRequest)
PartialRunSetupResponse = _reflection.GeneratedProtocolMessageType('PartialRunSetupResponse', (_message.Message,), {'DESCRIPTOR': _PARTIALRUNSETUPRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(PartialRunSetupResponse)
CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {'DESCRIPTOR': _CLOSESESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CloseSessionRequest)
CloseSessionResponse = _reflection.GeneratedProtocolMessageType('CloseSessionResponse', (_message.Message,), {'DESCRIPTOR': _CLOSESESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CloseSessionResponse)
ResetRequest = _reflection.GeneratedProtocolMessageType('ResetRequest', (_message.Message,), {'DESCRIPTOR': _RESETREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ResetRequest)
ResetResponse = _reflection.GeneratedProtocolMessageType('ResetResponse', (_message.Message,), {'DESCRIPTOR': _RESETRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ResetResponse)
ListDevicesRequest = _reflection.GeneratedProtocolMessageType('ListDevicesRequest', (_message.Message,), {'DESCRIPTOR': _LISTDEVICESREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ListDevicesRequest)
ListDevicesResponse = _reflection.GeneratedProtocolMessageType('ListDevicesResponse', (_message.Message,), {'DESCRIPTOR': _LISTDEVICESRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ListDevicesResponse)
MakeCallableRequest = _reflection.GeneratedProtocolMessageType('MakeCallableRequest', (_message.Message,), {'DESCRIPTOR': _MAKECALLABLEREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(MakeCallableRequest)
MakeCallableResponse = _reflection.GeneratedProtocolMessageType('MakeCallableResponse', (_message.Message,), {'DESCRIPTOR': _MAKECALLABLERESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(MakeCallableResponse)
RunCallableRequest = _reflection.GeneratedProtocolMessageType('RunCallableRequest', (_message.Message,), {'DESCRIPTOR': _RUNCALLABLEREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunCallableRequest)
RunCallableResponse = _reflection.GeneratedProtocolMessageType('RunCallableResponse', (_message.Message,), {'DESCRIPTOR': _RUNCALLABLERESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunCallableResponse)
ReleaseCallableRequest = _reflection.GeneratedProtocolMessageType('ReleaseCallableRequest', (_message.Message,), {'DESCRIPTOR': _RELEASECALLABLEREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ReleaseCallableRequest)
ReleaseCallableResponse = _reflection.GeneratedProtocolMessageType('ReleaseCallableResponse', (_message.Message,), {'DESCRIPTOR': _RELEASECALLABLERESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ReleaseCallableResponse)
DESCRIPTOR._options = None
