
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
from .....tensorflow.core.profiler.protobuf import pod_stats_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_pod__stats__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/pod_viewer.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n2tensorflow/core/profiler/protobuf/pod_viewer.proto\x12\x13tensorflow.profiler\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto\x1a1tensorflow/core/profiler/protobuf/pod_stats.proto"#\n\x0cReplicaGroup\x12\x13\n\x0breplica_ids\x18\x01 \x03(\x03"\xac\x01\n\x0fAllReduceOpInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0boccurrences\x18\x02 \x01(\r\x12\x13\n\x0bduration_us\x18\x03 \x01(\x01\x12\x11\n\tdata_size\x18\x04 \x01(\x04\x129\n\x0ereplica_groups\x18\x05 \x03(\x0b2!.tensorflow.profiler.ReplicaGroup\x12\x13\n\x0bdescription\x18\x06 \x01(\t"\xe1\x03\n\x0bPodStatsMap\x12\x10\n\x08step_num\x18\x01 \x01(\r\x12Q\n\x12pod_stats_per_core\x18\x02 \x03(\x0b25.tensorflow.profiler.PodStatsMap.PodStatsPerCoreEntry\x124\n\nchannel_db\x18\x03 \x03(\x0b2 .tensorflow.profiler.ChannelInfo\x12]\n\x19core_id_to_replica_id_map\x18\x04 \x03(\x0b2:.tensorflow.profiler.PodStatsMap.CoreIdToReplicaIdMapEntry\x12>\n\x10all_reduce_op_db\x18\x05 \x03(\x0b2$.tensorflow.profiler.AllReduceOpInfo\x1a[\n\x14PodStatsPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x122\n\x05value\x18\x02 \x01(\x0b2#.tensorflow.profiler.PodStatsRecord:\x028\x01\x1a;\n\x19CoreIdToReplicaIdMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r:\x028\x01"K\n\x10PodStatsSequence\x127\n\rpod_stats_map\x18\x01 \x03(\x0b2 .tensorflow.profiler.PodStatsMap"\xf0\x01\n\x0bChannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x14\n\x0csrc_core_ids\x18\x0b \x03(\r\x12\x14\n\x0cdst_core_ids\x18\x0c \x03(\r\x12\x11\n\tdata_size\x18\x04 \x01(\x04\x12\x13\n\x0bduration_us\x18\x05 \x01(\x01\x12\x13\n\x0boccurrences\x18\x06 \x01(\r\x12\x13\n\x0butilization\x18\x07 \x01(\x01\x12\x11\n\thlo_names\x18\x08 \x03(\t\x12\x15\n\rsend_delay_us\x18\t \x01(\x01\x12\x13\n\x0bdescription\x18\r \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\n\x10\x0b"$\n\x10PodViewerSummary\x12\x10\n\x08warnings\x18\x01 \x03(\t"\xb3\x01\n\x11PodViewerTopology\x12\x13\n\x0bx_dimension\x18\x01 \x01(\x05\x12\x13\n\x0by_dimension\x18\x02 \x01(\x05\x12\x13\n\x0bz_dimension\x18\x03 \x01(\x05\x12\x15\n\rhost_x_stride\x18\x04 \x01(\x05\x12\x15\n\rhost_y_stride\x18\x05 \x01(\x05\x12\x15\n\rhost_z_stride\x18\x06 \x01(\x05\x12\x1a\n\x12num_cores_per_chip\x18\x07 \x01(\x05"\xfb\x02\n\x11PodViewerDatabase\x12\x13\n\x0bdevice_type\x18\n \x01(\t\x12A\n\x12pod_stats_sequence\x18\x03 \x01(\x0b2%.tensorflow.profiler.PodStatsSequence\x126\n\x07summary\x18\x07 \x01(\x0b2%.tensorflow.profiler.PodViewerSummary\x125\n\x0bdiagnostics\x18\x08 \x01(\x0b2 .tensorflow.profiler.Diagnostics\x12G\n\x15step_breakdown_events\x18\t \x03(\x0b2(.tensorflow.profiler.StepBreakdownEvents\x128\n\x08topology\x18\x0b \x01(\x0b2&.tensorflow.profiler.PodViewerTopologyJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07b\x06proto3', dependencies=[tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_pod__stats__pb2.DESCRIPTOR])
_REPLICAGROUP = _descriptor.Descriptor(name='ReplicaGroup', full_name='tensorflow.profiler.ReplicaGroup', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='replica_ids', full_name='tensorflow.profiler.ReplicaGroup.replica_ids', index=0, number=1, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=179, serialized_end=214)
_ALLREDUCEOPINFO = _descriptor.Descriptor(name='AllReduceOpInfo', full_name='tensorflow.profiler.AllReduceOpInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.AllReduceOpInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='occurrences', full_name='tensorflow.profiler.AllReduceOpInfo.occurrences', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_us', full_name='tensorflow.profiler.AllReduceOpInfo.duration_us', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_size', full_name='tensorflow.profiler.AllReduceOpInfo.data_size', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='replica_groups', full_name='tensorflow.profiler.AllReduceOpInfo.replica_groups', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.profiler.AllReduceOpInfo.description', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=217, serialized_end=389)
_PODSTATSMAP_PODSTATSPERCOREENTRY = _descriptor.Descriptor(name='PodStatsPerCoreEntry', full_name='tensorflow.profiler.PodStatsMap.PodStatsPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PodStatsMap.PodStatsPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PodStatsMap.PodStatsPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=721, serialized_end=812)
_PODSTATSMAP_COREIDTOREPLICAIDMAPENTRY = _descriptor.Descriptor(name='CoreIdToReplicaIdMapEntry', full_name='tensorflow.profiler.PodStatsMap.CoreIdToReplicaIdMapEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PodStatsMap.CoreIdToReplicaIdMapEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PodStatsMap.CoreIdToReplicaIdMapEntry.value', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=814, serialized_end=873)
_PODSTATSMAP = _descriptor.Descriptor(name='PodStatsMap', full_name='tensorflow.profiler.PodStatsMap', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.PodStatsMap.step_num', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pod_stats_per_core', full_name='tensorflow.profiler.PodStatsMap.pod_stats_per_core', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='channel_db', full_name='tensorflow.profiler.PodStatsMap.channel_db', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_id_to_replica_id_map', full_name='tensorflow.profiler.PodStatsMap.core_id_to_replica_id_map', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_reduce_op_db', full_name='tensorflow.profiler.PodStatsMap.all_reduce_op_db', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PODSTATSMAP_PODSTATSPERCOREENTRY, _PODSTATSMAP_COREIDTOREPLICAIDMAPENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=392, serialized_end=873)
_PODSTATSSEQUENCE = _descriptor.Descriptor(name='PodStatsSequence', full_name='tensorflow.profiler.PodStatsSequence', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='pod_stats_map', full_name='tensorflow.profiler.PodStatsSequence.pod_stats_map', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=875, serialized_end=950)
_CHANNELINFO = _descriptor.Descriptor(name='ChannelInfo', full_name='tensorflow.profiler.ChannelInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='channel_id', full_name='tensorflow.profiler.ChannelInfo.channel_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='src_core_ids', full_name='tensorflow.profiler.ChannelInfo.src_core_ids', index=1, number=11, type=13, cpp_type=3, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dst_core_ids', full_name='tensorflow.profiler.ChannelInfo.dst_core_ids', index=2, number=12, type=13, cpp_type=3, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_size', full_name='tensorflow.profiler.ChannelInfo.data_size', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_us', full_name='tensorflow.profiler.ChannelInfo.duration_us', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='occurrences', full_name='tensorflow.profiler.ChannelInfo.occurrences', index=5, number=6, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='utilization', full_name='tensorflow.profiler.ChannelInfo.utilization', index=6, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_names', full_name='tensorflow.profiler.ChannelInfo.hlo_names', index=7, number=8, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='send_delay_us', full_name='tensorflow.profiler.ChannelInfo.send_delay_us', index=8, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.profiler.ChannelInfo.description', index=9, number=13, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=953, serialized_end=1193)
_PODVIEWERSUMMARY = _descriptor.Descriptor(name='PodViewerSummary', full_name='tensorflow.profiler.PodViewerSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='warnings', full_name='tensorflow.profiler.PodViewerSummary.warnings', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1195, serialized_end=1231)
_PODVIEWERTOPOLOGY = _descriptor.Descriptor(name='PodViewerTopology', full_name='tensorflow.profiler.PodViewerTopology', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='x_dimension', full_name='tensorflow.profiler.PodViewerTopology.x_dimension', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='y_dimension', full_name='tensorflow.profiler.PodViewerTopology.y_dimension', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='z_dimension', full_name='tensorflow.profiler.PodViewerTopology.z_dimension', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_x_stride', full_name='tensorflow.profiler.PodViewerTopology.host_x_stride', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_y_stride', full_name='tensorflow.profiler.PodViewerTopology.host_y_stride', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_z_stride', full_name='tensorflow.profiler.PodViewerTopology.host_z_stride', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_chip', full_name='tensorflow.profiler.PodViewerTopology.num_cores_per_chip', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1234, serialized_end=1413)
_PODVIEWERDATABASE = _descriptor.Descriptor(name='PodViewerDatabase', full_name='tensorflow.profiler.PodViewerDatabase', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.profiler.PodViewerDatabase.device_type', index=0, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='pod_stats_sequence', full_name='tensorflow.profiler.PodViewerDatabase.pod_stats_sequence', index=1, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary', full_name='tensorflow.profiler.PodViewerDatabase.summary', index=2, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.PodViewerDatabase.diagnostics', index=3, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown_events', full_name='tensorflow.profiler.PodViewerDatabase.step_breakdown_events', index=4, number=9, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='topology', full_name='tensorflow.profiler.PodViewerDatabase.topology', index=5, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1416, serialized_end=1795)
_ALLREDUCEOPINFO.fields_by_name['replica_groups'].message_type = _REPLICAGROUP
_PODSTATSMAP_PODSTATSPERCOREENTRY.fields_by_name['value'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_pod__stats__pb2._PODSTATSRECORD
_PODSTATSMAP_PODSTATSPERCOREENTRY.containing_type = _PODSTATSMAP
_PODSTATSMAP_COREIDTOREPLICAIDMAPENTRY.containing_type = _PODSTATSMAP
_PODSTATSMAP.fields_by_name['pod_stats_per_core'].message_type = _PODSTATSMAP_PODSTATSPERCOREENTRY
_PODSTATSMAP.fields_by_name['channel_db'].message_type = _CHANNELINFO
_PODSTATSMAP.fields_by_name['core_id_to_replica_id_map'].message_type = _PODSTATSMAP_COREIDTOREPLICAIDMAPENTRY
_PODSTATSMAP.fields_by_name['all_reduce_op_db'].message_type = _ALLREDUCEOPINFO
_PODSTATSSEQUENCE.fields_by_name['pod_stats_map'].message_type = _PODSTATSMAP
_PODVIEWERDATABASE.fields_by_name['pod_stats_sequence'].message_type = _PODSTATSSEQUENCE
_PODVIEWERDATABASE.fields_by_name['summary'].message_type = _PODVIEWERSUMMARY
_PODVIEWERDATABASE.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
_PODVIEWERDATABASE.fields_by_name['step_breakdown_events'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_pod__stats__pb2._STEPBREAKDOWNEVENTS
_PODVIEWERDATABASE.fields_by_name['topology'].message_type = _PODVIEWERTOPOLOGY
DESCRIPTOR.message_types_by_name['ReplicaGroup'] = _REPLICAGROUP
DESCRIPTOR.message_types_by_name['AllReduceOpInfo'] = _ALLREDUCEOPINFO
DESCRIPTOR.message_types_by_name['PodStatsMap'] = _PODSTATSMAP
DESCRIPTOR.message_types_by_name['PodStatsSequence'] = _PODSTATSSEQUENCE
DESCRIPTOR.message_types_by_name['ChannelInfo'] = _CHANNELINFO
DESCRIPTOR.message_types_by_name['PodViewerSummary'] = _PODVIEWERSUMMARY
DESCRIPTOR.message_types_by_name['PodViewerTopology'] = _PODVIEWERTOPOLOGY
DESCRIPTOR.message_types_by_name['PodViewerDatabase'] = _PODVIEWERDATABASE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ReplicaGroup = _reflection.GeneratedProtocolMessageType('ReplicaGroup', (_message.Message,), {'DESCRIPTOR': _REPLICAGROUP, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(ReplicaGroup)
AllReduceOpInfo = _reflection.GeneratedProtocolMessageType('AllReduceOpInfo', (_message.Message,), {'DESCRIPTOR': _ALLREDUCEOPINFO, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(AllReduceOpInfo)
PodStatsMap = _reflection.GeneratedProtocolMessageType('PodStatsMap', (_message.Message,), {'PodStatsPerCoreEntry': _reflection.GeneratedProtocolMessageType('PodStatsPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PODSTATSMAP_PODSTATSPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'}), 'CoreIdToReplicaIdMapEntry': _reflection.GeneratedProtocolMessageType('CoreIdToReplicaIdMapEntry', (_message.Message,), {'DESCRIPTOR': _PODSTATSMAP_COREIDTOREPLICAIDMAPENTRY, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'}), 'DESCRIPTOR': _PODSTATSMAP, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(PodStatsMap)
_sym_db.RegisterMessage(PodStatsMap.PodStatsPerCoreEntry)
_sym_db.RegisterMessage(PodStatsMap.CoreIdToReplicaIdMapEntry)
PodStatsSequence = _reflection.GeneratedProtocolMessageType('PodStatsSequence', (_message.Message,), {'DESCRIPTOR': _PODSTATSSEQUENCE, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(PodStatsSequence)
ChannelInfo = _reflection.GeneratedProtocolMessageType('ChannelInfo', (_message.Message,), {'DESCRIPTOR': _CHANNELINFO, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(ChannelInfo)
PodViewerSummary = _reflection.GeneratedProtocolMessageType('PodViewerSummary', (_message.Message,), {'DESCRIPTOR': _PODVIEWERSUMMARY, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(PodViewerSummary)
PodViewerTopology = _reflection.GeneratedProtocolMessageType('PodViewerTopology', (_message.Message,), {'DESCRIPTOR': _PODVIEWERTOPOLOGY, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(PodViewerTopology)
PodViewerDatabase = _reflection.GeneratedProtocolMessageType('PodViewerDatabase', (_message.Message,), {'DESCRIPTOR': _PODVIEWERDATABASE, '__module__': 'tensorflow.core.profiler.protobuf.pod_viewer_pb2'})
_sym_db.RegisterMessage(PodViewerDatabase)
_PODSTATSMAP_PODSTATSPERCOREENTRY._options = None
_PODSTATSMAP_COREIDTOREPLICAIDMAPENTRY._options = None
