
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/tfstreamz.proto', package='tensorflow.profiler.tfstreamz', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n1tensorflow/core/profiler/protobuf/tfstreamz.proto\x12\x1dtensorflow.profiler.tfstreamz"4\n\x0fPercentilePoint\x12\x12\n\npercentile\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01"\xc3\x02\n\x0bPercentiles\x12E\n\x0funit_of_measure\x18\x01 \x01(\x0e2,.tensorflow.profiler.tfstreamz.UnitOfMeasure\x12\x14\n\x0cstart_nstime\x18\x02 \x01(\x04\x12\x12\n\nend_nstime\x18\x03 \x01(\x04\x12\x11\n\tmin_value\x18\x04 \x01(\x01\x12\x11\n\tmax_value\x18\x05 \x01(\x01\x12\x0c\n\x04mean\x18\x06 \x01(\x01\x12\x0e\n\x06stddev\x18\x07 \x01(\x01\x12\x13\n\x0bnum_samples\x18\x08 \x01(\x04\x12\x15\n\rtotal_samples\x18\t \x01(\x04\x12\x13\n\x0baccumulator\x18\n \x01(\x01\x12>\n\x06points\x18\x0b \x03(\x0b2..tensorflow.profiler.tfstreamz.PercentilePoint*0\n\rUnitOfMeasure\x12\n\n\x06NUMBER\x10\x00\x12\x08\n\x04TIME\x10\x01\x12\t\n\x05BYTES\x10\x02b\x06proto3')
_UNITOFMEASURE = _descriptor.EnumDescriptor(name='UnitOfMeasure', full_name='tensorflow.profiler.tfstreamz.UnitOfMeasure', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='NUMBER', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TIME', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BYTES', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=464, serialized_end=512)
_sym_db.RegisterEnumDescriptor(_UNITOFMEASURE)
UnitOfMeasure = enum_type_wrapper.EnumTypeWrapper(_UNITOFMEASURE)
NUMBER = 0
TIME = 1
BYTES = 2
_PERCENTILEPOINT = _descriptor.Descriptor(name='PercentilePoint', full_name='tensorflow.profiler.tfstreamz.PercentilePoint', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='percentile', full_name='tensorflow.profiler.tfstreamz.PercentilePoint.percentile', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.tfstreamz.PercentilePoint.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=84, serialized_end=136)
_PERCENTILES = _descriptor.Descriptor(name='Percentiles', full_name='tensorflow.profiler.tfstreamz.Percentiles', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='unit_of_measure', full_name='tensorflow.profiler.tfstreamz.Percentiles.unit_of_measure', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_nstime', full_name='tensorflow.profiler.tfstreamz.Percentiles.start_nstime', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_nstime', full_name='tensorflow.profiler.tfstreamz.Percentiles.end_nstime', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='min_value', full_name='tensorflow.profiler.tfstreamz.Percentiles.min_value', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_value', full_name='tensorflow.profiler.tfstreamz.Percentiles.max_value', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mean', full_name='tensorflow.profiler.tfstreamz.Percentiles.mean', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stddev', full_name='tensorflow.profiler.tfstreamz.Percentiles.stddev', index=6, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_samples', full_name='tensorflow.profiler.tfstreamz.Percentiles.num_samples', index=7, number=8, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_samples', full_name='tensorflow.profiler.tfstreamz.Percentiles.total_samples', index=8, number=9, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='accumulator', full_name='tensorflow.profiler.tfstreamz.Percentiles.accumulator', index=9, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='points', full_name='tensorflow.profiler.tfstreamz.Percentiles.points', index=10, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=139, serialized_end=462)
_PERCENTILES.fields_by_name['unit_of_measure'].enum_type = _UNITOFMEASURE
_PERCENTILES.fields_by_name['points'].message_type = _PERCENTILEPOINT
DESCRIPTOR.message_types_by_name['PercentilePoint'] = _PERCENTILEPOINT
DESCRIPTOR.message_types_by_name['Percentiles'] = _PERCENTILES
DESCRIPTOR.enum_types_by_name['UnitOfMeasure'] = _UNITOFMEASURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
PercentilePoint = _reflection.GeneratedProtocolMessageType('PercentilePoint', (_message.Message,), {'DESCRIPTOR': _PERCENTILEPOINT, '__module__': 'tensorflow.core.profiler.protobuf.tfstreamz_pb2'})
_sym_db.RegisterMessage(PercentilePoint)
Percentiles = _reflection.GeneratedProtocolMessageType('Percentiles', (_message.Message,), {'DESCRIPTOR': _PERCENTILES, '__module__': 'tensorflow.core.profiler.protobuf.tfstreamz_pb2'})
_sym_db.RegisterMessage(Percentiles)
