
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.data.service import common_pb2 as tensorflow_dot_core_dot_data_dot_service_dot_common__pb2
from .....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/data/service/dispatcher.proto', package='tensorflow.data', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/data/service/dispatcher.proto\x12\x0ftensorflow.data\x1a)tensorflow/core/data/service/common.proto\x1a&tensorflow/core/framework/tensor.proto"2\n\x0cTaskProgress\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x11\n\tcompleted\x18\x02 \x01(\x08"a\n\x16WorkerHeartbeatRequest\x12\x16\n\x0eworker_address\x18\x01 \x01(\t\x12\x18\n\x10transfer_address\x18\x03 \x01(\t\x12\x15\n\rcurrent_tasks\x18\x02 \x03(\x03"_\n\x17WorkerHeartbeatResponse\x12+\n\tnew_tasks\x18\x01 \x03(\x0b2\x18.tensorflow.data.TaskDef\x12\x17\n\x0ftasks_to_delete\x18\x02 \x03(\x03"]\n\x13WorkerUpdateRequest\x12\x16\n\x0eworker_address\x18\x01 \x01(\t\x12.\n\x07updates\x18\x02 \x03(\x0b2\x1d.tensorflow.data.TaskProgress"\x16\n\x14WorkerUpdateResponse"*\n\x14GetDatasetDefRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x03"I\n\x15GetDatasetDefResponse\x120\n\x0bdataset_def\x18\x01 \x01(\x0b2\x1b.tensorflow.data.DatasetDef"S\n\x0fGetSplitRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\x03\x12\x12\n\nrepetition\x18\x02 \x01(\x03\x12\x1c\n\x14split_provider_index\x18\x03 \x01(\x03"Q\n\x10GetSplitResponse\x12&\n\x05split\x18\x01 \x01(\x0b2\x17.tensorflow.TensorProto\x12\x15\n\rend_of_splits\x18\x02 \x01(\x08"\x13\n\x11GetVersionRequest"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\x03"K\n\x1bGetOrRegisterDatasetRequest\x12,\n\x07dataset\x18\x01 \x01(\x0b2\x1b.tensorflow.data.DatasetDef"2\n\x1cGetOrRegisterDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\x03"2\n\x06JobKey\x12\x10\n\x08job_name\x18\x01 \x01(\t\x12\x16\n\x0ejob_name_index\x18\x02 \x01(\x03"\xd1\x01\n\x15GetOrCreateJobRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x03\x12;\n\x0fprocessing_mode\x18\x02 \x01(\x0e2".tensorflow.data.ProcessingModeDef\x12(\n\x07job_key\x18\x05 \x01(\x0b2\x17.tensorflow.data.JobKey\x12\x17\n\rnum_consumers\x18\x07 \x01(\x03H\x00B\x18\n\x16optional_num_consumersJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05"/\n\x16GetOrCreateJobResponse\x12\x15\n\rjob_client_id\x18\x01 \x01(\x03"P\n\x16MaybeRemoveTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x16\n\x0econsumer_index\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x03"*\n\x17MaybeRemoveTaskResponse\x12\x0f\n\x07removed\x18\x01 \x01(\x08"0\n\x17ReleaseJobClientRequest\x12\x15\n\rjob_client_id\x18\x01 \x01(\x03"\x1a\n\x18ReleaseJobClientResponse"\x9b\x01\n\x16ClientHeartbeatRequest\x12\x15\n\rjob_client_id\x18\x01 \x01(\x03\x12\x17\n\rcurrent_round\x18\x02 \x01(\x03H\x00\x12\x17\n\rblocked_round\x18\x04 \x01(\x03H\x01B\x18\n\x16optional_current_roundB\x18\n\x16optional_blocked_roundJ\x04\x08\x03\x10\x04"\x8c\x01\n\x17ClientHeartbeatResponse\x12,\n\ttask_info\x18\x01 \x03(\x0b2\x19.tensorflow.data.TaskInfo\x12\x15\n\x0bblock_round\x18\x03 \x01(\x03H\x00\x12\x14\n\x0cjob_finished\x18\x02 \x01(\x08B\x16\n\x14optional_block_round")\n\nWorkerInfo\x12\x0f\n\x07address\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03"\x13\n\x11GetWorkersRequest"B\n\x12GetWorkersResponse\x12,\n\x07workers\x18\x01 \x03(\x0b2\x1b.tensorflow.data.WorkerInfo2\xc2\x08\n\x11DispatcherService\x12d\n\x0fWorkerHeartbeat\x12\'.tensorflow.data.WorkerHeartbeatRequest\x1a(.tensorflow.data.WorkerHeartbeatResponse\x12[\n\x0cWorkerUpdate\x12$.tensorflow.data.WorkerUpdateRequest\x1a%.tensorflow.data.WorkerUpdateResponse\x12^\n\rGetDatasetDef\x12%.tensorflow.data.GetDatasetDefRequest\x1a&.tensorflow.data.GetDatasetDefResponse\x12O\n\x08GetSplit\x12 .tensorflow.data.GetSplitRequest\x1a!.tensorflow.data.GetSplitResponse\x12U\n\nGetVersion\x12".tensorflow.data.GetVersionRequest\x1a#.tensorflow.data.GetVersionResponse\x12s\n\x14GetOrRegisterDataset\x12,.tensorflow.data.GetOrRegisterDatasetRequest\x1a-.tensorflow.data.GetOrRegisterDatasetResponse\x12a\n\x0eGetOrCreateJob\x12&.tensorflow.data.GetOrCreateJobRequest\x1a\'.tensorflow.data.GetOrCreateJobResponse\x12d\n\x0fMaybeRemoveTask\x12\'.tensorflow.data.MaybeRemoveTaskRequest\x1a(.tensorflow.data.MaybeRemoveTaskResponse\x12g\n\x10ReleaseJobClient\x12(.tensorflow.data.ReleaseJobClientRequest\x1a).tensorflow.data.ReleaseJobClientResponse\x12d\n\x0fClientHeartbeat\x12\'.tensorflow.data.ClientHeartbeatRequest\x1a(.tensorflow.data.ClientHeartbeatResponse\x12U\n\nGetWorkers\x12".tensorflow.data.GetWorkersRequest\x1a#.tensorflow.data.GetWorkersResponseb\x06proto3', dependencies=[tensorflow_dot_core_dot_data_dot_service_dot_common__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR])
_TASKPROGRESS = _descriptor.Descriptor(name='TaskProgress', full_name='tensorflow.data.TaskProgress', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.TaskProgress.task_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='completed', full_name='tensorflow.data.TaskProgress.completed', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=149, serialized_end=199)
_WORKERHEARTBEATREQUEST = _descriptor.Descriptor(name='WorkerHeartbeatRequest', full_name='tensorflow.data.WorkerHeartbeatRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.WorkerHeartbeatRequest.worker_address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_address', full_name='tensorflow.data.WorkerHeartbeatRequest.transfer_address', index=1, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_tasks', full_name='tensorflow.data.WorkerHeartbeatRequest.current_tasks', index=2, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=201, serialized_end=298)
_WORKERHEARTBEATRESPONSE = _descriptor.Descriptor(name='WorkerHeartbeatResponse', full_name='tensorflow.data.WorkerHeartbeatResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='new_tasks', full_name='tensorflow.data.WorkerHeartbeatResponse.new_tasks', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tasks_to_delete', full_name='tensorflow.data.WorkerHeartbeatResponse.tasks_to_delete', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=300, serialized_end=395)
_WORKERUPDATEREQUEST = _descriptor.Descriptor(name='WorkerUpdateRequest', full_name='tensorflow.data.WorkerUpdateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.WorkerUpdateRequest.worker_address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='updates', full_name='tensorflow.data.WorkerUpdateRequest.updates', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=397, serialized_end=490)
_WORKERUPDATERESPONSE = _descriptor.Descriptor(name='WorkerUpdateResponse', full_name='tensorflow.data.WorkerUpdateResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=492, serialized_end=514)
_GETDATASETDEFREQUEST = _descriptor.Descriptor(name='GetDatasetDefRequest', full_name='tensorflow.data.GetDatasetDefRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.GetDatasetDefRequest.dataset_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=516, serialized_end=558)
_GETDATASETDEFRESPONSE = _descriptor.Descriptor(name='GetDatasetDefResponse', full_name='tensorflow.data.GetDatasetDefResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_def', full_name='tensorflow.data.GetDatasetDefResponse.dataset_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=560, serialized_end=633)
_GETSPLITREQUEST = _descriptor.Descriptor(name='GetSplitRequest', full_name='tensorflow.data.GetSplitRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_id', full_name='tensorflow.data.GetSplitRequest.job_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='repetition', full_name='tensorflow.data.GetSplitRequest.repetition', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='split_provider_index', full_name='tensorflow.data.GetSplitRequest.split_provider_index', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=635, serialized_end=718)
_GETSPLITRESPONSE = _descriptor.Descriptor(name='GetSplitResponse', full_name='tensorflow.data.GetSplitResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='split', full_name='tensorflow.data.GetSplitResponse.split', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_of_splits', full_name='tensorflow.data.GetSplitResponse.end_of_splits', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=720, serialized_end=801)
_GETVERSIONREQUEST = _descriptor.Descriptor(name='GetVersionRequest', full_name='tensorflow.data.GetVersionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=803, serialized_end=822)
_GETVERSIONRESPONSE = _descriptor.Descriptor(name='GetVersionResponse', full_name='tensorflow.data.GetVersionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='version', full_name='tensorflow.data.GetVersionResponse.version', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=824, serialized_end=861)
_GETORREGISTERDATASETREQUEST = _descriptor.Descriptor(name='GetOrRegisterDatasetRequest', full_name='tensorflow.data.GetOrRegisterDatasetRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset', full_name='tensorflow.data.GetOrRegisterDatasetRequest.dataset', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=863, serialized_end=938)
_GETORREGISTERDATASETRESPONSE = _descriptor.Descriptor(name='GetOrRegisterDatasetResponse', full_name='tensorflow.data.GetOrRegisterDatasetResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.GetOrRegisterDatasetResponse.dataset_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=940, serialized_end=990)
_JOBKEY = _descriptor.Descriptor(name='JobKey', full_name='tensorflow.data.JobKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_name', full_name='tensorflow.data.JobKey.job_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_name_index', full_name='tensorflow.data.JobKey.job_name_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=992, serialized_end=1042)
_GETORCREATEJOBREQUEST = _descriptor.Descriptor(name='GetOrCreateJobRequest', full_name='tensorflow.data.GetOrCreateJobRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.GetOrCreateJobRequest.dataset_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='processing_mode', full_name='tensorflow.data.GetOrCreateJobRequest.processing_mode', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_key', full_name='tensorflow.data.GetOrCreateJobRequest.job_key', index=2, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_consumers', full_name='tensorflow.data.GetOrCreateJobRequest.num_consumers', index=3, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_num_consumers', full_name='tensorflow.data.GetOrCreateJobRequest.optional_num_consumers', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1045, serialized_end=1254)
_GETORCREATEJOBRESPONSE = _descriptor.Descriptor(name='GetOrCreateJobResponse', full_name='tensorflow.data.GetOrCreateJobResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_client_id', full_name='tensorflow.data.GetOrCreateJobResponse.job_client_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1256, serialized_end=1303)
_MAYBEREMOVETASKREQUEST = _descriptor.Descriptor(name='MaybeRemoveTaskRequest', full_name='tensorflow.data.MaybeRemoveTaskRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.MaybeRemoveTaskRequest.task_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='consumer_index', full_name='tensorflow.data.MaybeRemoveTaskRequest.consumer_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='round', full_name='tensorflow.data.MaybeRemoveTaskRequest.round', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1305, serialized_end=1385)
_MAYBEREMOVETASKRESPONSE = _descriptor.Descriptor(name='MaybeRemoveTaskResponse', full_name='tensorflow.data.MaybeRemoveTaskResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='removed', full_name='tensorflow.data.MaybeRemoveTaskResponse.removed', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1387, serialized_end=1429)
_RELEASEJOBCLIENTREQUEST = _descriptor.Descriptor(name='ReleaseJobClientRequest', full_name='tensorflow.data.ReleaseJobClientRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_client_id', full_name='tensorflow.data.ReleaseJobClientRequest.job_client_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1431, serialized_end=1479)
_RELEASEJOBCLIENTRESPONSE = _descriptor.Descriptor(name='ReleaseJobClientResponse', full_name='tensorflow.data.ReleaseJobClientResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1481, serialized_end=1507)
_CLIENTHEARTBEATREQUEST = _descriptor.Descriptor(name='ClientHeartbeatRequest', full_name='tensorflow.data.ClientHeartbeatRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_client_id', full_name='tensorflow.data.ClientHeartbeatRequest.job_client_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_round', full_name='tensorflow.data.ClientHeartbeatRequest.current_round', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='blocked_round', full_name='tensorflow.data.ClientHeartbeatRequest.blocked_round', index=2, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_current_round', full_name='tensorflow.data.ClientHeartbeatRequest.optional_current_round', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_blocked_round', full_name='tensorflow.data.ClientHeartbeatRequest.optional_blocked_round', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1510, serialized_end=1665)
_CLIENTHEARTBEATRESPONSE = _descriptor.Descriptor(name='ClientHeartbeatResponse', full_name='tensorflow.data.ClientHeartbeatResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_info', full_name='tensorflow.data.ClientHeartbeatResponse.task_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='block_round', full_name='tensorflow.data.ClientHeartbeatResponse.block_round', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_finished', full_name='tensorflow.data.ClientHeartbeatResponse.job_finished', index=2, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_block_round', full_name='tensorflow.data.ClientHeartbeatResponse.optional_block_round', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1668, serialized_end=1808)
_WORKERINFO = _descriptor.Descriptor(name='WorkerInfo', full_name='tensorflow.data.WorkerInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='address', full_name='tensorflow.data.WorkerInfo.address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='id', full_name='tensorflow.data.WorkerInfo.id', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1810, serialized_end=1851)
_GETWORKERSREQUEST = _descriptor.Descriptor(name='GetWorkersRequest', full_name='tensorflow.data.GetWorkersRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1853, serialized_end=1872)
_GETWORKERSRESPONSE = _descriptor.Descriptor(name='GetWorkersResponse', full_name='tensorflow.data.GetWorkersResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='workers', full_name='tensorflow.data.GetWorkersResponse.workers', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1874, serialized_end=1940)
_WORKERHEARTBEATRESPONSE.fields_by_name['new_tasks'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._TASKDEF
_WORKERUPDATEREQUEST.fields_by_name['updates'].message_type = _TASKPROGRESS
_GETDATASETDEFRESPONSE.fields_by_name['dataset_def'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._DATASETDEF
_GETSPLITRESPONSE.fields_by_name['split'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_GETORREGISTERDATASETREQUEST.fields_by_name['dataset'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._DATASETDEF
_GETORCREATEJOBREQUEST.fields_by_name['processing_mode'].enum_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._PROCESSINGMODEDEF
_GETORCREATEJOBREQUEST.fields_by_name['job_key'].message_type = _JOBKEY
_GETORCREATEJOBREQUEST.oneofs_by_name['optional_num_consumers'].fields.append(_GETORCREATEJOBREQUEST.fields_by_name['num_consumers'])
_GETORCREATEJOBREQUEST.fields_by_name['num_consumers'].containing_oneof = _GETORCREATEJOBREQUEST.oneofs_by_name['optional_num_consumers']
_CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_current_round'].fields.append(_CLIENTHEARTBEATREQUEST.fields_by_name['current_round'])
_CLIENTHEARTBEATREQUEST.fields_by_name['current_round'].containing_oneof = _CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_current_round']
_CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_blocked_round'].fields.append(_CLIENTHEARTBEATREQUEST.fields_by_name['blocked_round'])
_CLIENTHEARTBEATREQUEST.fields_by_name['blocked_round'].containing_oneof = _CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_blocked_round']
_CLIENTHEARTBEATRESPONSE.fields_by_name['task_info'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._TASKINFO
_CLIENTHEARTBEATRESPONSE.oneofs_by_name['optional_block_round'].fields.append(_CLIENTHEARTBEATRESPONSE.fields_by_name['block_round'])
_CLIENTHEARTBEATRESPONSE.fields_by_name['block_round'].containing_oneof = _CLIENTHEARTBEATRESPONSE.oneofs_by_name['optional_block_round']
_GETWORKERSRESPONSE.fields_by_name['workers'].message_type = _WORKERINFO
DESCRIPTOR.message_types_by_name['TaskProgress'] = _TASKPROGRESS
DESCRIPTOR.message_types_by_name['WorkerHeartbeatRequest'] = _WORKERHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['WorkerHeartbeatResponse'] = _WORKERHEARTBEATRESPONSE
DESCRIPTOR.message_types_by_name['WorkerUpdateRequest'] = _WORKERUPDATEREQUEST
DESCRIPTOR.message_types_by_name['WorkerUpdateResponse'] = _WORKERUPDATERESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetDefRequest'] = _GETDATASETDEFREQUEST
DESCRIPTOR.message_types_by_name['GetDatasetDefResponse'] = _GETDATASETDEFRESPONSE
DESCRIPTOR.message_types_by_name['GetSplitRequest'] = _GETSPLITREQUEST
DESCRIPTOR.message_types_by_name['GetSplitResponse'] = _GETSPLITRESPONSE
DESCRIPTOR.message_types_by_name['GetVersionRequest'] = _GETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetOrRegisterDatasetRequest'] = _GETORREGISTERDATASETREQUEST
DESCRIPTOR.message_types_by_name['GetOrRegisterDatasetResponse'] = _GETORREGISTERDATASETRESPONSE
DESCRIPTOR.message_types_by_name['JobKey'] = _JOBKEY
DESCRIPTOR.message_types_by_name['GetOrCreateJobRequest'] = _GETORCREATEJOBREQUEST
DESCRIPTOR.message_types_by_name['GetOrCreateJobResponse'] = _GETORCREATEJOBRESPONSE
DESCRIPTOR.message_types_by_name['MaybeRemoveTaskRequest'] = _MAYBEREMOVETASKREQUEST
DESCRIPTOR.message_types_by_name['MaybeRemoveTaskResponse'] = _MAYBEREMOVETASKRESPONSE
DESCRIPTOR.message_types_by_name['ReleaseJobClientRequest'] = _RELEASEJOBCLIENTREQUEST
DESCRIPTOR.message_types_by_name['ReleaseJobClientResponse'] = _RELEASEJOBCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['ClientHeartbeatRequest'] = _CLIENTHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['ClientHeartbeatResponse'] = _CLIENTHEARTBEATRESPONSE
DESCRIPTOR.message_types_by_name['WorkerInfo'] = _WORKERINFO
DESCRIPTOR.message_types_by_name['GetWorkersRequest'] = _GETWORKERSREQUEST
DESCRIPTOR.message_types_by_name['GetWorkersResponse'] = _GETWORKERSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TaskProgress = _reflection.GeneratedProtocolMessageType('TaskProgress', (_message.Message,), {'DESCRIPTOR': _TASKPROGRESS, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(TaskProgress)
WorkerHeartbeatRequest = _reflection.GeneratedProtocolMessageType('WorkerHeartbeatRequest', (_message.Message,), {'DESCRIPTOR': _WORKERHEARTBEATREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerHeartbeatRequest)
WorkerHeartbeatResponse = _reflection.GeneratedProtocolMessageType('WorkerHeartbeatResponse', (_message.Message,), {'DESCRIPTOR': _WORKERHEARTBEATRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerHeartbeatResponse)
WorkerUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkerUpdateRequest', (_message.Message,), {'DESCRIPTOR': _WORKERUPDATEREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerUpdateRequest)
WorkerUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkerUpdateResponse', (_message.Message,), {'DESCRIPTOR': _WORKERUPDATERESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerUpdateResponse)
GetDatasetDefRequest = _reflection.GeneratedProtocolMessageType('GetDatasetDefRequest', (_message.Message,), {'DESCRIPTOR': _GETDATASETDEFREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetDatasetDefRequest)
GetDatasetDefResponse = _reflection.GeneratedProtocolMessageType('GetDatasetDefResponse', (_message.Message,), {'DESCRIPTOR': _GETDATASETDEFRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetDatasetDefResponse)
GetSplitRequest = _reflection.GeneratedProtocolMessageType('GetSplitRequest', (_message.Message,), {'DESCRIPTOR': _GETSPLITREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetSplitRequest)
GetSplitResponse = _reflection.GeneratedProtocolMessageType('GetSplitResponse', (_message.Message,), {'DESCRIPTOR': _GETSPLITRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetSplitResponse)
GetVersionRequest = _reflection.GeneratedProtocolMessageType('GetVersionRequest', (_message.Message,), {'DESCRIPTOR': _GETVERSIONREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetVersionRequest)
GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), {'DESCRIPTOR': _GETVERSIONRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetVersionResponse)
GetOrRegisterDatasetRequest = _reflection.GeneratedProtocolMessageType('GetOrRegisterDatasetRequest', (_message.Message,), {'DESCRIPTOR': _GETORREGISTERDATASETREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrRegisterDatasetRequest)
GetOrRegisterDatasetResponse = _reflection.GeneratedProtocolMessageType('GetOrRegisterDatasetResponse', (_message.Message,), {'DESCRIPTOR': _GETORREGISTERDATASETRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrRegisterDatasetResponse)
JobKey = _reflection.GeneratedProtocolMessageType('JobKey', (_message.Message,), {'DESCRIPTOR': _JOBKEY, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(JobKey)
GetOrCreateJobRequest = _reflection.GeneratedProtocolMessageType('GetOrCreateJobRequest', (_message.Message,), {'DESCRIPTOR': _GETORCREATEJOBREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrCreateJobRequest)
GetOrCreateJobResponse = _reflection.GeneratedProtocolMessageType('GetOrCreateJobResponse', (_message.Message,), {'DESCRIPTOR': _GETORCREATEJOBRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrCreateJobResponse)
MaybeRemoveTaskRequest = _reflection.GeneratedProtocolMessageType('MaybeRemoveTaskRequest', (_message.Message,), {'DESCRIPTOR': _MAYBEREMOVETASKREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(MaybeRemoveTaskRequest)
MaybeRemoveTaskResponse = _reflection.GeneratedProtocolMessageType('MaybeRemoveTaskResponse', (_message.Message,), {'DESCRIPTOR': _MAYBEREMOVETASKRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(MaybeRemoveTaskResponse)
ReleaseJobClientRequest = _reflection.GeneratedProtocolMessageType('ReleaseJobClientRequest', (_message.Message,), {'DESCRIPTOR': _RELEASEJOBCLIENTREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ReleaseJobClientRequest)
ReleaseJobClientResponse = _reflection.GeneratedProtocolMessageType('ReleaseJobClientResponse', (_message.Message,), {'DESCRIPTOR': _RELEASEJOBCLIENTRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ReleaseJobClientResponse)
ClientHeartbeatRequest = _reflection.GeneratedProtocolMessageType('ClientHeartbeatRequest', (_message.Message,), {'DESCRIPTOR': _CLIENTHEARTBEATREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ClientHeartbeatRequest)
ClientHeartbeatResponse = _reflection.GeneratedProtocolMessageType('ClientHeartbeatResponse', (_message.Message,), {'DESCRIPTOR': _CLIENTHEARTBEATRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ClientHeartbeatResponse)
WorkerInfo = _reflection.GeneratedProtocolMessageType('WorkerInfo', (_message.Message,), {'DESCRIPTOR': _WORKERINFO, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerInfo)
GetWorkersRequest = _reflection.GeneratedProtocolMessageType('GetWorkersRequest', (_message.Message,), {'DESCRIPTOR': _GETWORKERSREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetWorkersRequest)
GetWorkersResponse = _reflection.GeneratedProtocolMessageType('GetWorkersResponse', (_message.Message,), {'DESCRIPTOR': _GETWORKERSRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetWorkersResponse)
_DISPATCHERSERVICE = _descriptor.ServiceDescriptor(name='DispatcherService', full_name='tensorflow.data.DispatcherService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=1943, serialized_end=3033, methods=[_descriptor.MethodDescriptor(name='WorkerHeartbeat', full_name='tensorflow.data.DispatcherService.WorkerHeartbeat', index=0, containing_service=None, input_type=_WORKERHEARTBEATREQUEST, output_type=_WORKERHEARTBEATRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='WorkerUpdate', full_name='tensorflow.data.DispatcherService.WorkerUpdate', index=1, containing_service=None, input_type=_WORKERUPDATEREQUEST, output_type=_WORKERUPDATERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetDatasetDef', full_name='tensorflow.data.DispatcherService.GetDatasetDef', index=2, containing_service=None, input_type=_GETDATASETDEFREQUEST, output_type=_GETDATASETDEFRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetSplit', full_name='tensorflow.data.DispatcherService.GetSplit', index=3, containing_service=None, input_type=_GETSPLITREQUEST, output_type=_GETSPLITRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetVersion', full_name='tensorflow.data.DispatcherService.GetVersion', index=4, containing_service=None, input_type=_GETVERSIONREQUEST, output_type=_GETVERSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetOrRegisterDataset', full_name='tensorflow.data.DispatcherService.GetOrRegisterDataset', index=5, containing_service=None, input_type=_GETORREGISTERDATASETREQUEST, output_type=_GETORREGISTERDATASETRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetOrCreateJob', full_name='tensorflow.data.DispatcherService.GetOrCreateJob', index=6, containing_service=None, input_type=_GETORCREATEJOBREQUEST, output_type=_GETORCREATEJOBRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='MaybeRemoveTask', full_name='tensorflow.data.DispatcherService.MaybeRemoveTask', index=7, containing_service=None, input_type=_MAYBEREMOVETASKREQUEST, output_type=_MAYBEREMOVETASKRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ReleaseJobClient', full_name='tensorflow.data.DispatcherService.ReleaseJobClient', index=8, containing_service=None, input_type=_RELEASEJOBCLIENTREQUEST, output_type=_RELEASEJOBCLIENTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ClientHeartbeat', full_name='tensorflow.data.DispatcherService.ClientHeartbeat', index=9, containing_service=None, input_type=_CLIENTHEARTBEATREQUEST, output_type=_CLIENTHEARTBEATRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetWorkers', full_name='tensorflow.data.DispatcherService.GetWorkers', index=10, containing_service=None, input_type=_GETWORKERSREQUEST, output_type=_GETWORKERSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_DISPATCHERSERVICE)
DESCRIPTOR.services_by_name['DispatcherService'] = _DISPATCHERSERVICE
