
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/data/service/common.proto', package='tensorflow.data', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/data/service/common.proto\x12\x0ftensorflow.data\x1a%tensorflow/core/framework/graph.proto"1\n\nDatasetDef\x12#\n\x05graph\x18\x01 \x01(\x0b2\x14.tensorflow.GraphDef"\xb2\x02\n\x07TaskDef\x122\n\x0bdataset_def\x18\x01 \x01(\x0b2\x1b.tensorflow.data.DatasetDefH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12\x12\n\ndataset_id\x18\x03 \x01(\x03\x12\x0f\n\x07task_id\x18\x04 \x01(\x03\x12\x0e\n\x06job_id\x18\x05 \x01(\x03\x12\x1b\n\x13num_split_providers\x18\t \x01(\x03\x12\x16\n\x0eworker_address\x18\x08 \x01(\t\x12;\n\x0fprocessing_mode\x18\x06 \x01(\x0e2".tensorflow.data.ProcessingModeDef\x12\x17\n\rnum_consumers\x18\x07 \x01(\x03H\x01B\t\n\x07datasetB\x18\n\x16optional_num_consumers"u\n\x08TaskInfo\x12\x16\n\x0eworker_address\x18\x01 \x01(\t\x12\x18\n\x10transfer_address\x18\x04 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x03\x12\x0e\n\x06job_id\x18\x03 \x01(\x03\x12\x16\n\x0estarting_round\x18\x05 \x01(\x03*L\n\x11ProcessingModeDef\x12\x0b\n\x07INVALID\x10\x00\x12\x13\n\x0fPARALLEL_EPOCHS\x10\x01\x12\x15\n\x11DISTRIBUTED_EPOCH\x10\x02b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR])
_PROCESSINGMODEDEF = _descriptor.EnumDescriptor(name='ProcessingModeDef', full_name='tensorflow.data.ProcessingModeDef', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='PARALLEL_EPOCHS', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DISTRIBUTED_EPOCH', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=580, serialized_end=656)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODEDEF)
ProcessingModeDef = enum_type_wrapper.EnumTypeWrapper(_PROCESSINGMODEDEF)
INVALID = 0
PARALLEL_EPOCHS = 1
DISTRIBUTED_EPOCH = 2
_DATASETDEF = _descriptor.Descriptor(name='DatasetDef', full_name='tensorflow.data.DatasetDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph', full_name='tensorflow.data.DatasetDef.graph', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=101, serialized_end=150)
_TASKDEF = _descriptor.Descriptor(name='TaskDef', full_name='tensorflow.data.TaskDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_def', full_name='tensorflow.data.TaskDef.dataset_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='path', full_name='tensorflow.data.TaskDef.path', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.TaskDef.dataset_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.TaskDef.task_id', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_id', full_name='tensorflow.data.TaskDef.job_id', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_split_providers', full_name='tensorflow.data.TaskDef.num_split_providers', index=5, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.TaskDef.worker_address', index=6, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='processing_mode', full_name='tensorflow.data.TaskDef.processing_mode', index=7, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_consumers', full_name='tensorflow.data.TaskDef.num_consumers', index=8, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='dataset', full_name='tensorflow.data.TaskDef.dataset', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_num_consumers', full_name='tensorflow.data.TaskDef.optional_num_consumers', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=153, serialized_end=459)
_TASKINFO = _descriptor.Descriptor(name='TaskInfo', full_name='tensorflow.data.TaskInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.TaskInfo.worker_address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_address', full_name='tensorflow.data.TaskInfo.transfer_address', index=1, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.TaskInfo.task_id', index=2, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_id', full_name='tensorflow.data.TaskInfo.job_id', index=3, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='starting_round', full_name='tensorflow.data.TaskInfo.starting_round', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=461, serialized_end=578)
_DATASETDEF.fields_by_name['graph'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_TASKDEF.fields_by_name['dataset_def'].message_type = _DATASETDEF
_TASKDEF.fields_by_name['processing_mode'].enum_type = _PROCESSINGMODEDEF
_TASKDEF.oneofs_by_name['dataset'].fields.append(_TASKDEF.fields_by_name['dataset_def'])
_TASKDEF.fields_by_name['dataset_def'].containing_oneof = _TASKDEF.oneofs_by_name['dataset']
_TASKDEF.oneofs_by_name['dataset'].fields.append(_TASKDEF.fields_by_name['path'])
_TASKDEF.fields_by_name['path'].containing_oneof = _TASKDEF.oneofs_by_name['dataset']
_TASKDEF.oneofs_by_name['optional_num_consumers'].fields.append(_TASKDEF.fields_by_name['num_consumers'])
_TASKDEF.fields_by_name['num_consumers'].containing_oneof = _TASKDEF.oneofs_by_name['optional_num_consumers']
DESCRIPTOR.message_types_by_name['DatasetDef'] = _DATASETDEF
DESCRIPTOR.message_types_by_name['TaskDef'] = _TASKDEF
DESCRIPTOR.message_types_by_name['TaskInfo'] = _TASKINFO
DESCRIPTOR.enum_types_by_name['ProcessingModeDef'] = _PROCESSINGMODEDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DatasetDef = _reflection.GeneratedProtocolMessageType('DatasetDef', (_message.Message,), {'DESCRIPTOR': _DATASETDEF, '__module__': 'tensorflow.core.data.service.common_pb2'})
_sym_db.RegisterMessage(DatasetDef)
TaskDef = _reflection.GeneratedProtocolMessageType('TaskDef', (_message.Message,), {'DESCRIPTOR': _TASKDEF, '__module__': 'tensorflow.core.data.service.common_pb2'})
_sym_db.RegisterMessage(TaskDef)
TaskInfo = _reflection.GeneratedProtocolMessageType('TaskInfo', (_message.Message,), {'DESCRIPTOR': _TASKINFO, '__module__': 'tensorflow.core.data.service.common_pb2'})
_sym_db.RegisterMessage(TaskInfo)
