
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/input_pipeline.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/core/profiler/protobuf/input_pipeline.proto\x12\x13tensorflow.profiler\x1a\x19google/protobuf/any.proto\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto"\x80\x03\n\x12BottleneckAnalysis\x12\x15\n\rinput_percent\x18\x07 \x01(\x01\x12\x16\n\x0eoutput_percent\x18\x08 \x01(\x01\x12\x14\n\x0cidle_percent\x18\t \x01(\x01\x12\x17\n\x0fcompute_percent\x18\n \x01(\x01\x12\x1c\n\x14input_classification\x18\x01 \x01(\t\x12\x17\n\x0finput_statement\x18\x02 \x01(\t\x12$\n\x1ckernel_launch_classification\x18\x03 \x01(\t\x12\x1f\n\x17kernel_launch_statement\x18\x04 \x01(\t\x12 \n\x18all_other_classification\x18\x05 \x01(\t\x12\x1b\n\x13all_other_statement\x18\x06 \x01(\t\x12)\n!device_collectives_classification\x18\x0b \x01(\t\x12$\n\x1cdevice_collectives_statement\x18\x0c \x01(\t"\\\n\x0bStepSummary\x12\x0f\n\x07average\x18\x01 \x01(\x01\x12\x1a\n\x12standard_deviation\x18\x02 \x01(\x01\x12\x0f\n\x07minimum\x18\x03 \x01(\x01\x12\x0f\n\x07maximum\x18\x04 \x01(\x01"\xe0\x02\n\x15PerGenericStepDetails\x12\x13\n\x0bstep_number\x18\x01 \x01(\x05\x12\x11\n\tstep_name\x18\x0e \x01(\t\x12\x14\n\x0cstep_time_ms\x18\x02 \x01(\x01\x12\x17\n\x0funknown_time_ms\x18\x03 \x01(\x01\x12\x1a\n\x12host_wait_input_ms\x18\x0b \x01(\x01\x12\x19\n\x11host_to_device_ms\x18\x0c \x01(\x01\x12\x11\n\toutput_ms\x18\x05 \x01(\x01\x12\x19\n\x11device_compute_ms\x18\x06 \x01(\x01\x12\x1b\n\x13device_to_device_ms\x18\x07 \x01(\x01\x12\x1d\n\x15device_collectives_ms\x18\r \x01(\x01\x12\x17\n\x0fhost_compute_ms\x18\x08 \x01(\x01\x12\x17\n\x0fhost_prepare_ms\x18\t \x01(\x01\x12\x17\n\x0fhost_compile_ms\x18\n \x01(\x01J\x04\x08\x04\x10\x05"\xa5\x01\n\x12InputTimeBreakdown\x12\x1d\n\x15demanded_file_read_us\x18\x01 \x01(\x01\x12\x1d\n\x15advanced_file_read_us\x18\x02 \x01(\x01\x12\x18\n\x10preprocessing_us\x18\x03 \x01(\x01\x12\x12\n\nenqueue_us\x18\x04 \x01(\x01\x12#\n\x1bunclassified_non_enqueue_us\x18\x05 \x01(\x01"\xa6\x01\n\x0eInputOpDetails\x12\x0f\n\x07op_name\x18\x01 \x01(\t\x12\r\n\x05count\x18\x02 \x01(\x04\x12\x12\n\ntime_in_ms\x18\x03 \x01(\x01\x12\x17\n\x0ftime_in_percent\x18\x04 \x01(\x01\x12\x17\n\x0fself_time_in_ms\x18\x05 \x01(\x01\x12\x1c\n\x14self_time_in_percent\x18\x06 \x01(\x01\x12\x10\n\x08category\x18\x07 \x01(\t"\x84\x01\n#InputPipelineAnalysisRecommendation\x12\x0f\n\x07details\x18\x01 \x03(\t\x121\n\x13bottleneck_analysis\x18\x02 \x01(\x0b2\x14.google.protobuf.Any\x12\x19\n\x11summary_next_step\x18\x03 \x01(\t"\x85\x06\n\x18GenericStepTimeBreakdown\x12A\n\x17unknown_time_ms_summary\x18\x01 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12D\n\x1ahost_wait_input_ms_summary\x18\t \x01(\x0b2 .tensorflow.profiler.StepSummary\x12C\n\x19host_to_device_ms_summary\x18\n \x01(\x0b2 .tensorflow.profiler.StepSummary\x12:\n\x10input_ms_summary\x18\x0b \x01(\x0b2 .tensorflow.profiler.StepSummary\x12;\n\x11output_ms_summary\x18\x03 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12C\n\x19device_compute_ms_summary\x18\x04 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12E\n\x1bdevice_to_device_ms_summary\x18\x05 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12G\n\x1ddevice_collectives_ms_summary\x18\x0c \x01(\x0b2 .tensorflow.profiler.StepSummary\x12A\n\x17host_compute_ms_summary\x18\x06 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12A\n\x17host_prepare_ms_summary\x18\x07 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12A\n\x17host_compile_ms_summary\x18\x08 \x01(\x0b2 .tensorflow.profiler.StepSummaryJ\x04\x08\x02\x10\x03"\x8a\x05\n\x1bInputPipelineAnalysisResult\x12\x15\n\rhardware_type\x18\t \x01(\t\x12;\n\x11step_time_summary\x18\x02 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12?\n\x15input_percent_summary\x18\x03 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12\x15\n\rinput_percent\x18\x0b \x01(\x01\x12\x16\n\x0eoutput_percent\x18\r \x01(\x01\x12\x14\n\x0cidle_percent\x18\x0e \x01(\x01\x12\x17\n\x0fcompute_percent\x18\x0f \x01(\x01\x12*\n\x0cstep_details\x18\x04 \x03(\x0b2\x14.google.protobuf.Any\x12E\n\x14input_time_breakdown\x18\x05 \x01(\x0b2\'.tensorflow.profiler.InputTimeBreakdown\x12=\n\x10input_op_details\x18\x06 \x03(\x0b2#.tensorflow.profiler.InputOpDetails\x12P\n\x0erecommendation\x18\x07 \x01(\x0b28.tensorflow.profiler.InputPipelineAnalysisRecommendation\x121\n\x13step_time_breakdown\x18\x08 \x01(\x0b2\x14.google.protobuf.Any\x125\n\x0bdiagnostics\x18\x0c \x01(\x0b2 .tensorflow.profiler.DiagnosticsJ\x04\x08\x01\x10\x02J\x04\x08\n\x10\x0bb\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR])
_BOTTLENECKANALYSIS = _descriptor.Descriptor(name='BottleneckAnalysis', full_name='tensorflow.profiler.BottleneckAnalysis', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_percent', full_name='tensorflow.profiler.BottleneckAnalysis.input_percent', index=0, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_percent', full_name='tensorflow.profiler.BottleneckAnalysis.output_percent', index=1, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='idle_percent', full_name='tensorflow.profiler.BottleneckAnalysis.idle_percent', index=2, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_percent', full_name='tensorflow.profiler.BottleneckAnalysis.compute_percent', index=3, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_classification', full_name='tensorflow.profiler.BottleneckAnalysis.input_classification', index=4, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_statement', full_name='tensorflow.profiler.BottleneckAnalysis.input_statement', index=5, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_launch_classification', full_name='tensorflow.profiler.BottleneckAnalysis.kernel_launch_classification', index=6, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_launch_statement', full_name='tensorflow.profiler.BottleneckAnalysis.kernel_launch_statement', index=7, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_classification', full_name='tensorflow.profiler.BottleneckAnalysis.all_other_classification', index=8, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_statement', full_name='tensorflow.profiler.BottleneckAnalysis.all_other_statement', index=9, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_classification', full_name='tensorflow.profiler.BottleneckAnalysis.device_collectives_classification', index=10, number=11, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_statement', full_name='tensorflow.profiler.BottleneckAnalysis.device_collectives_statement', index=11, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=160, serialized_end=544)
_STEPSUMMARY = _descriptor.Descriptor(name='StepSummary', full_name='tensorflow.profiler.StepSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='average', full_name='tensorflow.profiler.StepSummary.average', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='standard_deviation', full_name='tensorflow.profiler.StepSummary.standard_deviation', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minimum', full_name='tensorflow.profiler.StepSummary.minimum', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='maximum', full_name='tensorflow.profiler.StepSummary.maximum', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=546, serialized_end=638)
_PERGENERICSTEPDETAILS = _descriptor.Descriptor(name='PerGenericStepDetails', full_name='tensorflow.profiler.PerGenericStepDetails', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_number', full_name='tensorflow.profiler.PerGenericStepDetails.step_number', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_name', full_name='tensorflow.profiler.PerGenericStepDetails.step_name', index=1, number=14, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_time_ms', full_name='tensorflow.profiler.PerGenericStepDetails.step_time_ms', index=2, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unknown_time_ms', full_name='tensorflow.profiler.PerGenericStepDetails.unknown_time_ms', index=3, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_wait_input_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_wait_input_ms', index=4, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_to_device_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_to_device_ms', index=5, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_ms', full_name='tensorflow.profiler.PerGenericStepDetails.output_ms', index=6, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_ms', full_name='tensorflow.profiler.PerGenericStepDetails.device_compute_ms', index=7, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_to_device_ms', full_name='tensorflow.profiler.PerGenericStepDetails.device_to_device_ms', index=8, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_ms', full_name='tensorflow.profiler.PerGenericStepDetails.device_collectives_ms', index=9, number=13, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_compute_ms', index=10, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_prepare_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_prepare_ms', index=11, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compile_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_compile_ms', index=12, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=641, serialized_end=993)
_INPUTTIMEBREAKDOWN = _descriptor.Descriptor(name='InputTimeBreakdown', full_name='tensorflow.profiler.InputTimeBreakdown', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='demanded_file_read_us', full_name='tensorflow.profiler.InputTimeBreakdown.demanded_file_read_us', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='advanced_file_read_us', full_name='tensorflow.profiler.InputTimeBreakdown.advanced_file_read_us', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='preprocessing_us', full_name='tensorflow.profiler.InputTimeBreakdown.preprocessing_us', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enqueue_us', full_name='tensorflow.profiler.InputTimeBreakdown.enqueue_us', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unclassified_non_enqueue_us', full_name='tensorflow.profiler.InputTimeBreakdown.unclassified_non_enqueue_us', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=996, serialized_end=1161)
_INPUTOPDETAILS = _descriptor.Descriptor(name='InputOpDetails', full_name='tensorflow.profiler.InputOpDetails', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_name', full_name='tensorflow.profiler.InputOpDetails.op_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='count', full_name='tensorflow.profiler.InputOpDetails.count', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='time_in_ms', full_name='tensorflow.profiler.InputOpDetails.time_in_ms', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='time_in_percent', full_name='tensorflow.profiler.InputOpDetails.time_in_percent', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_in_ms', full_name='tensorflow.profiler.InputOpDetails.self_time_in_ms', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_in_percent', full_name='tensorflow.profiler.InputOpDetails.self_time_in_percent', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.InputOpDetails.category', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1164, serialized_end=1330)
_INPUTPIPELINEANALYSISRECOMMENDATION = _descriptor.Descriptor(name='InputPipelineAnalysisRecommendation', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='details', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation.details', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bottleneck_analysis', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation.bottleneck_analysis', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary_next_step', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation.summary_next_step', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1333, serialized_end=1465)
_GENERICSTEPTIMEBREAKDOWN = _descriptor.Descriptor(name='GenericStepTimeBreakdown', full_name='tensorflow.profiler.GenericStepTimeBreakdown', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='unknown_time_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.unknown_time_ms_summary', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_wait_input_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_wait_input_ms_summary', index=1, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_to_device_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_to_device_ms_summary', index=2, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.input_ms_summary', index=3, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.output_ms_summary', index=4, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.device_compute_ms_summary', index=5, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_to_device_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.device_to_device_ms_summary', index=6, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.device_collectives_ms_summary', index=7, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_compute_ms_summary', index=8, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_prepare_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_prepare_ms_summary', index=9, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compile_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_compile_ms_summary', index=10, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1468, serialized_end=2241)
_INPUTPIPELINEANALYSISRESULT = _descriptor.Descriptor(name='InputPipelineAnalysisResult', full_name='tensorflow.profiler.InputPipelineAnalysisResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hardware_type', full_name='tensorflow.profiler.InputPipelineAnalysisResult.hardware_type', index=0, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_time_summary', full_name='tensorflow.profiler.InputPipelineAnalysisResult.step_time_summary', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_percent_summary', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_percent_summary', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_percent', index=3, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.output_percent', index=4, number=13, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='idle_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.idle_percent', index=5, number=14, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.compute_percent', index=6, number=15, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_details', full_name='tensorflow.profiler.InputPipelineAnalysisResult.step_details', index=7, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_time_breakdown', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_time_breakdown', index=8, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_op_details', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_op_details', index=9, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recommendation', full_name='tensorflow.profiler.InputPipelineAnalysisResult.recommendation', index=10, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_time_breakdown', full_name='tensorflow.profiler.InputPipelineAnalysisResult.step_time_breakdown', index=11, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.InputPipelineAnalysisResult.diagnostics', index=12, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2244, serialized_end=2894)
_INPUTPIPELINEANALYSISRECOMMENDATION.fields_by_name['bottleneck_analysis'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['unknown_time_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_wait_input_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_to_device_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['input_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['output_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['device_compute_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['device_to_device_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['device_collectives_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_compute_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_prepare_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_compile_ms_summary'].message_type = _STEPSUMMARY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['step_time_summary'].message_type = _STEPSUMMARY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['input_percent_summary'].message_type = _STEPSUMMARY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['step_details'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['input_time_breakdown'].message_type = _INPUTTIMEBREAKDOWN
_INPUTPIPELINEANALYSISRESULT.fields_by_name['input_op_details'].message_type = _INPUTOPDETAILS
_INPUTPIPELINEANALYSISRESULT.fields_by_name['recommendation'].message_type = _INPUTPIPELINEANALYSISRECOMMENDATION
_INPUTPIPELINEANALYSISRESULT.fields_by_name['step_time_breakdown'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
DESCRIPTOR.message_types_by_name['BottleneckAnalysis'] = _BOTTLENECKANALYSIS
DESCRIPTOR.message_types_by_name['StepSummary'] = _STEPSUMMARY
DESCRIPTOR.message_types_by_name['PerGenericStepDetails'] = _PERGENERICSTEPDETAILS
DESCRIPTOR.message_types_by_name['InputTimeBreakdown'] = _INPUTTIMEBREAKDOWN
DESCRIPTOR.message_types_by_name['InputOpDetails'] = _INPUTOPDETAILS
DESCRIPTOR.message_types_by_name['InputPipelineAnalysisRecommendation'] = _INPUTPIPELINEANALYSISRECOMMENDATION
DESCRIPTOR.message_types_by_name['GenericStepTimeBreakdown'] = _GENERICSTEPTIMEBREAKDOWN
DESCRIPTOR.message_types_by_name['InputPipelineAnalysisResult'] = _INPUTPIPELINEANALYSISRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
BottleneckAnalysis = _reflection.GeneratedProtocolMessageType('BottleneckAnalysis', (_message.Message,), {'DESCRIPTOR': _BOTTLENECKANALYSIS, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(BottleneckAnalysis)
StepSummary = _reflection.GeneratedProtocolMessageType('StepSummary', (_message.Message,), {'DESCRIPTOR': _STEPSUMMARY, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(StepSummary)
PerGenericStepDetails = _reflection.GeneratedProtocolMessageType('PerGenericStepDetails', (_message.Message,), {'DESCRIPTOR': _PERGENERICSTEPDETAILS, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(PerGenericStepDetails)
InputTimeBreakdown = _reflection.GeneratedProtocolMessageType('InputTimeBreakdown', (_message.Message,), {'DESCRIPTOR': _INPUTTIMEBREAKDOWN, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputTimeBreakdown)
InputOpDetails = _reflection.GeneratedProtocolMessageType('InputOpDetails', (_message.Message,), {'DESCRIPTOR': _INPUTOPDETAILS, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputOpDetails)
InputPipelineAnalysisRecommendation = _reflection.GeneratedProtocolMessageType('InputPipelineAnalysisRecommendation', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINEANALYSISRECOMMENDATION, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputPipelineAnalysisRecommendation)
GenericStepTimeBreakdown = _reflection.GeneratedProtocolMessageType('GenericStepTimeBreakdown', (_message.Message,), {'DESCRIPTOR': _GENERICSTEPTIMEBREAKDOWN, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(GenericStepTimeBreakdown)
InputPipelineAnalysisResult = _reflection.GeneratedProtocolMessageType('InputPipelineAnalysisResult', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINEANALYSISRESULT, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputPipelineAnalysisResult)
