
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/tf_data_stats.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/core/profiler/protobuf/tf_data_stats.proto\x12\x13tensorflow.profiler"\x84\x01\n\x0cIteratorStat\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x15\n\rstart_time_ps\x18\x02 \x01(\x03\x12\x13\n\x0bduration_ps\x18\x03 \x01(\x03\x12\x14\n\x0cself_time_ps\x18\x04 \x01(\x03\x12\x13\n\x0bis_blocking\x18\x05 \x01(\x08\x12\x11\n\tnum_calls\x18\x06 \x01(\x03"\xd6\x01\n\x10IteratorMetadata\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\tparent_id\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tlong_name\x18\x06 \x01(\t\x12\x10\n\x08is_async\x18\x04 \x01(\x08\x12A\n\x06params\x18\x05 \x03(\x0b21.tensorflow.profiler.IteratorMetadata.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"\x87\x02\n\x11InputPipelineStat\x12\x1e\n\x16bottleneck_iterator_id\x18\x02 \x01(\x03\x12&\n\x1ebottleneck_iterator_latency_ps\x18\x03 \x01(\x03\x12Q\n\x0eiterator_stats\x18\x01 \x03(\x0b29.tensorflow.profiler.InputPipelineStat.IteratorStatsEntry\x1aW\n\x12IteratorStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x120\n\x05value\x18\x02 \x01(\x0b2!.tensorflow.profiler.IteratorStat:\x028\x01"\xae\x01\n\x15InputPipelineMetadata\x12\n\n\x02id\x18\x01 \x01(\x03\x12J\n\x04type\x18\x02 \x01(\x0e2<.tensorflow.profiler.InputPipelineMetadata.InputPipelineType\x12\x0c\n\x04name\x18\x04 \x01(\t")\n\x11InputPipelineType\x12\x08\n\x04HOST\x10\x00\x12\n\n\x06DEVICE\x10\x01J\x04\x08\x03\x10\x04"\xe9\x01\n\x12InputPipelineStats\x12<\n\x08metadata\x18\x01 \x01(\x0b2*.tensorflow.profiler.InputPipelineMetadata\x12\x16\n\x0eavg_latency_ps\x18\x03 \x01(\x03\x12\x16\n\x0emin_latency_ps\x18\x04 \x01(\x03\x12\x16\n\x0emax_latency_ps\x18\x05 \x01(\x03\x12\x16\n\x0enum_slow_calls\x18\x06 \x01(\x03\x125\n\x05stats\x18\x02 \x03(\x0b2&.tensorflow.profiler.InputPipelineStat"\xef\x02\n\x0bTfDataStats\x12Q\n\x11iterator_metadata\x18\x02 \x03(\x0b26.tensorflow.profiler.TfDataStats.IteratorMetadataEntry\x12M\n\x0finput_pipelines\x18\x01 \x03(\x0b24.tensorflow.profiler.TfDataStats.InputPipelinesEntry\x1a^\n\x15IteratorMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x124\n\x05value\x18\x02 \x01(\x0b2%.tensorflow.profiler.IteratorMetadata:\x028\x01\x1a^\n\x13InputPipelinesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x126\n\x05value\x18\x02 \x01(\x0b2\'.tensorflow.profiler.InputPipelineStats:\x028\x01"\xbc\x01\n\x18TfDataBottleneckAnalysis\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x16\n\x0einput_pipeline\x18\x02 \x01(\t\x12\x16\n\x0emax_latency_ps\x18\x03 \x01(\x03\x12\x15\n\riterator_name\x18\x04 \x01(\t\x12\x1a\n\x12iterator_long_name\x18\x05 \x01(\t\x12\x1b\n\x13iterator_latency_ps\x18\x07 \x01(\x03\x12\x12\n\nsuggestion\x18\x06 \x01(\t"\xb2\x02\n\x13CombinedTfDataStats\x12\x16\n\x0eis_input_bound\x18\x03 \x01(\x08\x12\x0f\n\x07summary\x18\x04 \x01(\t\x12J\n\x13bottleneck_analysis\x18\x01 \x03(\x0b2-.tensorflow.profiler.TfDataBottleneckAnalysis\x12P\n\rtf_data_stats\x18\x02 \x03(\x0b29.tensorflow.profiler.CombinedTfDataStats.TfDataStatsEntry\x1aT\n\x10TfDataStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b2 .tensorflow.profiler.TfDataStats:\x028\x01b\x06proto3')
_INPUTPIPELINEMETADATA_INPUTPIPELINETYPE = _descriptor.EnumDescriptor(name='InputPipelineType', full_name='tensorflow.profiler.InputPipelineMetadata.InputPipelineType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='HOST', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DEVICE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=824, serialized_end=865)
_sym_db.RegisterEnumDescriptor(_INPUTPIPELINEMETADATA_INPUTPIPELINETYPE)
_ITERATORSTAT = _descriptor.Descriptor(name='IteratorStat', full_name='tensorflow.profiler.IteratorStat', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.IteratorStat.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time_ps', full_name='tensorflow.profiler.IteratorStat.start_time_ps', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ps', full_name='tensorflow.profiler.IteratorStat.duration_ps', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_ps', full_name='tensorflow.profiler.IteratorStat.self_time_ps', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_blocking', full_name='tensorflow.profiler.IteratorStat.is_blocking', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_calls', full_name='tensorflow.profiler.IteratorStat.num_calls', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=79, serialized_end=211)
_ITERATORMETADATA_PARAMSENTRY = _descriptor.Descriptor(name='ParamsEntry', full_name='tensorflow.profiler.IteratorMetadata.ParamsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.IteratorMetadata.ParamsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.IteratorMetadata.ParamsEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=383, serialized_end=428)
_ITERATORMETADATA = _descriptor.Descriptor(name='IteratorMetadata', full_name='tensorflow.profiler.IteratorMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.IteratorMetadata.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parent_id', full_name='tensorflow.profiler.IteratorMetadata.parent_id', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.IteratorMetadata.name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='long_name', full_name='tensorflow.profiler.IteratorMetadata.long_name', index=3, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_async', full_name='tensorflow.profiler.IteratorMetadata.is_async', index=4, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='params', full_name='tensorflow.profiler.IteratorMetadata.params', index=5, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_ITERATORMETADATA_PARAMSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=214, serialized_end=428)
_INPUTPIPELINESTAT_ITERATORSTATSENTRY = _descriptor.Descriptor(name='IteratorStatsEntry', full_name='tensorflow.profiler.InputPipelineStat.IteratorStatsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.InputPipelineStat.IteratorStatsEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.InputPipelineStat.IteratorStatsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=607, serialized_end=694)
_INPUTPIPELINESTAT = _descriptor.Descriptor(name='InputPipelineStat', full_name='tensorflow.profiler.InputPipelineStat', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bottleneck_iterator_id', full_name='tensorflow.profiler.InputPipelineStat.bottleneck_iterator_id', index=0, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bottleneck_iterator_latency_ps', full_name='tensorflow.profiler.InputPipelineStat.bottleneck_iterator_latency_ps', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='iterator_stats', full_name='tensorflow.profiler.InputPipelineStat.iterator_stats', index=2, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_INPUTPIPELINESTAT_ITERATORSTATSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=431, serialized_end=694)
_INPUTPIPELINEMETADATA = _descriptor.Descriptor(name='InputPipelineMetadata', full_name='tensorflow.profiler.InputPipelineMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.InputPipelineMetadata.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.profiler.InputPipelineMetadata.type', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.InputPipelineMetadata.name', index=2, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_INPUTPIPELINEMETADATA_INPUTPIPELINETYPE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=697, serialized_end=871)
_INPUTPIPELINESTATS = _descriptor.Descriptor(name='InputPipelineStats', full_name='tensorflow.profiler.InputPipelineStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.profiler.InputPipelineStats.metadata', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='avg_latency_ps', full_name='tensorflow.profiler.InputPipelineStats.avg_latency_ps', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='min_latency_ps', full_name='tensorflow.profiler.InputPipelineStats.min_latency_ps', index=2, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_latency_ps', full_name='tensorflow.profiler.InputPipelineStats.max_latency_ps', index=3, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_slow_calls', full_name='tensorflow.profiler.InputPipelineStats.num_slow_calls', index=4, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stats', full_name='tensorflow.profiler.InputPipelineStats.stats', index=5, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=874, serialized_end=1107)
_TFDATASTATS_ITERATORMETADATAENTRY = _descriptor.Descriptor(name='IteratorMetadataEntry', full_name='tensorflow.profiler.TfDataStats.IteratorMetadataEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.TfDataStats.IteratorMetadataEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.TfDataStats.IteratorMetadataEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1287, serialized_end=1381)
_TFDATASTATS_INPUTPIPELINESENTRY = _descriptor.Descriptor(name='InputPipelinesEntry', full_name='tensorflow.profiler.TfDataStats.InputPipelinesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.TfDataStats.InputPipelinesEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.TfDataStats.InputPipelinesEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1383, serialized_end=1477)
_TFDATASTATS = _descriptor.Descriptor(name='TfDataStats', full_name='tensorflow.profiler.TfDataStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='iterator_metadata', full_name='tensorflow.profiler.TfDataStats.iterator_metadata', index=0, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_pipelines', full_name='tensorflow.profiler.TfDataStats.input_pipelines', index=1, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TFDATASTATS_ITERATORMETADATAENTRY, _TFDATASTATS_INPUTPIPELINESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1110, serialized_end=1477)
_TFDATABOTTLENECKANALYSIS = _descriptor.Descriptor(name='TfDataBottleneckAnalysis', full_name='tensorflow.profiler.TfDataBottleneckAnalysis', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.host', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_pipeline', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.input_pipeline', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_latency_ps', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.max_latency_ps', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='iterator_name', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.iterator_name', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='iterator_long_name', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.iterator_long_name', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='iterator_latency_ps', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.iterator_latency_ps', index=5, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='suggestion', full_name='tensorflow.profiler.TfDataBottleneckAnalysis.suggestion', index=6, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1480, serialized_end=1668)
_COMBINEDTFDATASTATS_TFDATASTATSENTRY = _descriptor.Descriptor(name='TfDataStatsEntry', full_name='tensorflow.profiler.CombinedTfDataStats.TfDataStatsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.CombinedTfDataStats.TfDataStatsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.CombinedTfDataStats.TfDataStatsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1893, serialized_end=1977)
_COMBINEDTFDATASTATS = _descriptor.Descriptor(name='CombinedTfDataStats', full_name='tensorflow.profiler.CombinedTfDataStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='is_input_bound', full_name='tensorflow.profiler.CombinedTfDataStats.is_input_bound', index=0, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary', full_name='tensorflow.profiler.CombinedTfDataStats.summary', index=1, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bottleneck_analysis', full_name='tensorflow.profiler.CombinedTfDataStats.bottleneck_analysis', index=2, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_data_stats', full_name='tensorflow.profiler.CombinedTfDataStats.tf_data_stats', index=3, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_COMBINEDTFDATASTATS_TFDATASTATSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1671, serialized_end=1977)
_ITERATORMETADATA_PARAMSENTRY.containing_type = _ITERATORMETADATA
_ITERATORMETADATA.fields_by_name['params'].message_type = _ITERATORMETADATA_PARAMSENTRY
_INPUTPIPELINESTAT_ITERATORSTATSENTRY.fields_by_name['value'].message_type = _ITERATORSTAT
_INPUTPIPELINESTAT_ITERATORSTATSENTRY.containing_type = _INPUTPIPELINESTAT
_INPUTPIPELINESTAT.fields_by_name['iterator_stats'].message_type = _INPUTPIPELINESTAT_ITERATORSTATSENTRY
_INPUTPIPELINEMETADATA.fields_by_name['type'].enum_type = _INPUTPIPELINEMETADATA_INPUTPIPELINETYPE
_INPUTPIPELINEMETADATA_INPUTPIPELINETYPE.containing_type = _INPUTPIPELINEMETADATA
_INPUTPIPELINESTATS.fields_by_name['metadata'].message_type = _INPUTPIPELINEMETADATA
_INPUTPIPELINESTATS.fields_by_name['stats'].message_type = _INPUTPIPELINESTAT
_TFDATASTATS_ITERATORMETADATAENTRY.fields_by_name['value'].message_type = _ITERATORMETADATA
_TFDATASTATS_ITERATORMETADATAENTRY.containing_type = _TFDATASTATS
_TFDATASTATS_INPUTPIPELINESENTRY.fields_by_name['value'].message_type = _INPUTPIPELINESTATS
_TFDATASTATS_INPUTPIPELINESENTRY.containing_type = _TFDATASTATS
_TFDATASTATS.fields_by_name['iterator_metadata'].message_type = _TFDATASTATS_ITERATORMETADATAENTRY
_TFDATASTATS.fields_by_name['input_pipelines'].message_type = _TFDATASTATS_INPUTPIPELINESENTRY
_COMBINEDTFDATASTATS_TFDATASTATSENTRY.fields_by_name['value'].message_type = _TFDATASTATS
_COMBINEDTFDATASTATS_TFDATASTATSENTRY.containing_type = _COMBINEDTFDATASTATS
_COMBINEDTFDATASTATS.fields_by_name['bottleneck_analysis'].message_type = _TFDATABOTTLENECKANALYSIS
_COMBINEDTFDATASTATS.fields_by_name['tf_data_stats'].message_type = _COMBINEDTFDATASTATS_TFDATASTATSENTRY
DESCRIPTOR.message_types_by_name['IteratorStat'] = _ITERATORSTAT
DESCRIPTOR.message_types_by_name['IteratorMetadata'] = _ITERATORMETADATA
DESCRIPTOR.message_types_by_name['InputPipelineStat'] = _INPUTPIPELINESTAT
DESCRIPTOR.message_types_by_name['InputPipelineMetadata'] = _INPUTPIPELINEMETADATA
DESCRIPTOR.message_types_by_name['InputPipelineStats'] = _INPUTPIPELINESTATS
DESCRIPTOR.message_types_by_name['TfDataStats'] = _TFDATASTATS
DESCRIPTOR.message_types_by_name['TfDataBottleneckAnalysis'] = _TFDATABOTTLENECKANALYSIS
DESCRIPTOR.message_types_by_name['CombinedTfDataStats'] = _COMBINEDTFDATASTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
IteratorStat = _reflection.GeneratedProtocolMessageType('IteratorStat', (_message.Message,), {'DESCRIPTOR': _ITERATORSTAT, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(IteratorStat)
IteratorMetadata = _reflection.GeneratedProtocolMessageType('IteratorMetadata', (_message.Message,), {'ParamsEntry': _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {'DESCRIPTOR': _ITERATORMETADATA_PARAMSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'}), 'DESCRIPTOR': _ITERATORMETADATA, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(IteratorMetadata)
_sym_db.RegisterMessage(IteratorMetadata.ParamsEntry)
InputPipelineStat = _reflection.GeneratedProtocolMessageType('InputPipelineStat', (_message.Message,), {'IteratorStatsEntry': _reflection.GeneratedProtocolMessageType('IteratorStatsEntry', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINESTAT_ITERATORSTATSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'}), 'DESCRIPTOR': _INPUTPIPELINESTAT, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(InputPipelineStat)
_sym_db.RegisterMessage(InputPipelineStat.IteratorStatsEntry)
InputPipelineMetadata = _reflection.GeneratedProtocolMessageType('InputPipelineMetadata', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINEMETADATA, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(InputPipelineMetadata)
InputPipelineStats = _reflection.GeneratedProtocolMessageType('InputPipelineStats', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINESTATS, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(InputPipelineStats)
TfDataStats = _reflection.GeneratedProtocolMessageType('TfDataStats', (_message.Message,), {'IteratorMetadataEntry': _reflection.GeneratedProtocolMessageType('IteratorMetadataEntry', (_message.Message,), {'DESCRIPTOR': _TFDATASTATS_ITERATORMETADATAENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'}), 'InputPipelinesEntry': _reflection.GeneratedProtocolMessageType('InputPipelinesEntry', (_message.Message,), {'DESCRIPTOR': _TFDATASTATS_INPUTPIPELINESENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'}), 'DESCRIPTOR': _TFDATASTATS, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(TfDataStats)
_sym_db.RegisterMessage(TfDataStats.IteratorMetadataEntry)
_sym_db.RegisterMessage(TfDataStats.InputPipelinesEntry)
TfDataBottleneckAnalysis = _reflection.GeneratedProtocolMessageType('TfDataBottleneckAnalysis', (_message.Message,), {'DESCRIPTOR': _TFDATABOTTLENECKANALYSIS, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(TfDataBottleneckAnalysis)
CombinedTfDataStats = _reflection.GeneratedProtocolMessageType('CombinedTfDataStats', (_message.Message,), {'TfDataStatsEntry': _reflection.GeneratedProtocolMessageType('TfDataStatsEntry', (_message.Message,), {'DESCRIPTOR': _COMBINEDTFDATASTATS_TFDATASTATSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'}), 'DESCRIPTOR': _COMBINEDTFDATASTATS, '__module__': 'tensorflow.core.profiler.protobuf.tf_data_stats_pb2'})
_sym_db.RegisterMessage(CombinedTfDataStats)
_sym_db.RegisterMessage(CombinedTfDataStats.TfDataStatsEntry)
_ITERATORMETADATA_PARAMSENTRY._options = None
_INPUTPIPELINESTAT_ITERATORSTATSENTRY._options = None
_TFDATASTATS_ITERATORMETADATAENTRY._options = None
_TFDATASTATS_INPUTPIPELINESENTRY._options = None
_COMBINEDTFDATASTATS_TFDATASTATSENTRY._options = None
