
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from ......tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
from ......tensorflow.core.protobuf import autotuning_pb2 as tensorflow_dot_core_dot_protobuf_dot_autotuning__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/service/gpu/gpu_autotuning.proto', package='xla.gpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n8tensorflow/compiler/xla/service/gpu/gpu_autotuning.proto\x12\x07xla.gpu\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a&tensorflow/compiler/xla/xla_data.proto\x1a)tensorflow/core/protobuf/autotuning.proto"\x9f\x01\n\x12ConvInstructionLog\x12-\n\x0binstruction\x18\x01 \x01(\x0b2\x18.xla.HloInstructionProto\x12\'\n\x0eoperand_shapes\x18\x02 \x03(\x0b2\x0f.xla.ShapeProto\x12\x16\n\x0eresult_address\x18\x03 \x01(\x04\x12\x19\n\x11operand_addresses\x18\x04 \x03(\x04"5\n\x13DenylistedAlgorithm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x12\n\ntensor_ops\x18\x02 \x01(\x08"\xc4\x01\n\x16AlgorithmDenylistEntry\x12\x0b\n\x03hlo\x18\x01 \x01(\t\x12)\n\x02cc\x18\x02 \x01(\x0b2\x1d.tensorflow.ComputeCapability\x12/\n\rcudnn_version\x18\x03 \x01(\x0b2\x18.tensorflow.CudnnVersion\x12\x14\n\x0cblas_version\x18\x05 \x01(\t\x12+\n\x05algos\x18\x04 \x03(\x0b2\x1c.xla.gpu.DenylistedAlgorithm"E\n\x11AlgorithmDenylist\x120\n\x07entries\x18\x01 \x03(\x0b2\x1f.xla.gpu.AlgorithmDenylistEntryb\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_autotuning__pb2.DESCRIPTOR])
_CONVINSTRUCTIONLOG = _descriptor.Descriptor(name='ConvInstructionLog', full_name='xla.gpu.ConvInstructionLog', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='instruction', full_name='xla.gpu.ConvInstructionLog.instruction', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operand_shapes', full_name='xla.gpu.ConvInstructionLog.operand_shapes', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='result_address', full_name='xla.gpu.ConvInstructionLog.result_address', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operand_addresses', full_name='xla.gpu.ConvInstructionLog.operand_addresses', index=3, number=4, type=4, cpp_type=4, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=196, serialized_end=355)
_DENYLISTEDALGORITHM = _descriptor.Descriptor(name='DenylistedAlgorithm', full_name='xla.gpu.DenylistedAlgorithm', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='xla.gpu.DenylistedAlgorithm.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_ops', full_name='xla.gpu.DenylistedAlgorithm.tensor_ops', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=357, serialized_end=410)
_ALGORITHMDENYLISTENTRY = _descriptor.Descriptor(name='AlgorithmDenylistEntry', full_name='xla.gpu.AlgorithmDenylistEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hlo', full_name='xla.gpu.AlgorithmDenylistEntry.hlo', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cc', full_name='xla.gpu.AlgorithmDenylistEntry.cc', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cudnn_version', full_name='xla.gpu.AlgorithmDenylistEntry.cudnn_version', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='blas_version', full_name='xla.gpu.AlgorithmDenylistEntry.blas_version', index=3, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='algos', full_name='xla.gpu.AlgorithmDenylistEntry.algos', index=4, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=413, serialized_end=609)
_ALGORITHMDENYLIST = _descriptor.Descriptor(name='AlgorithmDenylist', full_name='xla.gpu.AlgorithmDenylist', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entries', full_name='xla.gpu.AlgorithmDenylist.entries', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=611, serialized_end=680)
_CONVINSTRUCTIONLOG.fields_by_name['instruction'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOINSTRUCTIONPROTO
_CONVINSTRUCTIONLOG.fields_by_name['operand_shapes'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_ALGORITHMDENYLISTENTRY.fields_by_name['cc'].message_type = tensorflow_dot_core_dot_protobuf_dot_autotuning__pb2._COMPUTECAPABILITY
_ALGORITHMDENYLISTENTRY.fields_by_name['cudnn_version'].message_type = tensorflow_dot_core_dot_protobuf_dot_autotuning__pb2._CUDNNVERSION
_ALGORITHMDENYLISTENTRY.fields_by_name['algos'].message_type = _DENYLISTEDALGORITHM
_ALGORITHMDENYLIST.fields_by_name['entries'].message_type = _ALGORITHMDENYLISTENTRY
DESCRIPTOR.message_types_by_name['ConvInstructionLog'] = _CONVINSTRUCTIONLOG
DESCRIPTOR.message_types_by_name['DenylistedAlgorithm'] = _DENYLISTEDALGORITHM
DESCRIPTOR.message_types_by_name['AlgorithmDenylistEntry'] = _ALGORITHMDENYLISTENTRY
DESCRIPTOR.message_types_by_name['AlgorithmDenylist'] = _ALGORITHMDENYLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ConvInstructionLog = _reflection.GeneratedProtocolMessageType('ConvInstructionLog', (_message.Message,), {'DESCRIPTOR': _CONVINSTRUCTIONLOG, '__module__': 'tensorflow.compiler.xla.service.gpu.gpu_autotuning_pb2'})
_sym_db.RegisterMessage(ConvInstructionLog)
DenylistedAlgorithm = _reflection.GeneratedProtocolMessageType('DenylistedAlgorithm', (_message.Message,), {'DESCRIPTOR': _DENYLISTEDALGORITHM, '__module__': 'tensorflow.compiler.xla.service.gpu.gpu_autotuning_pb2'})
_sym_db.RegisterMessage(DenylistedAlgorithm)
AlgorithmDenylistEntry = _reflection.GeneratedProtocolMessageType('AlgorithmDenylistEntry', (_message.Message,), {'DESCRIPTOR': _ALGORITHMDENYLISTENTRY, '__module__': 'tensorflow.compiler.xla.service.gpu.gpu_autotuning_pb2'})
_sym_db.RegisterMessage(AlgorithmDenylistEntry)
AlgorithmDenylist = _reflection.GeneratedProtocolMessageType('AlgorithmDenylist', (_message.Message,), {'DESCRIPTOR': _ALGORITHMDENYLIST, '__module__': 'tensorflow.compiler.xla.service.gpu.gpu_autotuning_pb2'})
_sym_db.RegisterMessage(AlgorithmDenylist)
