
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.tf2xla import host_compute_metadata_pb2 as tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2
from .....tensorflow.core.tpu.kernels import tpu_compilation_cache_common_pb2 as tensorflow_dot_core_dot_tpu_dot_kernels_dot_tpu__compilation__cache__common__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/tpu/kernels/tpu_compilation_cache.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n7tensorflow/core/tpu/kernels/tpu_compilation_cache.proto\x12\x0etensorflow.tpu\x1a6tensorflow/compiler/tf2xla/host_compute_metadata.proto\x1a>tensorflow/core/tpu/kernels/tpu_compilation_cache_common.proto"\xbe\x02\n\x1dGetTpuProgramResponseExternal\x12A\n\x05proto\x18\x01 \x01(\x0b22.tensorflow.tpu.GetTpuProgramResponseExternal.Blob\x12E\n\x15host_compute_metadata\x18\x02 \x01(\x0b2&.tensorflow.tf2xla.HostComputeMetadata\x12\x1c\n\x14may_modify_variables\x18\x03 \x01(\x08\x12M\n\x11compiler_metadata\x18\x04 \x01(\x0b22.tensorflow.tpu.GetTpuProgramResponseExternal.Blob\x12\x10\n\x08is_empty\x18\x05 \x01(\x08\x1a\x14\n\x04Blob\x12\x0c\n\x04data\x18\x01 \x01(\x0c2\x8c\x01\n"TpuCompilationCacheServiceExternal\x12f\n\rGetTpuProgram\x12$.tensorflow.tpu.GetTpuProgramRequest\x1a-.tensorflow.tpu.GetTpuProgramResponseExternal"\x00b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2.DESCRIPTOR, tensorflow_dot_core_dot_tpu_dot_kernels_dot_tpu__compilation__cache__common__pb2.DESCRIPTOR])
_GETTPUPROGRAMRESPONSEEXTERNAL_BLOB = _descriptor.Descriptor(name='Blob', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.Blob', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.Blob.data', index=0, number=1, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=494, serialized_end=514)
_GETTPUPROGRAMRESPONSEEXTERNAL = _descriptor.Descriptor(name='GetTpuProgramResponseExternal', full_name='tensorflow.tpu.GetTpuProgramResponseExternal', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='proto', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.proto', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_metadata', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.host_compute_metadata', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='may_modify_variables', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.may_modify_variables', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compiler_metadata', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.compiler_metadata', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_empty', full_name='tensorflow.tpu.GetTpuProgramResponseExternal.is_empty', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_GETTPUPROGRAMRESPONSEEXTERNAL_BLOB], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=196, serialized_end=514)
_GETTPUPROGRAMRESPONSEEXTERNAL_BLOB.containing_type = _GETTPUPROGRAMRESPONSEEXTERNAL
_GETTPUPROGRAMRESPONSEEXTERNAL.fields_by_name['proto'].message_type = _GETTPUPROGRAMRESPONSEEXTERNAL_BLOB
_GETTPUPROGRAMRESPONSEEXTERNAL.fields_by_name['host_compute_metadata'].message_type = tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2._HOSTCOMPUTEMETADATA
_GETTPUPROGRAMRESPONSEEXTERNAL.fields_by_name['compiler_metadata'].message_type = _GETTPUPROGRAMRESPONSEEXTERNAL_BLOB
DESCRIPTOR.message_types_by_name['GetTpuProgramResponseExternal'] = _GETTPUPROGRAMRESPONSEEXTERNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
GetTpuProgramResponseExternal = _reflection.GeneratedProtocolMessageType('GetTpuProgramResponseExternal', (_message.Message,), {'Blob': _reflection.GeneratedProtocolMessageType('Blob', (_message.Message,), {'DESCRIPTOR': _GETTPUPROGRAMRESPONSEEXTERNAL_BLOB, '__module__': 'tensorflow.core.tpu.kernels.tpu_compilation_cache_pb2'}), 'DESCRIPTOR': _GETTPUPROGRAMRESPONSEEXTERNAL, '__module__': 'tensorflow.core.tpu.kernels.tpu_compilation_cache_pb2'})
_sym_db.RegisterMessage(GetTpuProgramResponseExternal)
_sym_db.RegisterMessage(GetTpuProgramResponseExternal.Blob)
_TPUCOMPILATIONCACHESERVICEEXTERNAL = _descriptor.ServiceDescriptor(name='TpuCompilationCacheServiceExternal', full_name='tensorflow.tpu.TpuCompilationCacheServiceExternal', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=517, serialized_end=657, methods=[_descriptor.MethodDescriptor(name='GetTpuProgram', full_name='tensorflow.tpu.TpuCompilationCacheServiceExternal.GetTpuProgram', index=0, containing_service=None, input_type=tensorflow_dot_core_dot_tpu_dot_kernels_dot_tpu__compilation__cache__common__pb2._GETTPUPROGRAMREQUEST, output_type=_GETTPUPROGRAMRESPONSEEXTERNAL, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_TPUCOMPILATIONCACHESERVICEEXTERNAL)
DESCRIPTOR.services_by_name['TpuCompilationCacheServiceExternal'] = _TPUCOMPILATIONCACHESERVICEEXTERNAL
