
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/pod_stats.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n1tensorflow/core/profiler/protobuf/pod_stats.proto\x12\x13tensorflow.profiler\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto"/\n\x13StepBreakdownEvents\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t"\xd7\x01\n\x10PodStatsDatabase\x12=\n\x10pod_stats_record\x18\x01 \x03(\x0b2#.tensorflow.profiler.PodStatsRecord\x125\n\x0bdiagnostics\x18\x03 \x01(\x0b2 .tensorflow.profiler.Diagnostics\x12G\n\x15step_breakdown_events\x18\x04 \x03(\x0b2(.tensorflow.profiler.StepBreakdownEventsJ\x04\x08\x02\x10\x03"\xdb\x02\n\x0ePodStatsRecord\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x0f\n\x07chip_id\x18\x02 \x01(\x05\x12\x0f\n\x07node_id\x18\x03 \x01(\x05\x12\x10\n\x08step_num\x18\x04 \x01(\r\x12\x19\n\x11total_duration_us\x18\x05 \x01(\x01\x12S\n\x11step_breakdown_us\x18\x13 \x03(\x0b28.tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry\x12\x12\n\nbottleneck\x18\x0e \x01(\t\x1a6\n\x14StepBreakdownUsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01:\x028\x01J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\r\x10\x0eJ\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13b\x06proto3', dependencies=[tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR])
_STEPBREAKDOWNEVENTS = _descriptor.Descriptor(name='StepBreakdownEvents', full_name='tensorflow.profiler.StepBreakdownEvents', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.StepBreakdownEvents.id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.StepBreakdownEvents.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=127, serialized_end=174)
_PODSTATSDATABASE = _descriptor.Descriptor(name='PodStatsDatabase', full_name='tensorflow.profiler.PodStatsDatabase', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='pod_stats_record', full_name='tensorflow.profiler.PodStatsDatabase.pod_stats_record', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.PodStatsDatabase.diagnostics', index=1, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown_events', full_name='tensorflow.profiler.PodStatsDatabase.step_breakdown_events', index=2, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=177, serialized_end=392)
_PODSTATSRECORD_STEPBREAKDOWNUSENTRY = _descriptor.Descriptor(name='StepBreakdownUsEntry', full_name='tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PodStatsRecord.StepBreakdownUsEntry.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=616, serialized_end=670)
_PODSTATSRECORD = _descriptor.Descriptor(name='PodStatsRecord', full_name='tensorflow.profiler.PodStatsRecord', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_name', full_name='tensorflow.profiler.PodStatsRecord.host_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chip_id', full_name='tensorflow.profiler.PodStatsRecord.chip_id', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.profiler.PodStatsRecord.node_id', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.PodStatsRecord.step_num', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_duration_us', full_name='tensorflow.profiler.PodStatsRecord.total_duration_us', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown_us', full_name='tensorflow.profiler.PodStatsRecord.step_breakdown_us', index=5, number=19, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bottleneck', full_name='tensorflow.profiler.PodStatsRecord.bottleneck', index=6, number=14, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PODSTATSRECORD_STEPBREAKDOWNUSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=395, serialized_end=742)
_PODSTATSDATABASE.fields_by_name['pod_stats_record'].message_type = _PODSTATSRECORD
_PODSTATSDATABASE.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
_PODSTATSDATABASE.fields_by_name['step_breakdown_events'].message_type = _STEPBREAKDOWNEVENTS
_PODSTATSRECORD_STEPBREAKDOWNUSENTRY.containing_type = _PODSTATSRECORD
_PODSTATSRECORD.fields_by_name['step_breakdown_us'].message_type = _PODSTATSRECORD_STEPBREAKDOWNUSENTRY
DESCRIPTOR.message_types_by_name['StepBreakdownEvents'] = _STEPBREAKDOWNEVENTS
DESCRIPTOR.message_types_by_name['PodStatsDatabase'] = _PODSTATSDATABASE
DESCRIPTOR.message_types_by_name['PodStatsRecord'] = _PODSTATSRECORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
StepBreakdownEvents = _reflection.GeneratedProtocolMessageType('StepBreakdownEvents', (_message.Message,), {'DESCRIPTOR': _STEPBREAKDOWNEVENTS, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'})
_sym_db.RegisterMessage(StepBreakdownEvents)
PodStatsDatabase = _reflection.GeneratedProtocolMessageType('PodStatsDatabase', (_message.Message,), {'DESCRIPTOR': _PODSTATSDATABASE, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'})
_sym_db.RegisterMessage(PodStatsDatabase)
PodStatsRecord = _reflection.GeneratedProtocolMessageType('PodStatsRecord', (_message.Message,), {'StepBreakdownUsEntry': _reflection.GeneratedProtocolMessageType('StepBreakdownUsEntry', (_message.Message,), {'DESCRIPTOR': _PODSTATSRECORD_STEPBREAKDOWNUSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'}), 'DESCRIPTOR': _PODSTATSRECORD, '__module__': 'tensorflow.core.profiler.protobuf.pod_stats_pb2'})
_sym_db.RegisterMessage(PodStatsRecord)
_sym_db.RegisterMessage(PodStatsRecord.StepBreakdownUsEntry)
_PODSTATSRECORD_STEPBREAKDOWNUSENTRY._options = None
