
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/tpu/kernels/tpu_compilation_cache_common.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n>tensorflow/core/tpu/kernels/tpu_compilation_cache_common.proto\x12\x0etensorflow.tpu"=\n\x19TpuCompilationUidAndIndex\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x13\n\x0bproto_index\x18\x02 \x01(\x05"\xb9\x01\n\x14GetTpuProgramRequest\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12B\n\ruid_and_index\x18\x02 \x01(\x0b2).tensorflow.tpu.TpuCompilationUidAndIndexH\x00\x12A\n\x0cfetch_target\x18\x03 \x01(\x0e2+.tensorflow.tpu.CompilationCacheFetchTargetB\x0b\n\tkey_oneof*R\n\x1bCompilationCacheFetchTarget\x12\x0b\n\x07INVALID\x10\x00\x12\x08\n\x04MAIN\x10\x01\x12\x0c\n\x08SHARDING\x10\x02\x12\x0e\n\nUNSHARDING\x10\x03b\x06proto3')
_COMPILATIONCACHEFETCHTARGET = _descriptor.EnumDescriptor(name='CompilationCacheFetchTarget', full_name='tensorflow.tpu.CompilationCacheFetchTarget', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='MAIN', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SHARDING', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='UNSHARDING', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=333, serialized_end=415)
_sym_db.RegisterEnumDescriptor(_COMPILATIONCACHEFETCHTARGET)
CompilationCacheFetchTarget = enum_type_wrapper.EnumTypeWrapper(_COMPILATIONCACHEFETCHTARGET)
INVALID = 0
MAIN = 1
SHARDING = 2
UNSHARDING = 3
_TPUCOMPILATIONUIDANDINDEX = _descriptor.Descriptor(name='TpuCompilationUidAndIndex', full_name='tensorflow.tpu.TpuCompilationUidAndIndex', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='uid', full_name='tensorflow.tpu.TpuCompilationUidAndIndex.uid', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='proto_index', full_name='tensorflow.tpu.TpuCompilationUidAndIndex.proto_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=82, serialized_end=143)
_GETTPUPROGRAMREQUEST = _descriptor.Descriptor(name='GetTpuProgramRequest', full_name='tensorflow.tpu.GetTpuProgramRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.tpu.GetTpuProgramRequest.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uid_and_index', full_name='tensorflow.tpu.GetTpuProgramRequest.uid_and_index', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch_target', full_name='tensorflow.tpu.GetTpuProgramRequest.fetch_target', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='key_oneof', full_name='tensorflow.tpu.GetTpuProgramRequest.key_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=146, serialized_end=331)
_GETTPUPROGRAMREQUEST.fields_by_name['uid_and_index'].message_type = _TPUCOMPILATIONUIDANDINDEX
_GETTPUPROGRAMREQUEST.fields_by_name['fetch_target'].enum_type = _COMPILATIONCACHEFETCHTARGET
_GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof'].fields.append(_GETTPUPROGRAMREQUEST.fields_by_name['key'])
_GETTPUPROGRAMREQUEST.fields_by_name['key'].containing_oneof = _GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof']
_GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof'].fields.append(_GETTPUPROGRAMREQUEST.fields_by_name['uid_and_index'])
_GETTPUPROGRAMREQUEST.fields_by_name['uid_and_index'].containing_oneof = _GETTPUPROGRAMREQUEST.oneofs_by_name['key_oneof']
DESCRIPTOR.message_types_by_name['TpuCompilationUidAndIndex'] = _TPUCOMPILATIONUIDANDINDEX
DESCRIPTOR.message_types_by_name['GetTpuProgramRequest'] = _GETTPUPROGRAMREQUEST
DESCRIPTOR.enum_types_by_name['CompilationCacheFetchTarget'] = _COMPILATIONCACHEFETCHTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TpuCompilationUidAndIndex = _reflection.GeneratedProtocolMessageType('TpuCompilationUidAndIndex', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILATIONUIDANDINDEX, '__module__': 'tensorflow.core.tpu.kernels.tpu_compilation_cache_common_pb2'})
_sym_db.RegisterMessage(TpuCompilationUidAndIndex)
GetTpuProgramRequest = _reflection.GeneratedProtocolMessageType('GetTpuProgramRequest', (_message.Message,), {'DESCRIPTOR': _GETTPUPROGRAMREQUEST, '__module__': 'tensorflow.core.tpu.kernels.tpu_compilation_cache_common_pb2'})
_sym_db.RegisterMessage(GetTpuProgramRequest)
