
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
from .....tensorflow.core.framework import function_pb2 as tensorflow_dot_core_dot_framework_dot_function__pb2
from .....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from .....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from .....tensorflow.core.protobuf.tpu import compile_metadata_pb2 as tensorflow_dot_core_dot_protobuf_dot_tpu_dot_compile__metadata__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/tpu/kernels/tpu_compile.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/tpu/kernels/tpu_compile.proto\x12\x0etensorflow.tpu\x1a*tensorflow/core/framework/attr_value.proto\x1a(tensorflow/core/framework/function.proto\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a3tensorflow/core/protobuf/tpu/compile_metadata.proto"\xbc\x03\n\x1aTpuCompilationRequestProto\x12\x18\n\x10use_experimental\x18\x01 \x01(\x08\x12\x10\n\x08use_mlir\x18\x02 \x01(\x08\x12\x19\n\x11return_hlo_protos\x18\x03 \x01(\x08\x12%\n\x1dunload_cache_on_session_close\x18\x04 \x01(\x08\x129\n\x08metadata\x18\x05 \x01(\x0b2\'.tensorflow.tpu.TPUCompileMetadataProto\x120\n\narg_shapes\x18\x06 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x125\n\x14guaranteed_constants\x18\x07 \x03(\x0b2\x17.tensorflow.TensorProto\x12\x13\n\x0bmlir_module\x18\x08 \x01(\t\x120\n\x08fdef_lib\x18\t \x01(\x0b2\x1e.tensorflow.FunctionDefLibrary\x12\x19\n\x11graph_def_version\x18\n \x01(\x05\x12*\n\x08function\x18\x0b \x01(\x0b2\x18.tensorflow.NameAttrListb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_function__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tpu_dot_compile__metadata__pb2.DESCRIPTOR])
_TPUCOMPILATIONREQUESTPROTO = _descriptor.Descriptor(name='TpuCompilationRequestProto', full_name='tensorflow.tpu.TpuCompilationRequestProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='use_experimental', full_name='tensorflow.tpu.TpuCompilationRequestProto.use_experimental', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_mlir', full_name='tensorflow.tpu.TpuCompilationRequestProto.use_mlir', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='return_hlo_protos', full_name='tensorflow.tpu.TpuCompilationRequestProto.return_hlo_protos', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unload_cache_on_session_close', full_name='tensorflow.tpu.TpuCompilationRequestProto.unload_cache_on_session_close', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.tpu.TpuCompilationRequestProto.metadata', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='arg_shapes', full_name='tensorflow.tpu.TpuCompilationRequestProto.arg_shapes', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='guaranteed_constants', full_name='tensorflow.tpu.TpuCompilationRequestProto.guaranteed_constants', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mlir_module', full_name='tensorflow.tpu.TpuCompilationRequestProto.mlir_module', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fdef_lib', full_name='tensorflow.tpu.TpuCompilationRequestProto.fdef_lib', index=8, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_def_version', full_name='tensorflow.tpu.TpuCompilationRequestProto.graph_def_version', index=9, number=10, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function', full_name='tensorflow.tpu.TpuCompilationRequestProto.function', index=10, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=291, serialized_end=735)
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_tpu_dot_compile__metadata__pb2._TPUCOMPILEMETADATAPROTO
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['arg_shapes'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['guaranteed_constants'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['fdef_lib'].message_type = tensorflow_dot_core_dot_framework_dot_function__pb2._FUNCTIONDEFLIBRARY
_TPUCOMPILATIONREQUESTPROTO.fields_by_name['function'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._NAMEATTRLIST
DESCRIPTOR.message_types_by_name['TpuCompilationRequestProto'] = _TPUCOMPILATIONREQUESTPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TpuCompilationRequestProto = _reflection.GeneratedProtocolMessageType('TpuCompilationRequestProto', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILATIONREQUESTPROTO, '__module__': 'tensorflow.core.tpu.kernels.tpu_compile_pb2'})
_sym_db.RegisterMessage(TpuCompilationRequestProto)
