
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.xla import xla_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__pb2
from .....tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
from .....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from .....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
from .....tensorflow.core.protobuf.tpu import dynamic_padding_pb2 as tensorflow_dot_core_dot_protobuf_dot_tpu_dot_dynamic__padding__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/compile_metadata.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n3tensorflow/core/protobuf/tpu/compile_metadata.proto\x12\x0etensorflow.tpu\x1a!tensorflow/compiler/xla/xla.proto\x1a&tensorflow/compiler/xla/xla_data.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto\x1a2tensorflow/core/protobuf/tpu/dynamic_padding.proto"\xdd\t\n\x17TPUCompileMetadataProto\x129\n\x04args\x18\x01 \x03(\x0b2+.tensorflow.tpu.TPUCompileMetadataProto.Arg\x12?\n\x07retvals\x18\x02 \x03(\x0b2..tensorflow.tpu.TPUCompileMetadataProto.Retval\x12\x14\n\x0cnum_replicas\x18\x03 \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\x04 \x01(\x05\x125\n\x11device_assignment\x18\x08 \x01(\x0b2\x1a.xla.DeviceAssignmentProto\x12$\n\x1cfunction_library_fingerprint\x18\x06 \x01(\x04\x12\x16\n\x0esession_handle\x18\t \x01(\t\x12$\n\x1cguaranteed_const_fingerprint\x18\n \x01(\t\x120\n\x0cpadding_maps\x18\x0b \x03(\x0b2\x1a.tensorflow.tpu.PaddingMap\x12B\n\x14step_marker_location\x18\x0c \x01(\x0e2$.xla.DebugOptions.StepMarkerLocation\x12#\n\x1bxla_fusion_autotuner_thresh\x18\r \x01(\x03\x12*\n"enable_automatic_model_parallelism\x18\x0e \x01(\x08\x12%\n\x1duse_spmd_for_xla_partitioning\x18\x0f \x01(\x08\x1a\xc8\x04\n\x03Arg\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12>\n\x04kind\x18\x03 \x01(\x0e20.tensorflow.tpu.TPUCompileMetadataProto.Arg.Kind\x12!\n\x08sharding\x18\x04 \x01(\x0b2\x0f.xla.OpSharding\x12$\n\x1cis_same_data_across_replicas\x18\x05 \x01(\x08\x12Z\n\x13enable_xla_sharding\x18\x06 \x01(\x0e2=.tensorflow.tpu.TPUCompileMetadataProto.Arg.EnableXlaSharding\x12!\n\x19retval_index_for_sharding\x18\x08 \x01(\x05\x12\x10\n\x08fast_mem\x18\x07 \x01(\x08\x12\x1b\n\x13unrestricted_layout\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12\x1e\n\x16requires_xla_broadcast\x18\x0b \x01(\x08"I\n\x04Kind\x12\x0b\n\x07INVALID\x10\x00\x12\r\n\tPARAMETER\x10\x01\x12\x0c\n\x08VARIABLE\x10\x02\x12\x17\n\x13GUARANTEED_CONSTANT\x10\x03"?\n\x11EnableXlaSharding\x12\x0e\n\nDISALLOWED\x10\x00\x12\r\n\tTENTATIVE\x10\x01\x12\x0b\n\x07ALLOWED\x10\x02\x1a+\n\x06Retval\x12!\n\x08sharding\x18\x01 \x01(\x0b2\x0f.xla.OpShardingJ\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08J\x04\x08\x10\x10\x11B\x03\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_xla__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tpu_dot_dynamic__padding__pb2.DESCRIPTOR])
_TPUCOMPILEMETADATAPROTO_ARG_KIND = _descriptor.EnumDescriptor(name='Kind', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.Kind', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='PARAMETER', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GUARANTEED_CONSTANT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1328, serialized_end=1401)
_sym_db.RegisterEnumDescriptor(_TPUCOMPILEMETADATAPROTO_ARG_KIND)
_TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING = _descriptor.EnumDescriptor(name='EnableXlaSharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.EnableXlaSharding', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DISALLOWED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TENTATIVE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ALLOWED', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1403, serialized_end=1466)
_sym_db.RegisterEnumDescriptor(_TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING)
_TPUCOMPILEMETADATAPROTO_ARG = _descriptor.Descriptor(name='Arg', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kind', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.kind', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.sharding', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_same_data_across_replicas', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.is_same_data_across_replicas', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_xla_sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.enable_xla_sharding', index=5, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='retval_index_for_sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.retval_index_for_sharding', index=6, number=8, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fast_mem', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.fast_mem', index=7, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unrestricted_layout', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.unrestricted_layout', index=8, number=9, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.name', index=9, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requires_xla_broadcast', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.requires_xla_broadcast', index=10, number=11, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_TPUCOMPILEMETADATAPROTO_ARG_KIND, _TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=882, serialized_end=1466)
_TPUCOMPILEMETADATAPROTO_RETVAL = _descriptor.Descriptor(name='Retval', full_name='tensorflow.tpu.TPUCompileMetadataProto.Retval', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Retval.sharding', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1468, serialized_end=1511)
_TPUCOMPILEMETADATAPROTO = _descriptor.Descriptor(name='TPUCompileMetadataProto', full_name='tensorflow.tpu.TPUCompileMetadataProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='args', full_name='tensorflow.tpu.TPUCompileMetadataProto.args', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='retvals', full_name='tensorflow.tpu.TPUCompileMetadataProto.retvals', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_replicas', full_name='tensorflow.tpu.TPUCompileMetadataProto.num_replicas', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='tensorflow.tpu.TPUCompileMetadataProto.num_cores_per_replica', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='tensorflow.tpu.TPUCompileMetadataProto.device_assignment', index=4, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function_library_fingerprint', full_name='tensorflow.tpu.TPUCompileMetadataProto.function_library_fingerprint', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.tpu.TPUCompileMetadataProto.session_handle', index=6, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='guaranteed_const_fingerprint', full_name='tensorflow.tpu.TPUCompileMetadataProto.guaranteed_const_fingerprint', index=7, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_maps', full_name='tensorflow.tpu.TPUCompileMetadataProto.padding_maps', index=8, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_marker_location', full_name='tensorflow.tpu.TPUCompileMetadataProto.step_marker_location', index=9, number=12, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='xla_fusion_autotuner_thresh', full_name='tensorflow.tpu.TPUCompileMetadataProto.xla_fusion_autotuner_thresh', index=10, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_automatic_model_parallelism', full_name='tensorflow.tpu.TPUCompileMetadataProto.enable_automatic_model_parallelism', index=11, number=14, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_spmd_for_xla_partitioning', full_name='tensorflow.tpu.TPUCompileMetadataProto.use_spmd_for_xla_partitioning', index=12, number=15, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUCOMPILEMETADATAPROTO_ARG, _TPUCOMPILEMETADATAPROTO_RETVAL], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=284, serialized_end=1529)
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['kind'].enum_type = _TPUCOMPILEMETADATAPROTO_ARG_KIND
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['enable_xla_sharding'].enum_type = _TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING
_TPUCOMPILEMETADATAPROTO_ARG.containing_type = _TPUCOMPILEMETADATAPROTO
_TPUCOMPILEMETADATAPROTO_ARG_KIND.containing_type = _TPUCOMPILEMETADATAPROTO_ARG
_TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING.containing_type = _TPUCOMPILEMETADATAPROTO_ARG
_TPUCOMPILEMETADATAPROTO_RETVAL.fields_by_name['sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_TPUCOMPILEMETADATAPROTO_RETVAL.containing_type = _TPUCOMPILEMETADATAPROTO
_TPUCOMPILEMETADATAPROTO.fields_by_name['args'].message_type = _TPUCOMPILEMETADATAPROTO_ARG
_TPUCOMPILEMETADATAPROTO.fields_by_name['retvals'].message_type = _TPUCOMPILEMETADATAPROTO_RETVAL
_TPUCOMPILEMETADATAPROTO.fields_by_name['device_assignment'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DEVICEASSIGNMENTPROTO
_TPUCOMPILEMETADATAPROTO.fields_by_name['padding_maps'].message_type = tensorflow_dot_core_dot_protobuf_dot_tpu_dot_dynamic__padding__pb2._PADDINGMAP
_TPUCOMPILEMETADATAPROTO.fields_by_name['step_marker_location'].enum_type = tensorflow_dot_compiler_dot_xla_dot_xla__pb2._DEBUGOPTIONS_STEPMARKERLOCATION
DESCRIPTOR.message_types_by_name['TPUCompileMetadataProto'] = _TPUCOMPILEMETADATAPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TPUCompileMetadataProto = _reflection.GeneratedProtocolMessageType('TPUCompileMetadataProto', (_message.Message,), {'Arg': _reflection.GeneratedProtocolMessageType('Arg', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILEMETADATAPROTO_ARG, '__module__': 'tensorflow.core.protobuf.tpu.compile_metadata_pb2'}), 'Retval': _reflection.GeneratedProtocolMessageType('Retval', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILEMETADATAPROTO_RETVAL, '__module__': 'tensorflow.core.protobuf.tpu.compile_metadata_pb2'}), 'DESCRIPTOR': _TPUCOMPILEMETADATAPROTO, '__module__': 'tensorflow.core.protobuf.tpu.compile_metadata_pb2'})
_sym_db.RegisterMessage(TPUCompileMetadataProto)
_sym_db.RegisterMessage(TPUCompileMetadataProto.Arg)
_sym_db.RegisterMessage(TPUCompileMetadataProto.Retval)
DESCRIPTOR._options = None
