
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/autotuning.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/protobuf/autotuning.proto\x12\ntensorflow\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto";\n\x0cCudnnVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05"1\n\x11ComputeCapability\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05"\xc9\x06\n\x0eAutotuneResult\x12\x15\n\rscratch_bytes\x18\x08 \x01(\x03\x12+\n\x08run_time\x18\t \x01(\x0b2\x19.google.protobuf.Duration\x129\n\x07failure\x18\x07 \x01(\x0b2(.tensorflow.AutotuneResult.FailureResult\x122\n\x04conv\x18\x05 \x01(\x0b2".tensorflow.AutotuneResult.ConvKeyH\x00\x122\n\x04gemm\x18\x06 \x01(\x0b2".tensorflow.AutotuneResult.GemmKeyH\x00\x12D\n\x0ecuda_conv_plan\x18\x0f \x01(\x0b2*.tensorflow.AutotuneResult.CudaConvPlanKeyH\x00\x1a\xbd\x02\n\rFailureResult\x124\n\x04kind\x18\x01 \x01(\x0e2&.tensorflow.AutotuneResult.FailureKind\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12<\n\x0ereference_conv\x18\x0b \x01(\x0b2".tensorflow.AutotuneResult.ConvKeyH\x00\x12<\n\x0ereference_gemm\x18\x0c \x01(\x0b2".tensorflow.AutotuneResult.GemmKeyH\x00\x12N\n\x18reference_cuda_conv_plan\x18\x0e \x01(\x0b2*.tensorflow.AutotuneResult.CudaConvPlanKeyH\x00\x12\x16\n\x0ebuffer_address\x18\r \x01(\x03B\x05\n\x03key\x1a8\n\x07ConvKey\x12\x11\n\talgorithm\x18\x01 \x01(\x03\x12\x1a\n\x12tensor_ops_enabled\x18\x02 \x01(\x08\x1a\x1c\n\x07GemmKey\x12\x11\n\talgorithm\x18\x01 \x01(\x03\x1a\'\n\x0fCudaConvPlanKey\x12\x14\n\x0cexec_plan_id\x18\x01 \x01(\t"B\n\x0bFailureKind\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10REDZONE_MODIFIED\x10\x01\x12\x10\n\x0cWRONG_RESULT\x10\x02B\x05\n\x03key"\xfe\x01\n\rAutotuningLog\x12#\n\x05instr\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12+\n\x07results\x18\x02 \x03(\x0b2\x1a.tensorflow.AutotuneResult\x12/\n\rcudnn_version\x18\x03 \x01(\x0b2\x18.tensorflow.CudnnVersion\x129\n\x12compute_capability\x18\x04 \x01(\x0b2\x1d.tensorflow.ComputeCapability\x12\x19\n\x11device_pci_bus_id\x18\x05 \x01(\t\x12\x14\n\x0cblas_version\x18\x06 \x01(\tBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, google_dot_protobuf_dot_duration__pb2.DESCRIPTOR])
_AUTOTUNERESULT_FAILUREKIND = _descriptor.EnumDescriptor(name='FailureKind', full_name='tensorflow.AutotuneResult.FailureKind', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='REDZONE_MODIFIED', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='WRONG_RESULT', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=997, serialized_end=1063)
_sym_db.RegisterEnumDescriptor(_AUTOTUNERESULT_FAILUREKIND)
_CUDNNVERSION = _descriptor.Descriptor(name='CudnnVersion', full_name='tensorflow.CudnnVersion', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='major', full_name='tensorflow.CudnnVersion.major', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minor', full_name='tensorflow.CudnnVersion.minor', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='patch', full_name='tensorflow.CudnnVersion.patch', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=116, serialized_end=175)
_COMPUTECAPABILITY = _descriptor.Descriptor(name='ComputeCapability', full_name='tensorflow.ComputeCapability', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='major', full_name='tensorflow.ComputeCapability.major', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minor', full_name='tensorflow.ComputeCapability.minor', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=177, serialized_end=226)
_AUTOTUNERESULT_FAILURERESULT = _descriptor.Descriptor(name='FailureResult', full_name='tensorflow.AutotuneResult.FailureResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kind', full_name='tensorflow.AutotuneResult.FailureResult.kind', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='msg', full_name='tensorflow.AutotuneResult.FailureResult.msg', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reference_conv', full_name='tensorflow.AutotuneResult.FailureResult.reference_conv', index=2, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reference_gemm', full_name='tensorflow.AutotuneResult.FailureResult.reference_gemm', index=3, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reference_cuda_conv_plan', full_name='tensorflow.AutotuneResult.FailureResult.reference_cuda_conv_plan', index=4, number=14, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buffer_address', full_name='tensorflow.AutotuneResult.FailureResult.buffer_address', index=5, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='key', full_name='tensorflow.AutotuneResult.FailureResult.key', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=549, serialized_end=866)
_AUTOTUNERESULT_CONVKEY = _descriptor.Descriptor(name='ConvKey', full_name='tensorflow.AutotuneResult.ConvKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='tensorflow.AutotuneResult.ConvKey.algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_ops_enabled', full_name='tensorflow.AutotuneResult.ConvKey.tensor_ops_enabled', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=868, serialized_end=924)
_AUTOTUNERESULT_GEMMKEY = _descriptor.Descriptor(name='GemmKey', full_name='tensorflow.AutotuneResult.GemmKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='tensorflow.AutotuneResult.GemmKey.algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=926, serialized_end=954)
_AUTOTUNERESULT_CUDACONVPLANKEY = _descriptor.Descriptor(name='CudaConvPlanKey', full_name='tensorflow.AutotuneResult.CudaConvPlanKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='exec_plan_id', full_name='tensorflow.AutotuneResult.CudaConvPlanKey.exec_plan_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=956, serialized_end=995)
_AUTOTUNERESULT = _descriptor.Descriptor(name='AutotuneResult', full_name='tensorflow.AutotuneResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='scratch_bytes', full_name='tensorflow.AutotuneResult.scratch_bytes', index=0, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_time', full_name='tensorflow.AutotuneResult.run_time', index=1, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='failure', full_name='tensorflow.AutotuneResult.failure', index=2, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='conv', full_name='tensorflow.AutotuneResult.conv', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='gemm', full_name='tensorflow.AutotuneResult.gemm', index=4, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cuda_conv_plan', full_name='tensorflow.AutotuneResult.cuda_conv_plan', index=5, number=15, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_AUTOTUNERESULT_FAILURERESULT, _AUTOTUNERESULT_CONVKEY, _AUTOTUNERESULT_GEMMKEY, _AUTOTUNERESULT_CUDACONVPLANKEY], enum_types=[_AUTOTUNERESULT_FAILUREKIND], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='key', full_name='tensorflow.AutotuneResult.key', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=229, serialized_end=1070)
_AUTOTUNINGLOG = _descriptor.Descriptor(name='AutotuningLog', full_name='tensorflow.AutotuningLog', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='instr', full_name='tensorflow.AutotuningLog.instr', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='results', full_name='tensorflow.AutotuningLog.results', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cudnn_version', full_name='tensorflow.AutotuningLog.cudnn_version', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_capability', full_name='tensorflow.AutotuningLog.compute_capability', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_pci_bus_id', full_name='tensorflow.AutotuningLog.device_pci_bus_id', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='blas_version', full_name='tensorflow.AutotuningLog.blas_version', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1073, serialized_end=1327)
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['kind'].enum_type = _AUTOTUNERESULT_FAILUREKIND
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_conv'].message_type = _AUTOTUNERESULT_CONVKEY
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_gemm'].message_type = _AUTOTUNERESULT_GEMMKEY
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_cuda_conv_plan'].message_type = _AUTOTUNERESULT_CUDACONVPLANKEY
_AUTOTUNERESULT_FAILURERESULT.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_conv'])
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_conv'].containing_oneof = _AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key']
_AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_gemm'])
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_gemm'].containing_oneof = _AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key']
_AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_cuda_conv_plan'])
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_cuda_conv_plan'].containing_oneof = _AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key']
_AUTOTUNERESULT_CONVKEY.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT_GEMMKEY.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT_CUDACONVPLANKEY.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT.fields_by_name['run_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AUTOTUNERESULT.fields_by_name['failure'].message_type = _AUTOTUNERESULT_FAILURERESULT
_AUTOTUNERESULT.fields_by_name['conv'].message_type = _AUTOTUNERESULT_CONVKEY
_AUTOTUNERESULT.fields_by_name['gemm'].message_type = _AUTOTUNERESULT_GEMMKEY
_AUTOTUNERESULT.fields_by_name['cuda_conv_plan'].message_type = _AUTOTUNERESULT_CUDACONVPLANKEY
_AUTOTUNERESULT_FAILUREKIND.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT.fields_by_name['conv'])
_AUTOTUNERESULT.fields_by_name['conv'].containing_oneof = _AUTOTUNERESULT.oneofs_by_name['key']
_AUTOTUNERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT.fields_by_name['gemm'])
_AUTOTUNERESULT.fields_by_name['gemm'].containing_oneof = _AUTOTUNERESULT.oneofs_by_name['key']
_AUTOTUNERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT.fields_by_name['cuda_conv_plan'])
_AUTOTUNERESULT.fields_by_name['cuda_conv_plan'].containing_oneof = _AUTOTUNERESULT.oneofs_by_name['key']
_AUTOTUNINGLOG.fields_by_name['instr'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_AUTOTUNINGLOG.fields_by_name['results'].message_type = _AUTOTUNERESULT
_AUTOTUNINGLOG.fields_by_name['cudnn_version'].message_type = _CUDNNVERSION
_AUTOTUNINGLOG.fields_by_name['compute_capability'].message_type = _COMPUTECAPABILITY
DESCRIPTOR.message_types_by_name['CudnnVersion'] = _CUDNNVERSION
DESCRIPTOR.message_types_by_name['ComputeCapability'] = _COMPUTECAPABILITY
DESCRIPTOR.message_types_by_name['AutotuneResult'] = _AUTOTUNERESULT
DESCRIPTOR.message_types_by_name['AutotuningLog'] = _AUTOTUNINGLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CudnnVersion = _reflection.GeneratedProtocolMessageType('CudnnVersion', (_message.Message,), {'DESCRIPTOR': _CUDNNVERSION, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(CudnnVersion)
ComputeCapability = _reflection.GeneratedProtocolMessageType('ComputeCapability', (_message.Message,), {'DESCRIPTOR': _COMPUTECAPABILITY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(ComputeCapability)
AutotuneResult = _reflection.GeneratedProtocolMessageType('AutotuneResult', (_message.Message,), {'FailureResult': _reflection.GeneratedProtocolMessageType('FailureResult', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_FAILURERESULT, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'ConvKey': _reflection.GeneratedProtocolMessageType('ConvKey', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_CONVKEY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'GemmKey': _reflection.GeneratedProtocolMessageType('GemmKey', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_GEMMKEY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'CudaConvPlanKey': _reflection.GeneratedProtocolMessageType('CudaConvPlanKey', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_CUDACONVPLANKEY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'DESCRIPTOR': _AUTOTUNERESULT, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(AutotuneResult)
_sym_db.RegisterMessage(AutotuneResult.FailureResult)
_sym_db.RegisterMessage(AutotuneResult.ConvKey)
_sym_db.RegisterMessage(AutotuneResult.GemmKey)
_sym_db.RegisterMessage(AutotuneResult.CudaConvPlanKey)
AutotuningLog = _reflection.GeneratedProtocolMessageType('AutotuningLog', (_message.Message,), {'DESCRIPTOR': _AUTOTUNINGLOG, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(AutotuningLog)
DESCRIPTOR._options = None
