
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
from .....tensorflow.core.profiler.protobuf import input_pipeline_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_input__pipeline__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/overview_page.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/core/profiler/protobuf/overview_page.proto\x12\x13tensorflow.profiler\x1a\x19google/protobuf/any.proto\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto\x1a6tensorflow/core/profiler/protobuf/input_pipeline.proto"\xc2\x01\n\x0cOverviewTfOp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08category\x18\x02 \x01(\t\x12\x1a\n\x12self_time_fraction\x18\x03 \x01(\x01\x12 \n\x18cumulative_time_fraction\x18\x04 \x01(\x01\x12\x11\n\tflop_rate\x18\x05 \x01(\x01\x12!\n\x19is_op_tensorcore_eligible\x18\x06 \x01(\x08\x12\x1e\n\x16is_op_using_tensorcore\x18\x07 \x01(\x08"\xf5\x04\n\x14OverviewPageAnalysis\x12\x1f\n\x17mxu_utilization_percent\x18\x01 \x01(\x01\x12 \n\x18device_idle_time_percent\x18\x02 \x01(\x01\x12\x1e\n\x16host_idle_time_percent\x18\x03 \x01(\x01\x129\n\x0etop_device_ops\x18\x04 \x03(\x0b2!.tensorflow.profiler.OverviewTfOp\x12\x13\n\x0bremark_text\x18\x05 \x01(\t\x12\x14\n\x0cremark_color\x18\x06 \x01(\t\x12:\n2flop_rate_utilization_relative_to_roofline_percent\x18\x07 \x01(\x01\x12:\n2memory_bw_utilization_relative_to_hw_limit_percent\x18\x08 \x01(\x01\x12$\n\x1cdevice_compute_16bit_percent\x18\t \x01(\x01\x12$\n\x1cdevice_compute_32bit_percent\x18\n \x01(\x01\x12\x1a\n\x12host_tf_op_percent\x18\x0b \x01(\x01\x12\x1c\n\x14device_tf_op_percent\x18\x0c \x01(\x01\x12\x18\n\x10host_trace_level\x18\r \x01(\r\x12"\n\x1ahost_op_time_eager_percent\x18\x0e \x01(\x01\x12$\n\x1cdevice_op_time_eager_percent\x18\x0f \x01(\x01\x122\n*device_op_time_outside_compilation_percent\x18\x10 \x01(\x01"\x1f\n\x0fOverviewPageTip\x12\x0c\n\x04link\x18\x01 \x01(\t"\xff\x01\n\x15GenericRecommendation\x12 \n\x18kernel_launch_bottleneck\x18\x01 \x01(\t\x12\x1f\n\x17kernel_launch_statement\x18\x02 \x01(\t\x12\x1c\n\x14all_other_bottleneck\x18\x03 \x01(\t\x12\x1b\n\x13all_other_statement\x18\x04 \x01(\t\x12\x1b\n\x13precision_statement\x18\x05 \x01(\t\x12%\n\x1ddevice_collectives_bottleneck\x18\x06 \x01(\t\x12$\n\x1cdevice_collectives_statement\x18\x07 \x01(\t"\xdf\x04\n\x1aOverviewPageRecommendation\x12\x12\n\nbottleneck\x18\x01 \x01(\t\x12\x11\n\tstatement\x18\x02 \x01(\t\x128\n\ninput_tips\x18\x0b \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12\x18\n\x10output_statement\x18\t \x01(\t\x12\x1c\n\x14eager_statement_html\x18\x0c \x01(\t\x12*\n"outside_compilation_statement_html\x18\r \x01(\t\x12"\n\x1atf_function_statement_html\x18\n \x01(\t\x127\n\thost_tips\x18\x03 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x129\n\x0bdevice_tips\x18\x04 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12@\n\x12documentation_tips\x18\x05 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12,\n\x0erecommendation\x18\x06 \x01(\x0b2\x14.google.protobuf.Any\x126\n\x08faq_tips\x18\x07 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12<\n\x0einference_tips\x18\x08 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip"\x80\x01\n"OverviewPageHostIndependentJobInfo\x12\x13\n\x0bchange_list\x18\x01 \x01(\x03\x12\x12\n\nbuild_time\x18\x02 \x01(\x03\x12\x14\n\x0cbuild_target\x18\x03 \x01(\t\x12\x1b\n\x13profile_duration_ms\x18\x04 \x01(\r"\x8b\x01\n OverviewPageHostDependentJobInfo\x12\x0f\n\x07host_id\x18\x01 \x01(\t\x12\x14\n\x0ccommand_line\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x13\n\x0bbns_address\x18\x04 \x01(\t\x12\x17\n\x0fprofile_time_ns\x18\x05 \x01(\x04"\x80\x04\n\x1aOverviewPageRunEnvironment\x12\x12\n\nhost_count\x18\x01 \x01(\x05\x12\x12\n\ntask_count\x18\x02 \x01(\x05\x12Q\n\thostnames\x18\x03 \x03(\x0b2>.tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry\x12\x13\n\x0bdevice_type\x18\x04 \x01(\t\x12\x19\n\x11device_core_count\x18\x05 \x01(\x05\x12\x1b\n\x13per_core_batch_size\x18\x06 \x01(\x05\x12Z\n\x19host_independent_job_info\x18\x07 \x01(\x0b27.tensorflow.profiler.OverviewPageHostIndependentJobInfo\x12V\n\x17host_dependent_job_info\x18\x08 \x03(\x0b25.tensorflow.profiler.OverviewPageHostDependentJobInfo\x12\x15\n\rreplica_count\x18\t \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\n \x01(\x05\x1a0\n\x0eHostnamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x028\x01"\xf1\x02\n\x0cOverviewPage\x12H\n\x0frun_environment\x18\x06 \x01(\x0b2/.tensorflow.profiler.OverviewPageRunEnvironment\x12H\n\x0einput_analysis\x18\x02 \x01(\x0b20.tensorflow.profiler.InputPipelineAnalysisResult\x12;\n\x08analysis\x18\x03 \x01(\x0b2).tensorflow.profiler.OverviewPageAnalysis\x12G\n\x0erecommendation\x18\x04 \x01(\x0b2/.tensorflow.profiler.OverviewPageRecommendation\x125\n\x0bdiagnostics\x18\x08 \x01(\x0b2 .tensorflow.profiler.DiagnosticsJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08b\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_input__pipeline__pb2.DESCRIPTOR])
_OVERVIEWTFOP = _descriptor.Descriptor(name='OverviewTfOp', full_name='tensorflow.profiler.OverviewTfOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.OverviewTfOp.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.OverviewTfOp.category', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_fraction', full_name='tensorflow.profiler.OverviewTfOp.self_time_fraction', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cumulative_time_fraction', full_name='tensorflow.profiler.OverviewTfOp.cumulative_time_fraction', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flop_rate', full_name='tensorflow.profiler.OverviewTfOp.flop_rate', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_op_tensorcore_eligible', full_name='tensorflow.profiler.OverviewTfOp.is_op_tensorcore_eligible', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_op_using_tensorcore', full_name='tensorflow.profiler.OverviewTfOp.is_op_using_tensorcore', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=215, serialized_end=409)
_OVERVIEWPAGEANALYSIS = _descriptor.Descriptor(name='OverviewPageAnalysis', full_name='tensorflow.profiler.OverviewPageAnalysis', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='mxu_utilization_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.mxu_utilization_percent', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_idle_time_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_idle_time_percent', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_idle_time_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.host_idle_time_percent', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='top_device_ops', full_name='tensorflow.profiler.OverviewPageAnalysis.top_device_ops', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remark_text', full_name='tensorflow.profiler.OverviewPageAnalysis.remark_text', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remark_color', full_name='tensorflow.profiler.OverviewPageAnalysis.remark_color', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flop_rate_utilization_relative_to_roofline_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.flop_rate_utilization_relative_to_roofline_percent', index=6, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_bw_utilization_relative_to_hw_limit_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.memory_bw_utilization_relative_to_hw_limit_percent', index=7, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_16bit_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_compute_16bit_percent', index=8, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_32bit_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_compute_32bit_percent', index=9, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_tf_op_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.host_tf_op_percent', index=10, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_tf_op_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_tf_op_percent', index=11, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_trace_level', full_name='tensorflow.profiler.OverviewPageAnalysis.host_trace_level', index=12, number=13, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_op_time_eager_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.host_op_time_eager_percent', index=13, number=14, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_op_time_eager_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_op_time_eager_percent', index=14, number=15, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_op_time_outside_compilation_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_op_time_outside_compilation_percent', index=15, number=16, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=412, serialized_end=1041)
_OVERVIEWPAGETIP = _descriptor.Descriptor(name='OverviewPageTip', full_name='tensorflow.profiler.OverviewPageTip', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='link', full_name='tensorflow.profiler.OverviewPageTip.link', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1043, serialized_end=1074)
_GENERICRECOMMENDATION = _descriptor.Descriptor(name='GenericRecommendation', full_name='tensorflow.profiler.GenericRecommendation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kernel_launch_bottleneck', full_name='tensorflow.profiler.GenericRecommendation.kernel_launch_bottleneck', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_launch_statement', full_name='tensorflow.profiler.GenericRecommendation.kernel_launch_statement', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_bottleneck', full_name='tensorflow.profiler.GenericRecommendation.all_other_bottleneck', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_statement', full_name='tensorflow.profiler.GenericRecommendation.all_other_statement', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='precision_statement', full_name='tensorflow.profiler.GenericRecommendation.precision_statement', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_bottleneck', full_name='tensorflow.profiler.GenericRecommendation.device_collectives_bottleneck', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_statement', full_name='tensorflow.profiler.GenericRecommendation.device_collectives_statement', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1077, serialized_end=1332)
_OVERVIEWPAGERECOMMENDATION = _descriptor.Descriptor(name='OverviewPageRecommendation', full_name='tensorflow.profiler.OverviewPageRecommendation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bottleneck', full_name='tensorflow.profiler.OverviewPageRecommendation.bottleneck', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='statement', full_name='tensorflow.profiler.OverviewPageRecommendation.statement', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.input_tips', index=2, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_statement', full_name='tensorflow.profiler.OverviewPageRecommendation.output_statement', index=3, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='eager_statement_html', full_name='tensorflow.profiler.OverviewPageRecommendation.eager_statement_html', index=4, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='outside_compilation_statement_html', full_name='tensorflow.profiler.OverviewPageRecommendation.outside_compilation_statement_html', index=5, number=13, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_function_statement_html', full_name='tensorflow.profiler.OverviewPageRecommendation.tf_function_statement_html', index=6, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.host_tips', index=7, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.device_tips', index=8, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='documentation_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.documentation_tips', index=9, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recommendation', full_name='tensorflow.profiler.OverviewPageRecommendation.recommendation', index=10, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='faq_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.faq_tips', index=11, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inference_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.inference_tips', index=12, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1335, serialized_end=1942)
_OVERVIEWPAGEHOSTINDEPENDENTJOBINFO = _descriptor.Descriptor(name='OverviewPageHostIndependentJobInfo', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='change_list', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.change_list', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_time', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.build_time', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_target', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.build_target', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_duration_ms', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.profile_duration_ms', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1945, serialized_end=2073)
_OVERVIEWPAGEHOSTDEPENDENTJOBINFO = _descriptor.Descriptor(name='OverviewPageHostDependentJobInfo', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_id', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.host_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='command_line', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.command_line', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.start_time', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bns_address', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.bns_address', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_time_ns', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.profile_time_ns', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2076, serialized_end=2215)
_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY = _descriptor.Descriptor(name='HostnamesEntry', full_name='tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry.value', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2682, serialized_end=2730)
_OVERVIEWPAGERUNENVIRONMENT = _descriptor.Descriptor(name='OverviewPageRunEnvironment', full_name='tensorflow.profiler.OverviewPageRunEnvironment', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.host_count', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.task_count', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hostnames', full_name='tensorflow.profiler.OverviewPageRunEnvironment.hostnames', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.profiler.OverviewPageRunEnvironment.device_type', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_core_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.device_core_count', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='per_core_batch_size', full_name='tensorflow.profiler.OverviewPageRunEnvironment.per_core_batch_size', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_independent_job_info', full_name='tensorflow.profiler.OverviewPageRunEnvironment.host_independent_job_info', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_dependent_job_info', full_name='tensorflow.profiler.OverviewPageRunEnvironment.host_dependent_job_info', index=7, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='replica_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.replica_count', index=8, number=9, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='tensorflow.profiler.OverviewPageRunEnvironment.num_cores_per_replica', index=9, number=10, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2218, serialized_end=2730)
_OVERVIEWPAGE = _descriptor.Descriptor(name='OverviewPage', full_name='tensorflow.profiler.OverviewPage', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='run_environment', full_name='tensorflow.profiler.OverviewPage.run_environment', index=0, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_analysis', full_name='tensorflow.profiler.OverviewPage.input_analysis', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='analysis', full_name='tensorflow.profiler.OverviewPage.analysis', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recommendation', full_name='tensorflow.profiler.OverviewPage.recommendation', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.OverviewPage.diagnostics', index=4, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2733, serialized_end=3102)
_OVERVIEWPAGEANALYSIS.fields_by_name['top_device_ops'].message_type = _OVERVIEWTFOP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['input_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['host_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['device_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['documentation_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['recommendation'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OVERVIEWPAGERECOMMENDATION.fields_by_name['faq_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['inference_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY.containing_type = _OVERVIEWPAGERUNENVIRONMENT
_OVERVIEWPAGERUNENVIRONMENT.fields_by_name['hostnames'].message_type = _OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY
_OVERVIEWPAGERUNENVIRONMENT.fields_by_name['host_independent_job_info'].message_type = _OVERVIEWPAGEHOSTINDEPENDENTJOBINFO
_OVERVIEWPAGERUNENVIRONMENT.fields_by_name['host_dependent_job_info'].message_type = _OVERVIEWPAGEHOSTDEPENDENTJOBINFO
_OVERVIEWPAGE.fields_by_name['run_environment'].message_type = _OVERVIEWPAGERUNENVIRONMENT
_OVERVIEWPAGE.fields_by_name['input_analysis'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_input__pipeline__pb2._INPUTPIPELINEANALYSISRESULT
_OVERVIEWPAGE.fields_by_name['analysis'].message_type = _OVERVIEWPAGEANALYSIS
_OVERVIEWPAGE.fields_by_name['recommendation'].message_type = _OVERVIEWPAGERECOMMENDATION
_OVERVIEWPAGE.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
DESCRIPTOR.message_types_by_name['OverviewTfOp'] = _OVERVIEWTFOP
DESCRIPTOR.message_types_by_name['OverviewPageAnalysis'] = _OVERVIEWPAGEANALYSIS
DESCRIPTOR.message_types_by_name['OverviewPageTip'] = _OVERVIEWPAGETIP
DESCRIPTOR.message_types_by_name['GenericRecommendation'] = _GENERICRECOMMENDATION
DESCRIPTOR.message_types_by_name['OverviewPageRecommendation'] = _OVERVIEWPAGERECOMMENDATION
DESCRIPTOR.message_types_by_name['OverviewPageHostIndependentJobInfo'] = _OVERVIEWPAGEHOSTINDEPENDENTJOBINFO
DESCRIPTOR.message_types_by_name['OverviewPageHostDependentJobInfo'] = _OVERVIEWPAGEHOSTDEPENDENTJOBINFO
DESCRIPTOR.message_types_by_name['OverviewPageRunEnvironment'] = _OVERVIEWPAGERUNENVIRONMENT
DESCRIPTOR.message_types_by_name['OverviewPage'] = _OVERVIEWPAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
OverviewTfOp = _reflection.GeneratedProtocolMessageType('OverviewTfOp', (_message.Message,), {'DESCRIPTOR': _OVERVIEWTFOP, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewTfOp)
OverviewPageAnalysis = _reflection.GeneratedProtocolMessageType('OverviewPageAnalysis', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGEANALYSIS, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageAnalysis)
OverviewPageTip = _reflection.GeneratedProtocolMessageType('OverviewPageTip', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGETIP, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageTip)
GenericRecommendation = _reflection.GeneratedProtocolMessageType('GenericRecommendation', (_message.Message,), {'DESCRIPTOR': _GENERICRECOMMENDATION, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(GenericRecommendation)
OverviewPageRecommendation = _reflection.GeneratedProtocolMessageType('OverviewPageRecommendation', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGERECOMMENDATION, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageRecommendation)
OverviewPageHostIndependentJobInfo = _reflection.GeneratedProtocolMessageType('OverviewPageHostIndependentJobInfo', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGEHOSTINDEPENDENTJOBINFO, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageHostIndependentJobInfo)
OverviewPageHostDependentJobInfo = _reflection.GeneratedProtocolMessageType('OverviewPageHostDependentJobInfo', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGEHOSTDEPENDENTJOBINFO, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageHostDependentJobInfo)
OverviewPageRunEnvironment = _reflection.GeneratedProtocolMessageType('OverviewPageRunEnvironment', (_message.Message,), {'HostnamesEntry': _reflection.GeneratedProtocolMessageType('HostnamesEntry', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'}), 'DESCRIPTOR': _OVERVIEWPAGERUNENVIRONMENT, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageRunEnvironment)
_sym_db.RegisterMessage(OverviewPageRunEnvironment.HostnamesEntry)
OverviewPage = _reflection.GeneratedProtocolMessageType('OverviewPage', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGE, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPage)
_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY._options = None
