
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/memory_profile.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/core/profiler/protobuf/memory_profile.proto\x12\x13tensorflow.profiler"\xa1\x01\n\x16MemoryAggregationStats\x12\x1c\n\x14stack_reserved_bytes\x18\x01 \x01(\x03\x12\x1c\n\x14heap_allocated_bytes\x18\x02 \x01(\x03\x12\x19\n\x11free_memory_bytes\x18\x03 \x01(\x03\x12\x15\n\rfragmentation\x18\x04 \x01(\x01\x12\x19\n\x11peak_bytes_in_use\x18\x05 \x01(\x03"\xfd\x01\n\x16MemoryActivityMetadata\x12<\n\x0fmemory_activity\x18\x01 \x01(\x0e2#.tensorflow.profiler.MemoryActivity\x12\x17\n\x0frequested_bytes\x18\x02 \x01(\x03\x12\x18\n\x10allocation_bytes\x18\x03 \x01(\x03\x12\x0f\n\x07address\x18\x04 \x01(\x04\x12\x12\n\ntf_op_name\x18\x05 \x01(\t\x12\x0f\n\x07step_id\x18\x06 \x01(\x03\x12\x13\n\x0bregion_type\x18\x07 \x01(\t\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12\x14\n\x0ctensor_shape\x18\t \x01(\t"\xbf\x01\n\x15MemoryProfileSnapshot\x12\x16\n\x0etime_offset_ps\x18\x01 \x01(\x03\x12F\n\x11aggregation_stats\x18\x02 \x01(\x0b2+.tensorflow.profiler.MemoryAggregationStats\x12F\n\x11activity_metadata\x18\x03 \x01(\x0b2+.tensorflow.profiler.MemoryActivityMetadata"\xaf\x01\n\x14MemoryProfileSummary\x12!\n\x19peak_bytes_usage_lifetime\x18\x01 \x01(\x03\x12?\n\npeak_stats\x18\x02 \x01(\x0b2+.tensorflow.profiler.MemoryAggregationStats\x12\x1a\n\x12peak_stats_time_ps\x18\x03 \x01(\x03\x12\x17\n\x0fmemory_capacity\x18\x04 \x01(\x03"Z\n\x10ActiveAllocation\x12\x16\n\x0esnapshot_index\x18\x01 \x01(\x03\x12\x15\n\rspecial_index\x18\x02 \x01(\x03\x12\x17\n\x0fnum_occurrences\x18\x03 \x01(\x03"\xba\x02\n\x19PerAllocatorMemoryProfile\x12L\n\x18memory_profile_snapshots\x18\x01 \x03(\x0b2*.tensorflow.profiler.MemoryProfileSnapshot\x12B\n\x0fprofile_summary\x18\x02 \x01(\x0b2).tensorflow.profiler.MemoryProfileSummary\x12A\n\x12active_allocations\x18\x03 \x03(\x0b2%.tensorflow.profiler.ActiveAllocation\x12H\n\x13special_allocations\x18\x04 \x03(\x0b2+.tensorflow.profiler.MemoryActivityMetadata"\x97\x02\n\rMemoryProfile\x12g\n\x1cmemory_profile_per_allocator\x18\x01 \x03(\x0b2A.tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry\x12\x11\n\tnum_hosts\x18\x02 \x01(\x05\x12\x12\n\nmemory_ids\x18\x03 \x03(\t\x1ap\n\x1eMemoryProfilePerAllocatorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b2..tensorflow.profiler.PerAllocatorMemoryProfile:\x028\x01J\x04\x08\x04\x10\x05*h\n\x0eMemoryActivity\x12\x14\n\x10UNKNOWN_ACTIVITY\x10\x00\x12\x0e\n\nALLOCATION\x10\x01\x12\x10\n\x0cDEALLOCATION\x10\x02\x12\x0f\n\x0bRESERVATION\x10\x03\x12\r\n\tEXPANSION\x10\x04b\x06proto3')
_MEMORYACTIVITY = _descriptor.EnumDescriptor(name='MemoryActivity', full_name='tensorflow.profiler.MemoryActivity', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN_ACTIVITY', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ALLOCATION', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DEALLOCATION', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='RESERVATION', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EXPANSION', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1562, serialized_end=1666)
_sym_db.RegisterEnumDescriptor(_MEMORYACTIVITY)
MemoryActivity = enum_type_wrapper.EnumTypeWrapper(_MEMORYACTIVITY)
UNKNOWN_ACTIVITY = 0
ALLOCATION = 1
DEALLOCATION = 2
RESERVATION = 3
EXPANSION = 4
_MEMORYAGGREGATIONSTATS = _descriptor.Descriptor(name='MemoryAggregationStats', full_name='tensorflow.profiler.MemoryAggregationStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='stack_reserved_bytes', full_name='tensorflow.profiler.MemoryAggregationStats.stack_reserved_bytes', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='heap_allocated_bytes', full_name='tensorflow.profiler.MemoryAggregationStats.heap_allocated_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='free_memory_bytes', full_name='tensorflow.profiler.MemoryAggregationStats.free_memory_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fragmentation', full_name='tensorflow.profiler.MemoryAggregationStats.fragmentation', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_bytes_in_use', full_name='tensorflow.profiler.MemoryAggregationStats.peak_bytes_in_use', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=80, serialized_end=241)
_MEMORYACTIVITYMETADATA = _descriptor.Descriptor(name='MemoryActivityMetadata', full_name='tensorflow.profiler.MemoryActivityMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='memory_activity', full_name='tensorflow.profiler.MemoryActivityMetadata.memory_activity', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requested_bytes', full_name='tensorflow.profiler.MemoryActivityMetadata.requested_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_bytes', full_name='tensorflow.profiler.MemoryActivityMetadata.allocation_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='address', full_name='tensorflow.profiler.MemoryActivityMetadata.address', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_op_name', full_name='tensorflow.profiler.MemoryActivityMetadata.tf_op_name', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.profiler.MemoryActivityMetadata.step_id', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='region_type', full_name='tensorflow.profiler.MemoryActivityMetadata.region_type', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_type', full_name='tensorflow.profiler.MemoryActivityMetadata.data_type', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_shape', full_name='tensorflow.profiler.MemoryActivityMetadata.tensor_shape', index=8, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=244, serialized_end=497)
_MEMORYPROFILESNAPSHOT = _descriptor.Descriptor(name='MemoryProfileSnapshot', full_name='tensorflow.profiler.MemoryProfileSnapshot', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='time_offset_ps', full_name='tensorflow.profiler.MemoryProfileSnapshot.time_offset_ps', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='aggregation_stats', full_name='tensorflow.profiler.MemoryProfileSnapshot.aggregation_stats', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='activity_metadata', full_name='tensorflow.profiler.MemoryProfileSnapshot.activity_metadata', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=500, serialized_end=691)
_MEMORYPROFILESUMMARY = _descriptor.Descriptor(name='MemoryProfileSummary', full_name='tensorflow.profiler.MemoryProfileSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='peak_bytes_usage_lifetime', full_name='tensorflow.profiler.MemoryProfileSummary.peak_bytes_usage_lifetime', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_stats', full_name='tensorflow.profiler.MemoryProfileSummary.peak_stats', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_stats_time_ps', full_name='tensorflow.profiler.MemoryProfileSummary.peak_stats_time_ps', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_capacity', full_name='tensorflow.profiler.MemoryProfileSummary.memory_capacity', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=694, serialized_end=869)
_ACTIVEALLOCATION = _descriptor.Descriptor(name='ActiveAllocation', full_name='tensorflow.profiler.ActiveAllocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='snapshot_index', full_name='tensorflow.profiler.ActiveAllocation.snapshot_index', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='special_index', full_name='tensorflow.profiler.ActiveAllocation.special_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_occurrences', full_name='tensorflow.profiler.ActiveAllocation.num_occurrences', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=871, serialized_end=961)
_PERALLOCATORMEMORYPROFILE = _descriptor.Descriptor(name='PerAllocatorMemoryProfile', full_name='tensorflow.profiler.PerAllocatorMemoryProfile', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='memory_profile_snapshots', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.memory_profile_snapshots', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_summary', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.profile_summary', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='active_allocations', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.active_allocations', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='special_allocations', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.special_allocations', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=964, serialized_end=1278)
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY = _descriptor.Descriptor(name='MemoryProfilePerAllocatorEntry', full_name='tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1442, serialized_end=1554)
_MEMORYPROFILE = _descriptor.Descriptor(name='MemoryProfile', full_name='tensorflow.profiler.MemoryProfile', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='memory_profile_per_allocator', full_name='tensorflow.profiler.MemoryProfile.memory_profile_per_allocator', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_hosts', full_name='tensorflow.profiler.MemoryProfile.num_hosts', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_ids', full_name='tensorflow.profiler.MemoryProfile.memory_ids', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1281, serialized_end=1560)
_MEMORYACTIVITYMETADATA.fields_by_name['memory_activity'].enum_type = _MEMORYACTIVITY
_MEMORYPROFILESNAPSHOT.fields_by_name['aggregation_stats'].message_type = _MEMORYAGGREGATIONSTATS
_MEMORYPROFILESNAPSHOT.fields_by_name['activity_metadata'].message_type = _MEMORYACTIVITYMETADATA
_MEMORYPROFILESUMMARY.fields_by_name['peak_stats'].message_type = _MEMORYAGGREGATIONSTATS
_PERALLOCATORMEMORYPROFILE.fields_by_name['memory_profile_snapshots'].message_type = _MEMORYPROFILESNAPSHOT
_PERALLOCATORMEMORYPROFILE.fields_by_name['profile_summary'].message_type = _MEMORYPROFILESUMMARY
_PERALLOCATORMEMORYPROFILE.fields_by_name['active_allocations'].message_type = _ACTIVEALLOCATION
_PERALLOCATORMEMORYPROFILE.fields_by_name['special_allocations'].message_type = _MEMORYACTIVITYMETADATA
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY.fields_by_name['value'].message_type = _PERALLOCATORMEMORYPROFILE
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY.containing_type = _MEMORYPROFILE
_MEMORYPROFILE.fields_by_name['memory_profile_per_allocator'].message_type = _MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY
DESCRIPTOR.message_types_by_name['MemoryAggregationStats'] = _MEMORYAGGREGATIONSTATS
DESCRIPTOR.message_types_by_name['MemoryActivityMetadata'] = _MEMORYACTIVITYMETADATA
DESCRIPTOR.message_types_by_name['MemoryProfileSnapshot'] = _MEMORYPROFILESNAPSHOT
DESCRIPTOR.message_types_by_name['MemoryProfileSummary'] = _MEMORYPROFILESUMMARY
DESCRIPTOR.message_types_by_name['ActiveAllocation'] = _ACTIVEALLOCATION
DESCRIPTOR.message_types_by_name['PerAllocatorMemoryProfile'] = _PERALLOCATORMEMORYPROFILE
DESCRIPTOR.message_types_by_name['MemoryProfile'] = _MEMORYPROFILE
DESCRIPTOR.enum_types_by_name['MemoryActivity'] = _MEMORYACTIVITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
MemoryAggregationStats = _reflection.GeneratedProtocolMessageType('MemoryAggregationStats', (_message.Message,), {'DESCRIPTOR': _MEMORYAGGREGATIONSTATS, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryAggregationStats)
MemoryActivityMetadata = _reflection.GeneratedProtocolMessageType('MemoryActivityMetadata', (_message.Message,), {'DESCRIPTOR': _MEMORYACTIVITYMETADATA, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryActivityMetadata)
MemoryProfileSnapshot = _reflection.GeneratedProtocolMessageType('MemoryProfileSnapshot', (_message.Message,), {'DESCRIPTOR': _MEMORYPROFILESNAPSHOT, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryProfileSnapshot)
MemoryProfileSummary = _reflection.GeneratedProtocolMessageType('MemoryProfileSummary', (_message.Message,), {'DESCRIPTOR': _MEMORYPROFILESUMMARY, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryProfileSummary)
ActiveAllocation = _reflection.GeneratedProtocolMessageType('ActiveAllocation', (_message.Message,), {'DESCRIPTOR': _ACTIVEALLOCATION, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(ActiveAllocation)
PerAllocatorMemoryProfile = _reflection.GeneratedProtocolMessageType('PerAllocatorMemoryProfile', (_message.Message,), {'DESCRIPTOR': _PERALLOCATORMEMORYPROFILE, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(PerAllocatorMemoryProfile)
MemoryProfile = _reflection.GeneratedProtocolMessageType('MemoryProfile', (_message.Message,), {'MemoryProfilePerAllocatorEntry': _reflection.GeneratedProtocolMessageType('MemoryProfilePerAllocatorEntry', (_message.Message,), {'DESCRIPTOR': _MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'}), 'DESCRIPTOR': _MEMORYPROFILE, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryProfile)
_sym_db.RegisterMessage(MemoryProfile.MemoryProfilePerAllocatorEntry)
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY._options = None
