
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/grappler/optimizers/inference/batch_op_rewriter.proto', package='tensorflow.serving', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\nEtensorflow/core/grappler/optimizers/inference/batch_op_rewriter.proto\x12\x12tensorflow.serving\x1a\x1egoogle/protobuf/wrappers.proto"\xe1\x04\n\x14BatchOpRewriteConfig\x123\n+enable_adaptive_shared_batching_thread_pool\x18\x04 \x01(\x08\x12d\n\x17model_scheduler_options\x18\x01 \x03(\x0b2C.tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry\x1a\xa7\x02\n\x1cAdaptiveBatchSchedulerOption\x12@\n\x1amin_inflight_batches_limit\x18\x01 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x12D\n\x1einitial_inflight_batches_limit\x18\x02 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x12@\n\x1amax_inflight_batches_limit\x18\x03 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x12=\n\x17batches_to_average_over\x18\x04 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x1a\x83\x01\n\x1aModelSchedulerOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12T\n\x05value\x18\x02 \x01(\x0b2E.tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption:\x028\x01b\x06proto3', dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR])
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION = _descriptor.Descriptor(name='AdaptiveBatchSchedulerOption', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='min_inflight_batches_limit', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.min_inflight_batches_limit', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='initial_inflight_batches_limit', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.initial_inflight_batches_limit', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_inflight_batches_limit', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.max_inflight_batches_limit', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='batches_to_average_over', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.batches_to_average_over', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=306, serialized_end=601)
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY = _descriptor.Descriptor(name='ModelSchedulerOptionsEntry', full_name='tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=604, serialized_end=735)
_BATCHOPREWRITECONFIG = _descriptor.Descriptor(name='BatchOpRewriteConfig', full_name='tensorflow.serving.BatchOpRewriteConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='enable_adaptive_shared_batching_thread_pool', full_name='tensorflow.serving.BatchOpRewriteConfig.enable_adaptive_shared_batching_thread_pool', index=0, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='model_scheduler_options', full_name='tensorflow.serving.BatchOpRewriteConfig.model_scheduler_options', index=1, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION, _BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=126, serialized_end=735)
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['min_inflight_batches_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['initial_inflight_batches_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['max_inflight_batches_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['batches_to_average_over'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.containing_type = _BATCHOPREWRITECONFIG
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY.fields_by_name['value'].message_type = _BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY.containing_type = _BATCHOPREWRITECONFIG
_BATCHOPREWRITECONFIG.fields_by_name['model_scheduler_options'].message_type = _BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY
DESCRIPTOR.message_types_by_name['BatchOpRewriteConfig'] = _BATCHOPREWRITECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
BatchOpRewriteConfig = _reflection.GeneratedProtocolMessageType('BatchOpRewriteConfig', (_message.Message,), {'AdaptiveBatchSchedulerOption': _reflection.GeneratedProtocolMessageType('AdaptiveBatchSchedulerOption', (_message.Message,), {'DESCRIPTOR': _BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION, '__module__': 'tensorflow.core.grappler.optimizers.inference.batch_op_rewriter_pb2'}), 'ModelSchedulerOptionsEntry': _reflection.GeneratedProtocolMessageType('ModelSchedulerOptionsEntry', (_message.Message,), {'DESCRIPTOR': _BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY, '__module__': 'tensorflow.core.grappler.optimizers.inference.batch_op_rewriter_pb2'}), 'DESCRIPTOR': _BATCHOPREWRITECONFIG, '__module__': 'tensorflow.core.grappler.optimizers.inference.batch_op_rewriter_pb2'})
_sym_db.RegisterMessage(BatchOpRewriteConfig)
_sym_db.RegisterMessage(BatchOpRewriteConfig.AdaptiveBatchSchedulerOption)
_sym_db.RegisterMessage(BatchOpRewriteConfig.ModelSchedulerOptionsEntry)
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY._options = None
