
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....tensorflow.core.profiler.protobuf import op_metrics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/steps_db.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n0tensorflow/core/profiler/protobuf/steps_db.proto\x12\x13tensorflow.profiler\x1a\x19google/protobuf/any.proto\x1a2tensorflow/core/profiler/protobuf/op_metrics.proto"\x8d\x01\n\x14GenericStepBreakdown\x12F\n\x07type_ps\x18\x01 \x03(\x0b25.tensorflow.profiler.GenericStepBreakdown.TypePsEntry\x1a-\n\x0bTypePsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04:\x028\x01"V\n\x14DeviceMemoryTransfer\x12\x12\n\noccurrence\x18\x01 \x01(\x04\x12\x0f\n\x07time_us\x18\x02 \x01(\x01\x12\x19\n\x11bytes_transferred\x18\x03 \x01(\x04"\x8a\x01\n\x0eStepInfoResult\x12\x10\n\x08step_num\x18\x01 \x01(\r\x12\x11\n\tstep_name\x18\x05 \x01(\t\x12\x13\n\x0bduration_ps\x18\x02 \x01(\x04\x12\x10\n\x08begin_ps\x18\x03 \x01(\x04\x12,\n\x0estep_breakdown\x18\x04 \x01(\x0b2\x14.google.protobuf.Any"\xa7\x01\n\rFlowEventInfo\x12\x0f\n\x07flow_id\x18\x01 \x01(\x04\x12\x12\n\nchannel_id\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08category\x18\x04 \x01(\t\x12\x15\n\rstart_time_ps\x18\x05 \x01(\x04\x12\x13\n\x0bend_time_ps\x18\x06 \x01(\x04\x12\x11\n\tbyte_size\x18\x07 \x01(\x04\x12\x12\n\nreplica_id\x18\x08 \x01(\r"E\n\x0cFlowDbResult\x125\n\tflow_info\x18\x01 \x03(\x0b2".tensorflow.profiler.FlowEventInfo"\x7f\n\rAllReduceInfo\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rall_reduce_id\x18\x03 \x01(\x04\x12\x15\n\rstart_time_ps\x18\x04 \x01(\x04\x12\x13\n\x0bend_time_ps\x18\x05 \x01(\x04\x12\x11\n\tbyte_size\x18\x06 \x01(\x04"P\n\x11AllReduceDbResult\x12;\n\x0fall_reduce_info\x18\x01 \x03(\x0b2".tensorflow.profiler.AllReduceInfo"\xea\x06\n\x0fPerCoreStepInfo\x12\x10\n\x08step_num\x18\x01 \x01(\r\x12U\n\x12step_info_per_core\x18\x02 \x03(\x0b29.tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry\x128\n\x0ehlo_metrics_db\x18\x03 \x01(\x0b2 .tensorflow.profiler.OpMetricsDb\x12Q\n\x10flow_db_per_core\x18\x04 \x03(\x0b27.tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry\x12a\n\x19core_id_to_replica_id_map\x18\x05 \x03(\x0b2>.tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry\x12\\\n\x16all_reduce_db_per_core\x18\x06 \x03(\x0b2<.tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry\x12J\n\x17device_memory_transfers\x18\x07 \x03(\x0b2).tensorflow.profiler.DeviceMemoryTransfer\x1a[\n\x14StepInfoPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x122\n\x05value\x18\x02 \x01(\x0b2#.tensorflow.profiler.StepInfoResult:\x028\x01\x1aW\n\x12FlowDbPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x120\n\x05value\x18\x02 \x01(\x0b2!.tensorflow.profiler.FlowDbResult:\x028\x01\x1a;\n\x19CoreIdToReplicaIdMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r:\x028\x01\x1aa\n\x17AllReduceDbPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x125\n\x05value\x18\x02 \x01(\x0b2&.tensorflow.profiler.AllReduceDbResult:\x028\x01"\xa2\x01\n\x12StepDatabaseResult\x12;\n\rstep_sequence\x18\x01 \x03(\x0b2$.tensorflow.profiler.PerCoreStepInfo\x12\x1b\n\x13use_incomplete_step\x18\x02 \x01(\x08\x12\x19\n\x11num_steps_dropped\x18\x03 \x01(\r\x12\x17\n\x0fempty_intersect\x18\x04 \x01(\x08b\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2.DESCRIPTOR])
_GENERICSTEPBREAKDOWN_TYPEPSENTRY = _descriptor.Descriptor(name='TypePsEntry', full_name='tensorflow.profiler.GenericStepBreakdown.TypePsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.GenericStepBreakdown.TypePsEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.GenericStepBreakdown.TypePsEntry.value', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=249, serialized_end=294)
_GENERICSTEPBREAKDOWN = _descriptor.Descriptor(name='GenericStepBreakdown', full_name='tensorflow.profiler.GenericStepBreakdown', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_ps', full_name='tensorflow.profiler.GenericStepBreakdown.type_ps', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_GENERICSTEPBREAKDOWN_TYPEPSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=153, serialized_end=294)
_DEVICEMEMORYTRANSFER = _descriptor.Descriptor(name='DeviceMemoryTransfer', full_name='tensorflow.profiler.DeviceMemoryTransfer', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='occurrence', full_name='tensorflow.profiler.DeviceMemoryTransfer.occurrence', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='time_us', full_name='tensorflow.profiler.DeviceMemoryTransfer.time_us', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_transferred', full_name='tensorflow.profiler.DeviceMemoryTransfer.bytes_transferred', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=296, serialized_end=382)
_STEPINFORESULT = _descriptor.Descriptor(name='StepInfoResult', full_name='tensorflow.profiler.StepInfoResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.StepInfoResult.step_num', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_name', full_name='tensorflow.profiler.StepInfoResult.step_name', index=1, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ps', full_name='tensorflow.profiler.StepInfoResult.duration_ps', index=2, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='begin_ps', full_name='tensorflow.profiler.StepInfoResult.begin_ps', index=3, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown', full_name='tensorflow.profiler.StepInfoResult.step_breakdown', index=4, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=385, serialized_end=523)
_FLOWEVENTINFO = _descriptor.Descriptor(name='FlowEventInfo', full_name='tensorflow.profiler.FlowEventInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='flow_id', full_name='tensorflow.profiler.FlowEventInfo.flow_id', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='channel_id', full_name='tensorflow.profiler.FlowEventInfo.channel_id', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.FlowEventInfo.name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.FlowEventInfo.category', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time_ps', full_name='tensorflow.profiler.FlowEventInfo.start_time_ps', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_time_ps', full_name='tensorflow.profiler.FlowEventInfo.end_time_ps', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='byte_size', full_name='tensorflow.profiler.FlowEventInfo.byte_size', index=6, number=7, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='replica_id', full_name='tensorflow.profiler.FlowEventInfo.replica_id', index=7, number=8, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=526, serialized_end=693)
_FLOWDBRESULT = _descriptor.Descriptor(name='FlowDbResult', full_name='tensorflow.profiler.FlowDbResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='flow_info', full_name='tensorflow.profiler.FlowDbResult.flow_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=695, serialized_end=764)
_ALLREDUCEINFO = _descriptor.Descriptor(name='AllReduceInfo', full_name='tensorflow.profiler.AllReduceInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.AllReduceInfo.id', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.AllReduceInfo.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_reduce_id', full_name='tensorflow.profiler.AllReduceInfo.all_reduce_id', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time_ps', full_name='tensorflow.profiler.AllReduceInfo.start_time_ps', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_time_ps', full_name='tensorflow.profiler.AllReduceInfo.end_time_ps', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='byte_size', full_name='tensorflow.profiler.AllReduceInfo.byte_size', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=766, serialized_end=893)
_ALLREDUCEDBRESULT = _descriptor.Descriptor(name='AllReduceDbResult', full_name='tensorflow.profiler.AllReduceDbResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='all_reduce_info', full_name='tensorflow.profiler.AllReduceDbResult.all_reduce_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=895, serialized_end=975)
_PERCORESTEPINFO_STEPINFOPERCOREENTRY = _descriptor.Descriptor(name='StepInfoPerCoreEntry', full_name='tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1512, serialized_end=1603)
_PERCORESTEPINFO_FLOWDBPERCOREENTRY = _descriptor.Descriptor(name='FlowDbPerCoreEntry', full_name='tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1605, serialized_end=1692)
_PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY = _descriptor.Descriptor(name='CoreIdToReplicaIdMapEntry', full_name='tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry.value', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1694, serialized_end=1753)
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY = _descriptor.Descriptor(name='AllReduceDbPerCoreEntry', full_name='tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1755, serialized_end=1852)
_PERCORESTEPINFO = _descriptor.Descriptor(name='PerCoreStepInfo', full_name='tensorflow.profiler.PerCoreStepInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.PerCoreStepInfo.step_num', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_info_per_core', full_name='tensorflow.profiler.PerCoreStepInfo.step_info_per_core', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_metrics_db', full_name='tensorflow.profiler.PerCoreStepInfo.hlo_metrics_db', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flow_db_per_core', full_name='tensorflow.profiler.PerCoreStepInfo.flow_db_per_core', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_id_to_replica_id_map', full_name='tensorflow.profiler.PerCoreStepInfo.core_id_to_replica_id_map', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_reduce_db_per_core', full_name='tensorflow.profiler.PerCoreStepInfo.all_reduce_db_per_core', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_memory_transfers', full_name='tensorflow.profiler.PerCoreStepInfo.device_memory_transfers', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PERCORESTEPINFO_STEPINFOPERCOREENTRY, _PERCORESTEPINFO_FLOWDBPERCOREENTRY, _PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY, _PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=978, serialized_end=1852)
_STEPDATABASERESULT = _descriptor.Descriptor(name='StepDatabaseResult', full_name='tensorflow.profiler.StepDatabaseResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_sequence', full_name='tensorflow.profiler.StepDatabaseResult.step_sequence', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_incomplete_step', full_name='tensorflow.profiler.StepDatabaseResult.use_incomplete_step', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_steps_dropped', full_name='tensorflow.profiler.StepDatabaseResult.num_steps_dropped', index=2, number=3, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='empty_intersect', full_name='tensorflow.profiler.StepDatabaseResult.empty_intersect', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1855, serialized_end=2017)
_GENERICSTEPBREAKDOWN_TYPEPSENTRY.containing_type = _GENERICSTEPBREAKDOWN
_GENERICSTEPBREAKDOWN.fields_by_name['type_ps'].message_type = _GENERICSTEPBREAKDOWN_TYPEPSENTRY
_STEPINFORESULT.fields_by_name['step_breakdown'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FLOWDBRESULT.fields_by_name['flow_info'].message_type = _FLOWEVENTINFO
_ALLREDUCEDBRESULT.fields_by_name['all_reduce_info'].message_type = _ALLREDUCEINFO
_PERCORESTEPINFO_STEPINFOPERCOREENTRY.fields_by_name['value'].message_type = _STEPINFORESULT
_PERCORESTEPINFO_STEPINFOPERCOREENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO_FLOWDBPERCOREENTRY.fields_by_name['value'].message_type = _FLOWDBRESULT
_PERCORESTEPINFO_FLOWDBPERCOREENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY.fields_by_name['value'].message_type = _ALLREDUCEDBRESULT
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO.fields_by_name['step_info_per_core'].message_type = _PERCORESTEPINFO_STEPINFOPERCOREENTRY
_PERCORESTEPINFO.fields_by_name['hlo_metrics_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2._OPMETRICSDB
_PERCORESTEPINFO.fields_by_name['flow_db_per_core'].message_type = _PERCORESTEPINFO_FLOWDBPERCOREENTRY
_PERCORESTEPINFO.fields_by_name['core_id_to_replica_id_map'].message_type = _PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY
_PERCORESTEPINFO.fields_by_name['all_reduce_db_per_core'].message_type = _PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY
_PERCORESTEPINFO.fields_by_name['device_memory_transfers'].message_type = _DEVICEMEMORYTRANSFER
_STEPDATABASERESULT.fields_by_name['step_sequence'].message_type = _PERCORESTEPINFO
DESCRIPTOR.message_types_by_name['GenericStepBreakdown'] = _GENERICSTEPBREAKDOWN
DESCRIPTOR.message_types_by_name['DeviceMemoryTransfer'] = _DEVICEMEMORYTRANSFER
DESCRIPTOR.message_types_by_name['StepInfoResult'] = _STEPINFORESULT
DESCRIPTOR.message_types_by_name['FlowEventInfo'] = _FLOWEVENTINFO
DESCRIPTOR.message_types_by_name['FlowDbResult'] = _FLOWDBRESULT
DESCRIPTOR.message_types_by_name['AllReduceInfo'] = _ALLREDUCEINFO
DESCRIPTOR.message_types_by_name['AllReduceDbResult'] = _ALLREDUCEDBRESULT
DESCRIPTOR.message_types_by_name['PerCoreStepInfo'] = _PERCORESTEPINFO
DESCRIPTOR.message_types_by_name['StepDatabaseResult'] = _STEPDATABASERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
GenericStepBreakdown = _reflection.GeneratedProtocolMessageType('GenericStepBreakdown', (_message.Message,), {'TypePsEntry': _reflection.GeneratedProtocolMessageType('TypePsEntry', (_message.Message,), {'DESCRIPTOR': _GENERICSTEPBREAKDOWN_TYPEPSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'DESCRIPTOR': _GENERICSTEPBREAKDOWN, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(GenericStepBreakdown)
_sym_db.RegisterMessage(GenericStepBreakdown.TypePsEntry)
DeviceMemoryTransfer = _reflection.GeneratedProtocolMessageType('DeviceMemoryTransfer', (_message.Message,), {'DESCRIPTOR': _DEVICEMEMORYTRANSFER, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(DeviceMemoryTransfer)
StepInfoResult = _reflection.GeneratedProtocolMessageType('StepInfoResult', (_message.Message,), {'DESCRIPTOR': _STEPINFORESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(StepInfoResult)
FlowEventInfo = _reflection.GeneratedProtocolMessageType('FlowEventInfo', (_message.Message,), {'DESCRIPTOR': _FLOWEVENTINFO, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(FlowEventInfo)
FlowDbResult = _reflection.GeneratedProtocolMessageType('FlowDbResult', (_message.Message,), {'DESCRIPTOR': _FLOWDBRESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(FlowDbResult)
AllReduceInfo = _reflection.GeneratedProtocolMessageType('AllReduceInfo', (_message.Message,), {'DESCRIPTOR': _ALLREDUCEINFO, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(AllReduceInfo)
AllReduceDbResult = _reflection.GeneratedProtocolMessageType('AllReduceDbResult', (_message.Message,), {'DESCRIPTOR': _ALLREDUCEDBRESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(AllReduceDbResult)
PerCoreStepInfo = _reflection.GeneratedProtocolMessageType('PerCoreStepInfo', (_message.Message,), {'StepInfoPerCoreEntry': _reflection.GeneratedProtocolMessageType('StepInfoPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_STEPINFOPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'FlowDbPerCoreEntry': _reflection.GeneratedProtocolMessageType('FlowDbPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_FLOWDBPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'CoreIdToReplicaIdMapEntry': _reflection.GeneratedProtocolMessageType('CoreIdToReplicaIdMapEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'AllReduceDbPerCoreEntry': _reflection.GeneratedProtocolMessageType('AllReduceDbPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'DESCRIPTOR': _PERCORESTEPINFO, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(PerCoreStepInfo)
_sym_db.RegisterMessage(PerCoreStepInfo.StepInfoPerCoreEntry)
_sym_db.RegisterMessage(PerCoreStepInfo.FlowDbPerCoreEntry)
_sym_db.RegisterMessage(PerCoreStepInfo.CoreIdToReplicaIdMapEntry)
_sym_db.RegisterMessage(PerCoreStepInfo.AllReduceDbPerCoreEntry)
StepDatabaseResult = _reflection.GeneratedProtocolMessageType('StepDatabaseResult', (_message.Message,), {'DESCRIPTOR': _STEPDATABASERESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(StepDatabaseResult)
_GENERICSTEPBREAKDOWN_TYPEPSENTRY._options = None
_PERCORESTEPINFO_STEPINFOPERCOREENTRY._options = None
_PERCORESTEPINFO_FLOWDBPERCOREENTRY._options = None
_PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY._options = None
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY._options = None
