
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.compiler.tf2xla import host_compute_metadata_pb2 as tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2
from ....tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from ....tensorflow.compiler.xla import xla_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__pb2
from ....tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xrt/xrt.proto', package='xrt', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n!tensorflow/compiler/xrt/xrt.proto\x12\x03xrt\x1a6tensorflow/compiler/tf2xla/host_compute_metadata.proto\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a!tensorflow/compiler/xla/xla.proto\x1a&tensorflow/compiler/xla/xla_data.proto"\xee\x01\n\x10DeviceAssignment\x12D\n\x13computation_devices\x18\x01 \x03(\x0b2\'.xrt.DeviceAssignment.ComputationDevice\x1a\x93\x01\n\x11ComputationDevice\x12V\n\x0freplica_devices\x18\x01 \x03(\x0b2=.xrt.DeviceAssignment.ComputationDevice.DeviceMeshCoordinates\x1a&\n\x15DeviceMeshCoordinates\x12\r\n\x05value\x18\x01 \x03(\x05"\xaf\x04\n\x14XLAComputationConfig\x12\x14\n\x0cnum_replicas\x18\x01 \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\x02 \x01(\x05\x12E\n\x15host_compute_metadata\x18\x03 \x01(\x0b2&.tensorflow.tf2xla.HostComputeMetadata\x12-\n\rprogram_shape\x18\x04 \x01(\x0b2\x16.xla.ProgramShapeProto\x126\n\x16per_core_program_shape\x18\x05 \x03(\x0b2\x16.xla.ProgramShapeProto\x120\n\x11device_assignment\x18\x06 \x01(\x0b2\x15.xrt.DeviceAssignment\x12(\n\rdebug_options\x18\x07 \x01(\x0b2\x11.xla.DebugOptions\x12<\n\x0cexperimental\x18\x08 \x01(\x0b2&.xrt.XLAComputationConfig.Experimental\x1a\x99\x01\n\x0cExperimental\x12V\n\x16stateful_input_indices\x18\x01 \x03(\x0b26.xrt.XLAComputationConfig.Experimental.UpdateIndexPair\x1a1\n\x0fUpdateIndexPair\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07updated\x18\x02 \x01(\x08"c\n\x0eXLAComputation\x12)\n\x06config\x18\x01 \x01(\x0b2\x19.xrt.XLAComputationConfig\x12&\n\x0chlo_snapshot\x18\x02 \x01(\x0b2\x10.xla.HloSnapshot"7\n\rXLAAllocation\x12 \n\x05value\x18\x02 \x01(\x0b2\x11.xla.LiteralProtoJ\x04\x08\x01\x10\x02"d\n\x0cXLATupleNode\x12\x13\n\x0binput_index\x18\x01 \x01(\x05\x12\x1c\n\x14release_input_handle\x18\x02 \x01(\x08\x12!\n\x06tuples\x18\x03 \x03(\x0b2\x11.xrt.XLATupleNode"Z\n\x15CommonExecutionConfig\x12\x12\n\nreplica_id\x18\x01 \x01(\x05\x12\x1d\n\x15local_replica_mapping\x18\x02 \x03(\x05\x12\x0e\n\x06run_id\x18\x03 \x01(\x03"\x98\x02\n\x12XRTExecutionConfig\x12\x16\n\x0edevice_ordinal\x18\x01 \x01(\x05\x12\x1d\n\x15core_index_in_replica\x18\x02 \x01(\x05\x12\x1e\n\x16execution_instance_key\x18\x03 \x01(\t\x12\x10\n\x08rng_seed\x18\x04 \x01(\r\x12\x1d\n\x15release_input_handles\x18\x05 \x01(\x08\x12"\n\x1arelease_compilation_handle\x18\x06 \x01(\x08\x12\x1d\n\x15return_exploded_tuple\x18\x07 \x01(\x08\x121\n\rcommon_config\x18\t \x01(\x0b2\x1a.xrt.CommonExecutionConfigJ\x04\x08\x08\x10\t"\xa3\x01\n\x17XRTChainedExecuteConfig\x12\x10\n\x08rng_seed\x18\x01 \x01(\r\x12\x1d\n\x15core_index_in_replica\x18\x02 \x01(\x05\x12\x1e\n\x16execution_instance_key\x18\x03 \x01(\t\x121\n\rcommon_config\x18\x05 \x01(\x0b2\x1a.xrt.CommonExecutionConfigJ\x04\x08\x04\x10\x05"\x9f\x02\n\x13XRTChainedExecuteOp\x12\x15\n\x0bdata_handle\x18\x01 \x01(\x03H\x00\x12\x1c\n\x12computation_handle\x18\x02 \x01(\x03H\x00\x120\n\x07outputs\x18\x03 \x03(\x0b2\x1f.xrt.XRTChainedExecuteOp.Output\x12.\n\x06inputs\x18\x04 \x03(\x0b2\x1e.xrt.XRTChainedExecuteOp.Input\x1a/\n\x05Input\x12\x10\n\x08op_index\x18\x01 \x01(\x03\x12\x14\n\x0coutput_index\x18\x02 \x01(\x03\x1a4\n\x06Output\x12\x14\n\x0coutput_index\x18\x01 \x01(\x03\x12\x14\n\x0cresult_index\x18\x02 \x01(\x03B\n\n\x08op_oneof">\n\x15XRTChainedExecutePlan\x12%\n\x03ops\x18\x01 \x03(\x0b2\x18.xrt.XRTChainedExecuteOp"*\n\x11XRTMetricsCollect\x12\x15\n\rmetrics_regex\x18\x01 \x03(\t"\x90\x02\n\x0bPercentiles\x12\x14\n\x0cstart_nstime\x18\x01 \x01(\x04\x12\x12\n\nend_nstime\x18\x02 \x01(\x04\x12\x11\n\tmin_value\x18\x03 \x01(\x01\x12\x11\n\tmax_value\x18\x04 \x01(\x01\x12\x0c\n\x04mean\x18\x05 \x01(\x01\x12\x0e\n\x06stddev\x18\x06 \x01(\x01\x12\x13\n\x0bnum_samples\x18\x07 \x01(\x04\x12\x15\n\rtotal_samples\x18\x08 \x01(\x04\x12\x13\n\x0baccumulator\x18\t \x01(\x01\x12&\n\x06points\x18\n \x03(\x0b2\x16.xrt.Percentiles.Point\x1a*\n\x05Point\x12\x12\n\npercentile\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01"\xeb\x01\n\x0cMetricValues\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x11percentiles_value\x18\x02 \x01(\x0b2\x10.xrt.PercentilesH\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x128\n\x0funit_of_measure\x18\x04 \x01(\x0e2\x1f.xrt.MetricValues.UnitOfMeasure"=\n\rUnitOfMeasure\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x08\n\x04TIME\x10\x02\x12\t\n\x05BYTES\x10\x03B\x0e\n\x0cvalues_oneof"3\n\rMetricsReport\x12"\n\x07metrics\x18\x01 \x03(\x0b2\x11.xrt.MetricValues"/\n\nMemoryInfo\x12\x10\n\x08kb_total\x18\x01 \x01(\x03\x12\x0f\n\x07kb_free\x18\x02 \x01(\x03b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR])
_METRICVALUES_UNITOFMEASURE = _descriptor.EnumDescriptor(name='UnitOfMeasure', full_name='xrt.MetricValues.UnitOfMeasure', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='NUMBER', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TIME', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BYTES', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=2652, serialized_end=2713)
_sym_db.RegisterEnumDescriptor(_METRICVALUES_UNITOFMEASURE)
_DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES = _descriptor.Descriptor(name='DeviceMeshCoordinates', full_name='xrt.DeviceAssignment.ComputationDevice.DeviceMeshCoordinates', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='xrt.DeviceAssignment.ComputationDevice.DeviceMeshCoordinates.value', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=417, serialized_end=455)
_DEVICEASSIGNMENT_COMPUTATIONDEVICE = _descriptor.Descriptor(name='ComputationDevice', full_name='xrt.DeviceAssignment.ComputationDevice', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='replica_devices', full_name='xrt.DeviceAssignment.ComputationDevice.replica_devices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=308, serialized_end=455)
_DEVICEASSIGNMENT = _descriptor.Descriptor(name='DeviceAssignment', full_name='xrt.DeviceAssignment', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='computation_devices', full_name='xrt.DeviceAssignment.computation_devices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DEVICEASSIGNMENT_COMPUTATIONDEVICE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=217, serialized_end=455)
_XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR = _descriptor.Descriptor(name='UpdateIndexPair', full_name='xrt.XLAComputationConfig.Experimental.UpdateIndexPair', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='index', full_name='xrt.XLAComputationConfig.Experimental.UpdateIndexPair.index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='updated', full_name='xrt.XLAComputationConfig.Experimental.UpdateIndexPair.updated', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=968, serialized_end=1017)
_XLACOMPUTATIONCONFIG_EXPERIMENTAL = _descriptor.Descriptor(name='Experimental', full_name='xrt.XLAComputationConfig.Experimental', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='stateful_input_indices', full_name='xrt.XLAComputationConfig.Experimental.stateful_input_indices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=864, serialized_end=1017)
_XLACOMPUTATIONCONFIG = _descriptor.Descriptor(name='XLAComputationConfig', full_name='xrt.XLAComputationConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_replicas', full_name='xrt.XLAComputationConfig.num_replicas', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='xrt.XLAComputationConfig.num_cores_per_replica', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_metadata', full_name='xrt.XLAComputationConfig.host_compute_metadata', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='program_shape', full_name='xrt.XLAComputationConfig.program_shape', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='per_core_program_shape', full_name='xrt.XLAComputationConfig.per_core_program_shape', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='xrt.XLAComputationConfig.device_assignment', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_options', full_name='xrt.XLAComputationConfig.debug_options', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='experimental', full_name='xrt.XLAComputationConfig.experimental', index=7, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XLACOMPUTATIONCONFIG_EXPERIMENTAL], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=458, serialized_end=1017)
_XLACOMPUTATION = _descriptor.Descriptor(name='XLAComputation', full_name='xrt.XLAComputation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='config', full_name='xrt.XLAComputation.config', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_snapshot', full_name='xrt.XLAComputation.hlo_snapshot', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1019, serialized_end=1118)
_XLAALLOCATION = _descriptor.Descriptor(name='XLAAllocation', full_name='xrt.XLAAllocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='xrt.XLAAllocation.value', index=0, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1120, serialized_end=1175)
_XLATUPLENODE = _descriptor.Descriptor(name='XLATupleNode', full_name='xrt.XLATupleNode', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_index', full_name='xrt.XLATupleNode.input_index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_input_handle', full_name='xrt.XLATupleNode.release_input_handle', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tuples', full_name='xrt.XLATupleNode.tuples', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1177, serialized_end=1277)
_COMMONEXECUTIONCONFIG = _descriptor.Descriptor(name='CommonExecutionConfig', full_name='xrt.CommonExecutionConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='replica_id', full_name='xrt.CommonExecutionConfig.replica_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='local_replica_mapping', full_name='xrt.CommonExecutionConfig.local_replica_mapping', index=1, number=2, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_id', full_name='xrt.CommonExecutionConfig.run_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1279, serialized_end=1369)
_XRTEXECUTIONCONFIG = _descriptor.Descriptor(name='XRTExecutionConfig', full_name='xrt.XRTExecutionConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_ordinal', full_name='xrt.XRTExecutionConfig.device_ordinal', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_index_in_replica', full_name='xrt.XRTExecutionConfig.core_index_in_replica', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='execution_instance_key', full_name='xrt.XRTExecutionConfig.execution_instance_key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='rng_seed', full_name='xrt.XRTExecutionConfig.rng_seed', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_input_handles', full_name='xrt.XRTExecutionConfig.release_input_handles', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_compilation_handle', full_name='xrt.XRTExecutionConfig.release_compilation_handle', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='return_exploded_tuple', full_name='xrt.XRTExecutionConfig.return_exploded_tuple', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='common_config', full_name='xrt.XRTExecutionConfig.common_config', index=7, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1372, serialized_end=1652)
_XRTCHAINEDEXECUTECONFIG = _descriptor.Descriptor(name='XRTChainedExecuteConfig', full_name='xrt.XRTChainedExecuteConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='rng_seed', full_name='xrt.XRTChainedExecuteConfig.rng_seed', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_index_in_replica', full_name='xrt.XRTChainedExecuteConfig.core_index_in_replica', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='execution_instance_key', full_name='xrt.XRTChainedExecuteConfig.execution_instance_key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='common_config', full_name='xrt.XRTChainedExecuteConfig.common_config', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1655, serialized_end=1818)
_XRTCHAINEDEXECUTEOP_INPUT = _descriptor.Descriptor(name='Input', full_name='xrt.XRTChainedExecuteOp.Input', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_index', full_name='xrt.XRTChainedExecuteOp.Input.op_index', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_index', full_name='xrt.XRTChainedExecuteOp.Input.output_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1995, serialized_end=2042)
_XRTCHAINEDEXECUTEOP_OUTPUT = _descriptor.Descriptor(name='Output', full_name='xrt.XRTChainedExecuteOp.Output', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='output_index', full_name='xrt.XRTChainedExecuteOp.Output.output_index', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='result_index', full_name='xrt.XRTChainedExecuteOp.Output.result_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2044, serialized_end=2096)
_XRTCHAINEDEXECUTEOP = _descriptor.Descriptor(name='XRTChainedExecuteOp', full_name='xrt.XRTChainedExecuteOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data_handle', full_name='xrt.XRTChainedExecuteOp.data_handle', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='computation_handle', full_name='xrt.XRTChainedExecuteOp.computation_handle', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='outputs', full_name='xrt.XRTChainedExecuteOp.outputs', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inputs', full_name='xrt.XRTChainedExecuteOp.inputs', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XRTCHAINEDEXECUTEOP_INPUT, _XRTCHAINEDEXECUTEOP_OUTPUT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='op_oneof', full_name='xrt.XRTChainedExecuteOp.op_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1821, serialized_end=2108)
_XRTCHAINEDEXECUTEPLAN = _descriptor.Descriptor(name='XRTChainedExecutePlan', full_name='xrt.XRTChainedExecutePlan', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='ops', full_name='xrt.XRTChainedExecutePlan.ops', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2110, serialized_end=2172)
_XRTMETRICSCOLLECT = _descriptor.Descriptor(name='XRTMetricsCollect', full_name='xrt.XRTMetricsCollect', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metrics_regex', full_name='xrt.XRTMetricsCollect.metrics_regex', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2174, serialized_end=2216)
_PERCENTILES_POINT = _descriptor.Descriptor(name='Point', full_name='xrt.Percentiles.Point', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='percentile', full_name='xrt.Percentiles.Point.percentile', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='xrt.Percentiles.Point.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2449, serialized_end=2491)
_PERCENTILES = _descriptor.Descriptor(name='Percentiles', full_name='xrt.Percentiles', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='start_nstime', full_name='xrt.Percentiles.start_nstime', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_nstime', full_name='xrt.Percentiles.end_nstime', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='min_value', full_name='xrt.Percentiles.min_value', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_value', full_name='xrt.Percentiles.max_value', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mean', full_name='xrt.Percentiles.mean', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stddev', full_name='xrt.Percentiles.stddev', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_samples', full_name='xrt.Percentiles.num_samples', index=6, number=7, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_samples', full_name='xrt.Percentiles.total_samples', index=7, number=8, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='accumulator', full_name='xrt.Percentiles.accumulator', index=8, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='points', full_name='xrt.Percentiles.points', index=9, number=10, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PERCENTILES_POINT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2219, serialized_end=2491)
_METRICVALUES = _descriptor.Descriptor(name='MetricValues', full_name='xrt.MetricValues', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='xrt.MetricValues.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='percentiles_value', full_name='xrt.MetricValues.percentiles_value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int64_value', full_name='xrt.MetricValues.int64_value', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unit_of_measure', full_name='xrt.MetricValues.unit_of_measure', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_METRICVALUES_UNITOFMEASURE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='values_oneof', full_name='xrt.MetricValues.values_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=2494, serialized_end=2729)
_METRICSREPORT = _descriptor.Descriptor(name='MetricsReport', full_name='xrt.MetricsReport', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metrics', full_name='xrt.MetricsReport.metrics', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2731, serialized_end=2782)
_MEMORYINFO = _descriptor.Descriptor(name='MemoryInfo', full_name='xrt.MemoryInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kb_total', full_name='xrt.MemoryInfo.kb_total', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kb_free', full_name='xrt.MemoryInfo.kb_free', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2784, serialized_end=2831)
_DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES.containing_type = _DEVICEASSIGNMENT_COMPUTATIONDEVICE
_DEVICEASSIGNMENT_COMPUTATIONDEVICE.fields_by_name['replica_devices'].message_type = _DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES
_DEVICEASSIGNMENT_COMPUTATIONDEVICE.containing_type = _DEVICEASSIGNMENT
_DEVICEASSIGNMENT.fields_by_name['computation_devices'].message_type = _DEVICEASSIGNMENT_COMPUTATIONDEVICE
_XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR.containing_type = _XLACOMPUTATIONCONFIG_EXPERIMENTAL
_XLACOMPUTATIONCONFIG_EXPERIMENTAL.fields_by_name['stateful_input_indices'].message_type = _XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR
_XLACOMPUTATIONCONFIG_EXPERIMENTAL.containing_type = _XLACOMPUTATIONCONFIG
_XLACOMPUTATIONCONFIG.fields_by_name['host_compute_metadata'].message_type = tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2._HOSTCOMPUTEMETADATA
_XLACOMPUTATIONCONFIG.fields_by_name['program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_XLACOMPUTATIONCONFIG.fields_by_name['per_core_program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_XLACOMPUTATIONCONFIG.fields_by_name['device_assignment'].message_type = _DEVICEASSIGNMENT
_XLACOMPUTATIONCONFIG.fields_by_name['debug_options'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__pb2._DEBUGOPTIONS
_XLACOMPUTATIONCONFIG.fields_by_name['experimental'].message_type = _XLACOMPUTATIONCONFIG_EXPERIMENTAL
_XLACOMPUTATION.fields_by_name['config'].message_type = _XLACOMPUTATIONCONFIG
_XLACOMPUTATION.fields_by_name['hlo_snapshot'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOSNAPSHOT
_XLAALLOCATION.fields_by_name['value'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LITERALPROTO
_XLATUPLENODE.fields_by_name['tuples'].message_type = _XLATUPLENODE
_XRTEXECUTIONCONFIG.fields_by_name['common_config'].message_type = _COMMONEXECUTIONCONFIG
_XRTCHAINEDEXECUTECONFIG.fields_by_name['common_config'].message_type = _COMMONEXECUTIONCONFIG
_XRTCHAINEDEXECUTEOP_INPUT.containing_type = _XRTCHAINEDEXECUTEOP
_XRTCHAINEDEXECUTEOP_OUTPUT.containing_type = _XRTCHAINEDEXECUTEOP
_XRTCHAINEDEXECUTEOP.fields_by_name['outputs'].message_type = _XRTCHAINEDEXECUTEOP_OUTPUT
_XRTCHAINEDEXECUTEOP.fields_by_name['inputs'].message_type = _XRTCHAINEDEXECUTEOP_INPUT
_XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof'].fields.append(_XRTCHAINEDEXECUTEOP.fields_by_name['data_handle'])
_XRTCHAINEDEXECUTEOP.fields_by_name['data_handle'].containing_oneof = _XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof']
_XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof'].fields.append(_XRTCHAINEDEXECUTEOP.fields_by_name['computation_handle'])
_XRTCHAINEDEXECUTEOP.fields_by_name['computation_handle'].containing_oneof = _XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof']
_XRTCHAINEDEXECUTEPLAN.fields_by_name['ops'].message_type = _XRTCHAINEDEXECUTEOP
_PERCENTILES_POINT.containing_type = _PERCENTILES
_PERCENTILES.fields_by_name['points'].message_type = _PERCENTILES_POINT
_METRICVALUES.fields_by_name['percentiles_value'].message_type = _PERCENTILES
_METRICVALUES.fields_by_name['unit_of_measure'].enum_type = _METRICVALUES_UNITOFMEASURE
_METRICVALUES_UNITOFMEASURE.containing_type = _METRICVALUES
_METRICVALUES.oneofs_by_name['values_oneof'].fields.append(_METRICVALUES.fields_by_name['percentiles_value'])
_METRICVALUES.fields_by_name['percentiles_value'].containing_oneof = _METRICVALUES.oneofs_by_name['values_oneof']
_METRICVALUES.oneofs_by_name['values_oneof'].fields.append(_METRICVALUES.fields_by_name['int64_value'])
_METRICVALUES.fields_by_name['int64_value'].containing_oneof = _METRICVALUES.oneofs_by_name['values_oneof']
_METRICSREPORT.fields_by_name['metrics'].message_type = _METRICVALUES
DESCRIPTOR.message_types_by_name['DeviceAssignment'] = _DEVICEASSIGNMENT
DESCRIPTOR.message_types_by_name['XLAComputationConfig'] = _XLACOMPUTATIONCONFIG
DESCRIPTOR.message_types_by_name['XLAComputation'] = _XLACOMPUTATION
DESCRIPTOR.message_types_by_name['XLAAllocation'] = _XLAALLOCATION
DESCRIPTOR.message_types_by_name['XLATupleNode'] = _XLATUPLENODE
DESCRIPTOR.message_types_by_name['CommonExecutionConfig'] = _COMMONEXECUTIONCONFIG
DESCRIPTOR.message_types_by_name['XRTExecutionConfig'] = _XRTEXECUTIONCONFIG
DESCRIPTOR.message_types_by_name['XRTChainedExecuteConfig'] = _XRTCHAINEDEXECUTECONFIG
DESCRIPTOR.message_types_by_name['XRTChainedExecuteOp'] = _XRTCHAINEDEXECUTEOP
DESCRIPTOR.message_types_by_name['XRTChainedExecutePlan'] = _XRTCHAINEDEXECUTEPLAN
DESCRIPTOR.message_types_by_name['XRTMetricsCollect'] = _XRTMETRICSCOLLECT
DESCRIPTOR.message_types_by_name['Percentiles'] = _PERCENTILES
DESCRIPTOR.message_types_by_name['MetricValues'] = _METRICVALUES
DESCRIPTOR.message_types_by_name['MetricsReport'] = _METRICSREPORT
DESCRIPTOR.message_types_by_name['MemoryInfo'] = _MEMORYINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DeviceAssignment = _reflection.GeneratedProtocolMessageType('DeviceAssignment', (_message.Message,), {'ComputationDevice': _reflection.GeneratedProtocolMessageType('ComputationDevice', (_message.Message,), {'DeviceMeshCoordinates': _reflection.GeneratedProtocolMessageType('DeviceMeshCoordinates', (_message.Message,), {'DESCRIPTOR': _DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _DEVICEASSIGNMENT_COMPUTATIONDEVICE, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _DEVICEASSIGNMENT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(DeviceAssignment)
_sym_db.RegisterMessage(DeviceAssignment.ComputationDevice)
_sym_db.RegisterMessage(DeviceAssignment.ComputationDevice.DeviceMeshCoordinates)
XLAComputationConfig = _reflection.GeneratedProtocolMessageType('XLAComputationConfig', (_message.Message,), {'Experimental': _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {'UpdateIndexPair': _reflection.GeneratedProtocolMessageType('UpdateIndexPair', (_message.Message,), {'DESCRIPTOR': _XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _XLACOMPUTATIONCONFIG_EXPERIMENTAL, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _XLACOMPUTATIONCONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLAComputationConfig)
_sym_db.RegisterMessage(XLAComputationConfig.Experimental)
_sym_db.RegisterMessage(XLAComputationConfig.Experimental.UpdateIndexPair)
XLAComputation = _reflection.GeneratedProtocolMessageType('XLAComputation', (_message.Message,), {'DESCRIPTOR': _XLACOMPUTATION, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLAComputation)
XLAAllocation = _reflection.GeneratedProtocolMessageType('XLAAllocation', (_message.Message,), {'DESCRIPTOR': _XLAALLOCATION, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLAAllocation)
XLATupleNode = _reflection.GeneratedProtocolMessageType('XLATupleNode', (_message.Message,), {'DESCRIPTOR': _XLATUPLENODE, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLATupleNode)
CommonExecutionConfig = _reflection.GeneratedProtocolMessageType('CommonExecutionConfig', (_message.Message,), {'DESCRIPTOR': _COMMONEXECUTIONCONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(CommonExecutionConfig)
XRTExecutionConfig = _reflection.GeneratedProtocolMessageType('XRTExecutionConfig', (_message.Message,), {'DESCRIPTOR': _XRTEXECUTIONCONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTExecutionConfig)
XRTChainedExecuteConfig = _reflection.GeneratedProtocolMessageType('XRTChainedExecuteConfig', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTECONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTChainedExecuteConfig)
XRTChainedExecuteOp = _reflection.GeneratedProtocolMessageType('XRTChainedExecuteOp', (_message.Message,), {'Input': _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTEOP_INPUT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'Output': _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTEOP_OUTPUT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _XRTCHAINEDEXECUTEOP, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTChainedExecuteOp)
_sym_db.RegisterMessage(XRTChainedExecuteOp.Input)
_sym_db.RegisterMessage(XRTChainedExecuteOp.Output)
XRTChainedExecutePlan = _reflection.GeneratedProtocolMessageType('XRTChainedExecutePlan', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTEPLAN, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTChainedExecutePlan)
XRTMetricsCollect = _reflection.GeneratedProtocolMessageType('XRTMetricsCollect', (_message.Message,), {'DESCRIPTOR': _XRTMETRICSCOLLECT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTMetricsCollect)
Percentiles = _reflection.GeneratedProtocolMessageType('Percentiles', (_message.Message,), {'Point': _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {'DESCRIPTOR': _PERCENTILES_POINT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _PERCENTILES, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(Percentiles)
_sym_db.RegisterMessage(Percentiles.Point)
MetricValues = _reflection.GeneratedProtocolMessageType('MetricValues', (_message.Message,), {'DESCRIPTOR': _METRICVALUES, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(MetricValues)
MetricsReport = _reflection.GeneratedProtocolMessageType('MetricsReport', (_message.Message,), {'DESCRIPTOR': _METRICSREPORT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(MetricsReport)
MemoryInfo = _reflection.GeneratedProtocolMessageType('MemoryInfo', (_message.Message,), {'DESCRIPTOR': _MEMORYINFO, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(MemoryInfo)
