
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import worker_pb2 as tensorflow_dot_core_dot_protobuf_dot_worker__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/worker_service.proto', package='tensorflow.grpc', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\x13WorkerServiceProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/protobuf/worker_service.proto\x12\x0ftensorflow.grpc\x1a%tensorflow/core/protobuf/worker.proto2\xf0\t\n\rWorkerService\x12H\n\tGetStatus\x12\x1c.tensorflow.GetStatusRequest\x1a\x1d.tensorflow.GetStatusResponse\x12f\n\x13CreateWorkerSession\x12&.tensorflow.CreateWorkerSessionRequest\x1a\'.tensorflow.CreateWorkerSessionResponse\x12f\n\x13DeleteWorkerSession\x12&.tensorflow.DeleteWorkerSessionRequest\x1a\'.tensorflow.DeleteWorkerSessionResponse\x12T\n\rRegisterGraph\x12 .tensorflow.RegisterGraphRequest\x1a!.tensorflow.RegisterGraphResponse\x12Z\n\x0fDeregisterGraph\x12".tensorflow.DeregisterGraphRequest\x1a#.tensorflow.DeregisterGraphResponse\x12E\n\x08RunGraph\x12\x1b.tensorflow.RunGraphRequest\x1a\x1c.tensorflow.RunGraphResponse\x12Q\n\x0cCleanupGraph\x12\x1f.tensorflow.CleanupGraphRequest\x1a .tensorflow.CleanupGraphResponse\x12K\n\nCleanupAll\x12\x1d.tensorflow.CleanupAllRequest\x1a\x1e.tensorflow.CleanupAllResponse\x12M\n\nRecvTensor\x12\x1d.tensorflow.RecvTensorRequest\x1a\x1e.tensorflow.RecvTensorResponse"\x00\x12B\n\x07Logging\x12\x1a.tensorflow.LoggingRequest\x1a\x1b.tensorflow.LoggingResponse\x12B\n\x07Tracing\x12\x1a.tensorflow.TracingRequest\x1a\x1b.tensorflow.TracingResponse\x12D\n\x07RecvBuf\x12\x1a.tensorflow.RecvBufRequest\x1a\x1b.tensorflow.RecvBufResponse"\x00\x12Z\n\x0fGetStepSequence\x12".tensorflow.GetStepSequenceRequest\x1a#.tensorflow.GetStepSequenceResponse\x12T\n\rCompleteGroup\x12 .tensorflow.CompleteGroupRequest\x1a!.tensorflow.CompleteGroupResponse\x12]\n\x10CompleteInstance\x12#.tensorflow.CompleteInstanceRequest\x1a$.tensorflow.CompleteInstanceResponseB\x8a\x01\n\x1aorg.tensorflow.distruntimeB\x13WorkerServiceProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_worker__pb2.DESCRIPTOR])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DESCRIPTOR._options = None
_WORKERSERVICE = _descriptor.ServiceDescriptor(name='WorkerService', full_name='tensorflow.grpc.WorkerService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=106, serialized_end=1370, methods=[_descriptor.MethodDescriptor(name='GetStatus', full_name='tensorflow.grpc.WorkerService.GetStatus', index=0, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTATUSREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTATUSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CreateWorkerSession', full_name='tensorflow.grpc.WorkerService.CreateWorkerSession', index=1, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CREATEWORKERSESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CREATEWORKERSESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='DeleteWorkerSession', full_name='tensorflow.grpc.WorkerService.DeleteWorkerSession', index=2, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DELETEWORKERSESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DELETEWORKERSESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RegisterGraph', full_name='tensorflow.grpc.WorkerService.RegisterGraph', index=3, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._REGISTERGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._REGISTERGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='DeregisterGraph', full_name='tensorflow.grpc.WorkerService.DeregisterGraph', index=4, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DEREGISTERGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DEREGISTERGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RunGraph', full_name='tensorflow.grpc.WorkerService.RunGraph', index=5, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RUNGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RUNGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CleanupGraph', full_name='tensorflow.grpc.WorkerService.CleanupGraph', index=6, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CleanupAll', full_name='tensorflow.grpc.WorkerService.CleanupAll', index=7, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPALLREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPALLRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RecvTensor', full_name='tensorflow.grpc.WorkerService.RecvTensor', index=8, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVTENSORREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVTENSORRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Logging', full_name='tensorflow.grpc.WorkerService.Logging', index=9, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._LOGGINGREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._LOGGINGRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Tracing', full_name='tensorflow.grpc.WorkerService.Tracing', index=10, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._TRACINGREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._TRACINGRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RecvBuf', full_name='tensorflow.grpc.WorkerService.RecvBuf', index=11, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVBUFREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVBUFRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetStepSequence', full_name='tensorflow.grpc.WorkerService.GetStepSequence', index=12, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTEPSEQUENCEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTEPSEQUENCERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CompleteGroup', full_name='tensorflow.grpc.WorkerService.CompleteGroup', index=13, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEGROUPREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEGROUPRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CompleteInstance', full_name='tensorflow.grpc.WorkerService.CompleteInstance', index=14, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEINSTANCEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEINSTANCERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_WORKERSERVICE)
DESCRIPTOR.services_by_name['WorkerService'] = _WORKERSERVICE
