
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/python/tpu/tensor_tracer.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/python/tpu/tensor_tracer.proto\x12\ntensorflow\x1a%tensorflow/core/framework/graph.proto"\xfb\x04\n\x12TensorTracerReport\x12A\n\x06config\x18\x01 \x01(\x0b21.tensorflow.TensorTracerReport.TensorTracerConfig\x12&\n\x08graphdef\x18\x02 \x01(\x0b2\x14.tensorflow.GraphDef\x12@\n\ttensordef\x18\x03 \x03(\x0b2-.tensorflow.TensorTracerReport.TensordefEntry\x12\x13\n\x0bfingerprint\x18\x04 \x01(\t\x1a`\n\x0eTensordefEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b2..tensorflow.TensorTracerReport.TracedTensorDef:\x028\x01\x1a\xc8\x01\n\x12TensorTracerConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0e\n\x06device\x18\x02 \x01(\t\x12\x12\n\ntrace_mode\x18\x03 \x01(\t\x12\x11\n\tnum_cores\x18\x04 \x01(\x05\x12\x11\n\tnum_hosts\x18\x05 \x01(\x05\x12\x0f\n\x07submode\x18\x06 \x01(\t\x12\x1a\n\x12num_cores_per_host\x18\x07 \x01(\x05\x12\x16\n\x0eincluded_cores\x18\x08 \x03(\x05\x12\x12\n\nsignatures\x18\t \x03(\t\x1av\n\x0fTracedTensorDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bcache_index\x18\x02 \x01(\x05\x12\x18\n\x10trace_point_name\x18\x03 \x01(\t\x12\x11\n\tis_traced\x18\x04 \x01(\x08\x12\x13\n\x0bexplanation\x18\x05 \x01(\tb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR])
_TENSORTRACERREPORT_TENSORDEFENTRY = _descriptor.Descriptor(name='TensordefEntry', full_name='tensorflow.TensorTracerReport.TensordefEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.TensorTracerReport.TensordefEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.TensorTracerReport.TensordefEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=313, serialized_end=409)
_TENSORTRACERREPORT_TENSORTRACERCONFIG = _descriptor.Descriptor(name='TensorTracerConfig', full_name='tensorflow.TensorTracerReport.TensorTracerConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='version', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.version', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.device', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trace_mode', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.trace_mode', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.num_cores', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_hosts', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.num_hosts', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='submode', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.submode', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_host', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.num_cores_per_host', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='included_cores', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.included_cores', index=7, number=8, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='signatures', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.signatures', index=8, number=9, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=412, serialized_end=612)
_TENSORTRACERREPORT_TRACEDTENSORDEF = _descriptor.Descriptor(name='TracedTensorDef', full_name='tensorflow.TensorTracerReport.TracedTensorDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.TensorTracerReport.TracedTensorDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cache_index', full_name='tensorflow.TensorTracerReport.TracedTensorDef.cache_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trace_point_name', full_name='tensorflow.TensorTracerReport.TracedTensorDef.trace_point_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_traced', full_name='tensorflow.TensorTracerReport.TracedTensorDef.is_traced', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='explanation', full_name='tensorflow.TensorTracerReport.TracedTensorDef.explanation', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=614, serialized_end=732)
_TENSORTRACERREPORT = _descriptor.Descriptor(name='TensorTracerReport', full_name='tensorflow.TensorTracerReport', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='config', full_name='tensorflow.TensorTracerReport.config', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graphdef', full_name='tensorflow.TensorTracerReport.graphdef', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensordef', full_name='tensorflow.TensorTracerReport.tensordef', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fingerprint', full_name='tensorflow.TensorTracerReport.fingerprint', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TENSORTRACERREPORT_TENSORDEFENTRY, _TENSORTRACERREPORT_TENSORTRACERCONFIG, _TENSORTRACERREPORT_TRACEDTENSORDEF], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=97, serialized_end=732)
_TENSORTRACERREPORT_TENSORDEFENTRY.fields_by_name['value'].message_type = _TENSORTRACERREPORT_TRACEDTENSORDEF
_TENSORTRACERREPORT_TENSORDEFENTRY.containing_type = _TENSORTRACERREPORT
_TENSORTRACERREPORT_TENSORTRACERCONFIG.containing_type = _TENSORTRACERREPORT
_TENSORTRACERREPORT_TRACEDTENSORDEF.containing_type = _TENSORTRACERREPORT
_TENSORTRACERREPORT.fields_by_name['config'].message_type = _TENSORTRACERREPORT_TENSORTRACERCONFIG
_TENSORTRACERREPORT.fields_by_name['graphdef'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_TENSORTRACERREPORT.fields_by_name['tensordef'].message_type = _TENSORTRACERREPORT_TENSORDEFENTRY
DESCRIPTOR.message_types_by_name['TensorTracerReport'] = _TENSORTRACERREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorTracerReport = _reflection.GeneratedProtocolMessageType('TensorTracerReport', (_message.Message,), {'TensordefEntry': _reflection.GeneratedProtocolMessageType('TensordefEntry', (_message.Message,), {'DESCRIPTOR': _TENSORTRACERREPORT_TENSORDEFENTRY, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'}), 'TensorTracerConfig': _reflection.GeneratedProtocolMessageType('TensorTracerConfig', (_message.Message,), {'DESCRIPTOR': _TENSORTRACERREPORT_TENSORTRACERCONFIG, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'}), 'TracedTensorDef': _reflection.GeneratedProtocolMessageType('TracedTensorDef', (_message.Message,), {'DESCRIPTOR': _TENSORTRACERREPORT_TRACEDTENSORDEF, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'}), 'DESCRIPTOR': _TENSORTRACERREPORT, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'})
_sym_db.RegisterMessage(TensorTracerReport)
_sym_db.RegisterMessage(TensorTracerReport.TensordefEntry)
_sym_db.RegisterMessage(TensorTracerReport.TensorTracerConfig)
_sym_db.RegisterMessage(TensorTracerReport.TracedTensorDef)
_TENSORTRACERREPORT_TENSORDEFENTRY._options = None
