
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......tensorflow.compiler.xla.python.tpu_driver import tpu_driver_pb2 as tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2
from ......tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from ......tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/python/tpu_driver/tpu_service.proto', package='tpu_driver', syntax='proto2', serialized_options=b'H\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n;tensorflow/compiler/xla/python/tpu_driver/tpu_service.proto\x12\ntpu_driver\x1a:tensorflow/compiler/xla/python/tpu_driver/tpu_driver.proto\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a&tensorflow/compiler/xla/xla_data.proto".\n\rStatusMessage\x12\x0c\n\x04code\x18\x01 \x02(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t"\x8b\x01\n\x0fAllocateRequest\x12\x0f\n\x07core_id\x18\x01 \x02(\x05\x12(\n\x06region\x18\x02 \x02(\x0e2\x18.tpu_driver.MemoryRegion\x12\x13\n\tnum_bytes\x18\x03 \x01(\x03H\x00\x12 \n\x05shape\x18\x04 \x01(\x0b2\x0f.xla.ShapeProtoH\x00B\x06\n\x04size"c\n\x14AllocateTupleRequest\x12\x0f\n\x07core_id\x18\x01 \x02(\x05\x12(\n\x06region\x18\x02 \x02(\x0e2\x18.tpu_driver.MemoryRegion\x12\x10\n\x08children\x18\x03 \x03(\x03"#\n\x11DeallocateRequest\x12\x0e\n\x06handle\x18\x01 \x02(\x03">\n\x17TransferToDeviceRequest\x12\x15\n\rtarget_handle\x18\x01 \x02(\x03\x12\x0c\n\x04data\x18\x02 \x02(\x0c"2\n\x19TransferFromDeviceRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x03"*\n\x1aTransferFromDeviceResponse\x12\x0c\n\x04data\x18\x02 \x02(\x0c"Q\n!TransferFromDeviceToDeviceRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x03\x12\x15\n\rtarget_handle\x18\x02 \x02(\x03"J\n\x0eCompileRequest\x12"\n\x0bhlo_program\x18\x01 \x02(\x0b2\r.xla.HloProto\x12\x14\n\x0cnum_replicas\x18\x02 \x01(\x03"H\n\x17CompiledProgramMetadata\x12-\n\rprogram_shape\x18\x01 \x02(\x0b2\x16.xla.ProgramShapeProto"H\n\x0fCompileResponse\x125\n\x08metadata\x18\x01 \x02(\x0b2#.tpu_driver.CompiledProgramMetadata"F\n\x12LoadProgramRequest\x12\x0f\n\x07core_id\x18\x01 \x02(\x05\x12\x1f\n\x17compiled_program_handle\x18\x02 \x02(\x03"5\n\x14UnloadProgramRequest\x12\x1d\n\x15loaded_program_handle\x18\x01 \x02(\x03"\x93\x01\n\x0eExecuteRequest\x12\x1d\n\x15loaded_program_handle\x18\x01 \x02(\x03\x12\x14\n\x0cinput_handle\x18\x02 \x03(\x03\x12\x15\n\routput_handle\x18\x03 \x03(\x03\x125\n\x11device_assignment\x18\x04 \x01(\x0b2\x1a.xla.DeviceAssignmentProto"\xb4\x05\n\rStreamRequest\x12.\n\x05entry\x18\x1e \x03(\x0b2\x1f.tpu_driver.StreamRequest.Entry\x1a\xf2\x04\n\x05Entry\x12,\n\x05alloc\x18\x01 \x01(\x0b2\x1b.tpu_driver.AllocateRequestH\x00\x127\n\x0balloc_tuple\x18\x02 \x01(\x0b2 .tpu_driver.AllocateTupleRequestH\x00\x120\n\x07dealloc\x18\x03 \x01(\x0b2\x1d.tpu_driver.DeallocateRequestH\x00\x12:\n\x0btransfer_to\x18\x04 \x01(\x0b2#.tpu_driver.TransferToDeviceRequestH\x00\x12>\n\rtransfer_from\x18\x05 \x01(\x0b2%.tpu_driver.TransferFromDeviceRequestH\x00\x12I\n\x10transfer_from_to\x18\n \x01(\x0b2-.tpu_driver.TransferFromDeviceToDeviceRequestH\x00\x12-\n\x07compile\x18\x06 \x01(\x0b2\x1a.tpu_driver.CompileRequestH\x00\x12.\n\x04load\x18\x07 \x01(\x0b2\x1e.tpu_driver.LoadProgramRequestH\x00\x122\n\x06unload\x18\x08 \x01(\x0b2 .tpu_driver.UnloadProgramRequestH\x00\x12-\n\x07execute\x18\t \x01(\x0b2\x1a.tpu_driver.ExecuteRequestH\x00\x12\x13\n\x0bwait_for_id\x18\x14 \x03(\x03\x12\x14\n\x0coperation_id\x18\x15 \x02(\x03\x12\x11\n\tthread_id\x18\x16 \x01(\x03B\t\n\x07request"\x89\x02\n\x0eStreamResponse\x12/\n\x05entry\x18\x14 \x03(\x0b2 .tpu_driver.StreamResponse.Entry\x1a\xc5\x01\n\x05Entry\x12?\n\rtransfer_from\x18\x03 \x01(\x0b2&.tpu_driver.TransferFromDeviceResponseH\x00\x12.\n\x07compile\x18\x04 \x01(\x0b2\x1b.tpu_driver.CompileResponseH\x00\x12)\n\x06status\x18\n \x02(\x0b2\x19.tpu_driver.StatusMessage\x12\x14\n\x0coperation_id\x18\x0b \x02(\x03B\n\n\x08response"(\n\x0bOpenRequest\x12\x19\n\x0eclient_version\x18\x01 \x01(\x05:\x010"F\n\x0cOpenResponse\x12\x11\n\tclient_id\x18\x01 \x02(\r\x12#\n\x15max_idle_time_seconds\x18\x02 \x01(\x05:\x043600"!\n\x0cCloseRequest\x12\x11\n\tclient_id\x18\x01 \x02(\x07"\x0f\n\rCloseResponse"\x0e\n\x0cResetRequest"\x0f\n\rResetResponse"\x18\n\x16QuerySystemInfoRequest"F\n\x17QuerySystemInfoResponse\x12+\n\x0bsystem_info\x18\x01 \x02(\x0b2\x16.tpu_driver.SystemInfo2\xef\x02\n\x0eCloudTpuDriver\x129\n\x04Open\x12\x17.tpu_driver.OpenRequest\x1a\x18.tpu_driver.OpenResponse\x12<\n\x05Close\x12\x18.tpu_driver.CloseRequest\x1a\x19.tpu_driver.CloseResponse\x12<\n\x05Reset\x12\x18.tpu_driver.ResetRequest\x1a\x19.tpu_driver.ResetResponse\x12Z\n\x0fQuerySystemInfo\x12".tpu_driver.QuerySystemInfoRequest\x1a#.tpu_driver.QuerySystemInfoResponse\x12J\n\rStreamExecute\x12\x19.tpu_driver.StreamRequest\x1a\x1a.tpu_driver.StreamResponse(\x010\x01B\x02H\x01', dependencies=[tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR])
_STATUSMESSAGE = _descriptor.Descriptor(name='StatusMessage', full_name='tpu_driver.StatusMessage', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='code', full_name='tpu_driver.StatusMessage.code', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='message', full_name='tpu_driver.StatusMessage.message', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=218, serialized_end=264)
_ALLOCATEREQUEST = _descriptor.Descriptor(name='AllocateRequest', full_name='tpu_driver.AllocateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core_id', full_name='tpu_driver.AllocateRequest.core_id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='region', full_name='tpu_driver.AllocateRequest.region', index=1, number=2, type=14, cpp_type=8, label=2, has_default_value=False, default_value=1, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_bytes', full_name='tpu_driver.AllocateRequest.num_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tpu_driver.AllocateRequest.shape', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='size', full_name='tpu_driver.AllocateRequest.size', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=267, serialized_end=406)
_ALLOCATETUPLEREQUEST = _descriptor.Descriptor(name='AllocateTupleRequest', full_name='tpu_driver.AllocateTupleRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core_id', full_name='tpu_driver.AllocateTupleRequest.core_id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='region', full_name='tpu_driver.AllocateTupleRequest.region', index=1, number=2, type=14, cpp_type=8, label=2, has_default_value=False, default_value=1, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='children', full_name='tpu_driver.AllocateTupleRequest.children', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=408, serialized_end=507)
_DEALLOCATEREQUEST = _descriptor.Descriptor(name='DeallocateRequest', full_name='tpu_driver.DeallocateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='handle', full_name='tpu_driver.DeallocateRequest.handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=509, serialized_end=544)
_TRANSFERTODEVICEREQUEST = _descriptor.Descriptor(name='TransferToDeviceRequest', full_name='tpu_driver.TransferToDeviceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target_handle', full_name='tpu_driver.TransferToDeviceRequest.target_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data', full_name='tpu_driver.TransferToDeviceRequest.data', index=1, number=2, type=12, cpp_type=9, label=2, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=546, serialized_end=608)
_TRANSFERFROMDEVICEREQUEST = _descriptor.Descriptor(name='TransferFromDeviceRequest', full_name='tpu_driver.TransferFromDeviceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_handle', full_name='tpu_driver.TransferFromDeviceRequest.source_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=610, serialized_end=660)
_TRANSFERFROMDEVICERESPONSE = _descriptor.Descriptor(name='TransferFromDeviceResponse', full_name='tpu_driver.TransferFromDeviceResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data', full_name='tpu_driver.TransferFromDeviceResponse.data', index=0, number=2, type=12, cpp_type=9, label=2, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=662, serialized_end=704)
_TRANSFERFROMDEVICETODEVICEREQUEST = _descriptor.Descriptor(name='TransferFromDeviceToDeviceRequest', full_name='tpu_driver.TransferFromDeviceToDeviceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_handle', full_name='tpu_driver.TransferFromDeviceToDeviceRequest.source_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target_handle', full_name='tpu_driver.TransferFromDeviceToDeviceRequest.target_handle', index=1, number=2, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=706, serialized_end=787)
_COMPILEREQUEST = _descriptor.Descriptor(name='CompileRequest', full_name='tpu_driver.CompileRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hlo_program', full_name='tpu_driver.CompileRequest.hlo_program', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_replicas', full_name='tpu_driver.CompileRequest.num_replicas', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=789, serialized_end=863)
_COMPILEDPROGRAMMETADATA = _descriptor.Descriptor(name='CompiledProgramMetadata', full_name='tpu_driver.CompiledProgramMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='program_shape', full_name='tpu_driver.CompiledProgramMetadata.program_shape', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=865, serialized_end=937)
_COMPILERESPONSE = _descriptor.Descriptor(name='CompileResponse', full_name='tpu_driver.CompileResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metadata', full_name='tpu_driver.CompileResponse.metadata', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=939, serialized_end=1011)
_LOADPROGRAMREQUEST = _descriptor.Descriptor(name='LoadProgramRequest', full_name='tpu_driver.LoadProgramRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core_id', full_name='tpu_driver.LoadProgramRequest.core_id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compiled_program_handle', full_name='tpu_driver.LoadProgramRequest.compiled_program_handle', index=1, number=2, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1013, serialized_end=1083)
_UNLOADPROGRAMREQUEST = _descriptor.Descriptor(name='UnloadProgramRequest', full_name='tpu_driver.UnloadProgramRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='loaded_program_handle', full_name='tpu_driver.UnloadProgramRequest.loaded_program_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1085, serialized_end=1138)
_EXECUTEREQUEST = _descriptor.Descriptor(name='ExecuteRequest', full_name='tpu_driver.ExecuteRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='loaded_program_handle', full_name='tpu_driver.ExecuteRequest.loaded_program_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_handle', full_name='tpu_driver.ExecuteRequest.input_handle', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_handle', full_name='tpu_driver.ExecuteRequest.output_handle', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='tpu_driver.ExecuteRequest.device_assignment', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1141, serialized_end=1288)
_STREAMREQUEST_ENTRY = _descriptor.Descriptor(name='Entry', full_name='tpu_driver.StreamRequest.Entry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='alloc', full_name='tpu_driver.StreamRequest.Entry.alloc', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alloc_tuple', full_name='tpu_driver.StreamRequest.Entry.alloc_tuple', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dealloc', full_name='tpu_driver.StreamRequest.Entry.dealloc', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_to', full_name='tpu_driver.StreamRequest.Entry.transfer_to', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_from', full_name='tpu_driver.StreamRequest.Entry.transfer_from', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_from_to', full_name='tpu_driver.StreamRequest.Entry.transfer_from_to', index=5, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compile', full_name='tpu_driver.StreamRequest.Entry.compile', index=6, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='load', full_name='tpu_driver.StreamRequest.Entry.load', index=7, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unload', full_name='tpu_driver.StreamRequest.Entry.unload', index=8, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='execute', full_name='tpu_driver.StreamRequest.Entry.execute', index=9, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='wait_for_id', full_name='tpu_driver.StreamRequest.Entry.wait_for_id', index=10, number=20, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation_id', full_name='tpu_driver.StreamRequest.Entry.operation_id', index=11, number=21, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='thread_id', full_name='tpu_driver.StreamRequest.Entry.thread_id', index=12, number=22, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='request', full_name='tpu_driver.StreamRequest.Entry.request', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1357, serialized_end=1983)
_STREAMREQUEST = _descriptor.Descriptor(name='StreamRequest', full_name='tpu_driver.StreamRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entry', full_name='tpu_driver.StreamRequest.entry', index=0, number=30, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_STREAMREQUEST_ENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1291, serialized_end=1983)
_STREAMRESPONSE_ENTRY = _descriptor.Descriptor(name='Entry', full_name='tpu_driver.StreamResponse.Entry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='transfer_from', full_name='tpu_driver.StreamResponse.Entry.transfer_from', index=0, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compile', full_name='tpu_driver.StreamResponse.Entry.compile', index=1, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status', full_name='tpu_driver.StreamResponse.Entry.status', index=2, number=10, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation_id', full_name='tpu_driver.StreamResponse.Entry.operation_id', index=3, number=11, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='response', full_name='tpu_driver.StreamResponse.Entry.response', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=2054, serialized_end=2251)
_STREAMRESPONSE = _descriptor.Descriptor(name='StreamResponse', full_name='tpu_driver.StreamResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entry', full_name='tpu_driver.StreamResponse.entry', index=0, number=20, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_STREAMRESPONSE_ENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1986, serialized_end=2251)
_OPENREQUEST = _descriptor.Descriptor(name='OpenRequest', full_name='tpu_driver.OpenRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='client_version', full_name='tpu_driver.OpenRequest.client_version', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=True, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2253, serialized_end=2293)
_OPENRESPONSE = _descriptor.Descriptor(name='OpenResponse', full_name='tpu_driver.OpenResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='client_id', full_name='tpu_driver.OpenResponse.client_id', index=0, number=1, type=13, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_idle_time_seconds', full_name='tpu_driver.OpenResponse.max_idle_time_seconds', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=True, default_value=3600, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2295, serialized_end=2365)
_CLOSEREQUEST = _descriptor.Descriptor(name='CloseRequest', full_name='tpu_driver.CloseRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='client_id', full_name='tpu_driver.CloseRequest.client_id', index=0, number=1, type=7, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2367, serialized_end=2400)
_CLOSERESPONSE = _descriptor.Descriptor(name='CloseResponse', full_name='tpu_driver.CloseResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2402, serialized_end=2417)
_RESETREQUEST = _descriptor.Descriptor(name='ResetRequest', full_name='tpu_driver.ResetRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2419, serialized_end=2433)
_RESETRESPONSE = _descriptor.Descriptor(name='ResetResponse', full_name='tpu_driver.ResetResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2435, serialized_end=2450)
_QUERYSYSTEMINFOREQUEST = _descriptor.Descriptor(name='QuerySystemInfoRequest', full_name='tpu_driver.QuerySystemInfoRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2452, serialized_end=2476)
_QUERYSYSTEMINFORESPONSE = _descriptor.Descriptor(name='QuerySystemInfoResponse', full_name='tpu_driver.QuerySystemInfoResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='system_info', full_name='tpu_driver.QuerySystemInfoResponse.system_info', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2478, serialized_end=2548)
_ALLOCATEREQUEST.fields_by_name['region'].enum_type = tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2._MEMORYREGION
_ALLOCATEREQUEST.fields_by_name['shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_ALLOCATEREQUEST.oneofs_by_name['size'].fields.append(_ALLOCATEREQUEST.fields_by_name['num_bytes'])
_ALLOCATEREQUEST.fields_by_name['num_bytes'].containing_oneof = _ALLOCATEREQUEST.oneofs_by_name['size']
_ALLOCATEREQUEST.oneofs_by_name['size'].fields.append(_ALLOCATEREQUEST.fields_by_name['shape'])
_ALLOCATEREQUEST.fields_by_name['shape'].containing_oneof = _ALLOCATEREQUEST.oneofs_by_name['size']
_ALLOCATETUPLEREQUEST.fields_by_name['region'].enum_type = tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2._MEMORYREGION
_COMPILEREQUEST.fields_by_name['hlo_program'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOPROTO
_COMPILEDPROGRAMMETADATA.fields_by_name['program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_COMPILERESPONSE.fields_by_name['metadata'].message_type = _COMPILEDPROGRAMMETADATA
_EXECUTEREQUEST.fields_by_name['device_assignment'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DEVICEASSIGNMENTPROTO
_STREAMREQUEST_ENTRY.fields_by_name['alloc'].message_type = _ALLOCATEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['alloc_tuple'].message_type = _ALLOCATETUPLEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['dealloc'].message_type = _DEALLOCATEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['transfer_to'].message_type = _TRANSFERTODEVICEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from'].message_type = _TRANSFERFROMDEVICEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from_to'].message_type = _TRANSFERFROMDEVICETODEVICEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['compile'].message_type = _COMPILEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['load'].message_type = _LOADPROGRAMREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['unload'].message_type = _UNLOADPROGRAMREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['execute'].message_type = _EXECUTEREQUEST
_STREAMREQUEST_ENTRY.containing_type = _STREAMREQUEST
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['alloc'])
_STREAMREQUEST_ENTRY.fields_by_name['alloc'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['alloc_tuple'])
_STREAMREQUEST_ENTRY.fields_by_name['alloc_tuple'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['dealloc'])
_STREAMREQUEST_ENTRY.fields_by_name['dealloc'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['transfer_to'])
_STREAMREQUEST_ENTRY.fields_by_name['transfer_to'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['transfer_from'])
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['transfer_from_to'])
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from_to'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['compile'])
_STREAMREQUEST_ENTRY.fields_by_name['compile'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['load'])
_STREAMREQUEST_ENTRY.fields_by_name['load'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['unload'])
_STREAMREQUEST_ENTRY.fields_by_name['unload'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['execute'])
_STREAMREQUEST_ENTRY.fields_by_name['execute'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST.fields_by_name['entry'].message_type = _STREAMREQUEST_ENTRY
_STREAMRESPONSE_ENTRY.fields_by_name['transfer_from'].message_type = _TRANSFERFROMDEVICERESPONSE
_STREAMRESPONSE_ENTRY.fields_by_name['compile'].message_type = _COMPILERESPONSE
_STREAMRESPONSE_ENTRY.fields_by_name['status'].message_type = _STATUSMESSAGE
_STREAMRESPONSE_ENTRY.containing_type = _STREAMRESPONSE
_STREAMRESPONSE_ENTRY.oneofs_by_name['response'].fields.append(_STREAMRESPONSE_ENTRY.fields_by_name['transfer_from'])
_STREAMRESPONSE_ENTRY.fields_by_name['transfer_from'].containing_oneof = _STREAMRESPONSE_ENTRY.oneofs_by_name['response']
_STREAMRESPONSE_ENTRY.oneofs_by_name['response'].fields.append(_STREAMRESPONSE_ENTRY.fields_by_name['compile'])
_STREAMRESPONSE_ENTRY.fields_by_name['compile'].containing_oneof = _STREAMRESPONSE_ENTRY.oneofs_by_name['response']
_STREAMRESPONSE.fields_by_name['entry'].message_type = _STREAMRESPONSE_ENTRY
_QUERYSYSTEMINFORESPONSE.fields_by_name['system_info'].message_type = tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2._SYSTEMINFO
DESCRIPTOR.message_types_by_name['StatusMessage'] = _STATUSMESSAGE
DESCRIPTOR.message_types_by_name['AllocateRequest'] = _ALLOCATEREQUEST
DESCRIPTOR.message_types_by_name['AllocateTupleRequest'] = _ALLOCATETUPLEREQUEST
DESCRIPTOR.message_types_by_name['DeallocateRequest'] = _DEALLOCATEREQUEST
DESCRIPTOR.message_types_by_name['TransferToDeviceRequest'] = _TRANSFERTODEVICEREQUEST
DESCRIPTOR.message_types_by_name['TransferFromDeviceRequest'] = _TRANSFERFROMDEVICEREQUEST
DESCRIPTOR.message_types_by_name['TransferFromDeviceResponse'] = _TRANSFERFROMDEVICERESPONSE
DESCRIPTOR.message_types_by_name['TransferFromDeviceToDeviceRequest'] = _TRANSFERFROMDEVICETODEVICEREQUEST
DESCRIPTOR.message_types_by_name['CompileRequest'] = _COMPILEREQUEST
DESCRIPTOR.message_types_by_name['CompiledProgramMetadata'] = _COMPILEDPROGRAMMETADATA
DESCRIPTOR.message_types_by_name['CompileResponse'] = _COMPILERESPONSE
DESCRIPTOR.message_types_by_name['LoadProgramRequest'] = _LOADPROGRAMREQUEST
DESCRIPTOR.message_types_by_name['UnloadProgramRequest'] = _UNLOADPROGRAMREQUEST
DESCRIPTOR.message_types_by_name['ExecuteRequest'] = _EXECUTEREQUEST
DESCRIPTOR.message_types_by_name['StreamRequest'] = _STREAMREQUEST
DESCRIPTOR.message_types_by_name['StreamResponse'] = _STREAMRESPONSE
DESCRIPTOR.message_types_by_name['OpenRequest'] = _OPENREQUEST
DESCRIPTOR.message_types_by_name['OpenResponse'] = _OPENRESPONSE
DESCRIPTOR.message_types_by_name['CloseRequest'] = _CLOSEREQUEST
DESCRIPTOR.message_types_by_name['CloseResponse'] = _CLOSERESPONSE
DESCRIPTOR.message_types_by_name['ResetRequest'] = _RESETREQUEST
DESCRIPTOR.message_types_by_name['ResetResponse'] = _RESETRESPONSE
DESCRIPTOR.message_types_by_name['QuerySystemInfoRequest'] = _QUERYSYSTEMINFOREQUEST
DESCRIPTOR.message_types_by_name['QuerySystemInfoResponse'] = _QUERYSYSTEMINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
StatusMessage = _reflection.GeneratedProtocolMessageType('StatusMessage', (_message.Message,), {'DESCRIPTOR': _STATUSMESSAGE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(StatusMessage)
AllocateRequest = _reflection.GeneratedProtocolMessageType('AllocateRequest', (_message.Message,), {'DESCRIPTOR': _ALLOCATEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(AllocateRequest)
AllocateTupleRequest = _reflection.GeneratedProtocolMessageType('AllocateTupleRequest', (_message.Message,), {'DESCRIPTOR': _ALLOCATETUPLEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(AllocateTupleRequest)
DeallocateRequest = _reflection.GeneratedProtocolMessageType('DeallocateRequest', (_message.Message,), {'DESCRIPTOR': _DEALLOCATEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(DeallocateRequest)
TransferToDeviceRequest = _reflection.GeneratedProtocolMessageType('TransferToDeviceRequest', (_message.Message,), {'DESCRIPTOR': _TRANSFERTODEVICEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferToDeviceRequest)
TransferFromDeviceRequest = _reflection.GeneratedProtocolMessageType('TransferFromDeviceRequest', (_message.Message,), {'DESCRIPTOR': _TRANSFERFROMDEVICEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferFromDeviceRequest)
TransferFromDeviceResponse = _reflection.GeneratedProtocolMessageType('TransferFromDeviceResponse', (_message.Message,), {'DESCRIPTOR': _TRANSFERFROMDEVICERESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferFromDeviceResponse)
TransferFromDeviceToDeviceRequest = _reflection.GeneratedProtocolMessageType('TransferFromDeviceToDeviceRequest', (_message.Message,), {'DESCRIPTOR': _TRANSFERFROMDEVICETODEVICEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferFromDeviceToDeviceRequest)
CompileRequest = _reflection.GeneratedProtocolMessageType('CompileRequest', (_message.Message,), {'DESCRIPTOR': _COMPILEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CompileRequest)
CompiledProgramMetadata = _reflection.GeneratedProtocolMessageType('CompiledProgramMetadata', (_message.Message,), {'DESCRIPTOR': _COMPILEDPROGRAMMETADATA, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CompiledProgramMetadata)
CompileResponse = _reflection.GeneratedProtocolMessageType('CompileResponse', (_message.Message,), {'DESCRIPTOR': _COMPILERESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CompileResponse)
LoadProgramRequest = _reflection.GeneratedProtocolMessageType('LoadProgramRequest', (_message.Message,), {'DESCRIPTOR': _LOADPROGRAMREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(LoadProgramRequest)
UnloadProgramRequest = _reflection.GeneratedProtocolMessageType('UnloadProgramRequest', (_message.Message,), {'DESCRIPTOR': _UNLOADPROGRAMREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(UnloadProgramRequest)
ExecuteRequest = _reflection.GeneratedProtocolMessageType('ExecuteRequest', (_message.Message,), {'DESCRIPTOR': _EXECUTEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(ExecuteRequest)
StreamRequest = _reflection.GeneratedProtocolMessageType('StreamRequest', (_message.Message,), {'Entry': _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {'DESCRIPTOR': _STREAMREQUEST_ENTRY, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'}), 'DESCRIPTOR': _STREAMREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(StreamRequest)
_sym_db.RegisterMessage(StreamRequest.Entry)
StreamResponse = _reflection.GeneratedProtocolMessageType('StreamResponse', (_message.Message,), {'Entry': _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {'DESCRIPTOR': _STREAMRESPONSE_ENTRY, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'}), 'DESCRIPTOR': _STREAMRESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(StreamResponse)
_sym_db.RegisterMessage(StreamResponse.Entry)
OpenRequest = _reflection.GeneratedProtocolMessageType('OpenRequest', (_message.Message,), {'DESCRIPTOR': _OPENREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(OpenRequest)
OpenResponse = _reflection.GeneratedProtocolMessageType('OpenResponse', (_message.Message,), {'DESCRIPTOR': _OPENRESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(OpenResponse)
CloseRequest = _reflection.GeneratedProtocolMessageType('CloseRequest', (_message.Message,), {'DESCRIPTOR': _CLOSEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CloseRequest)
CloseResponse = _reflection.GeneratedProtocolMessageType('CloseResponse', (_message.Message,), {'DESCRIPTOR': _CLOSERESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CloseResponse)
ResetRequest = _reflection.GeneratedProtocolMessageType('ResetRequest', (_message.Message,), {'DESCRIPTOR': _RESETREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(ResetRequest)
ResetResponse = _reflection.GeneratedProtocolMessageType('ResetResponse', (_message.Message,), {'DESCRIPTOR': _RESETRESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(ResetResponse)
QuerySystemInfoRequest = _reflection.GeneratedProtocolMessageType('QuerySystemInfoRequest', (_message.Message,), {'DESCRIPTOR': _QUERYSYSTEMINFOREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(QuerySystemInfoRequest)
QuerySystemInfoResponse = _reflection.GeneratedProtocolMessageType('QuerySystemInfoResponse', (_message.Message,), {'DESCRIPTOR': _QUERYSYSTEMINFORESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(QuerySystemInfoResponse)
DESCRIPTOR._options = None
_CLOUDTPUDRIVER = _descriptor.ServiceDescriptor(name='CloudTpuDriver', full_name='tpu_driver.CloudTpuDriver', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=2551, serialized_end=2918, methods=[_descriptor.MethodDescriptor(name='Open', full_name='tpu_driver.CloudTpuDriver.Open', index=0, containing_service=None, input_type=_OPENREQUEST, output_type=_OPENRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Close', full_name='tpu_driver.CloudTpuDriver.Close', index=1, containing_service=None, input_type=_CLOSEREQUEST, output_type=_CLOSERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Reset', full_name='tpu_driver.CloudTpuDriver.Reset', index=2, containing_service=None, input_type=_RESETREQUEST, output_type=_RESETRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='QuerySystemInfo', full_name='tpu_driver.CloudTpuDriver.QuerySystemInfo', index=3, containing_service=None, input_type=_QUERYSYSTEMINFOREQUEST, output_type=_QUERYSYSTEMINFORESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='StreamExecute', full_name='tpu_driver.CloudTpuDriver.StreamExecute', index=4, containing_service=None, input_type=_STREAMREQUEST, output_type=_STREAMRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_CLOUDTPUDRIVER)
DESCRIPTOR.services_by_name['CloudTpuDriver'] = _CLOUDTPUDRIVER
