// Copyright 2019 The TensorFlow Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
syntax = "proto2";

package toco;

// TocoConversionLog contains the analytics to be gathered when user converts
// a model to TF Lite using TOCO.
// Next ID to USE: 14.
message TocoConversionLog {
  // Total ops listed by name.
  repeated string op_list = 1;
  // Counts of built-in ops.
  // Key is op name and value is the count.
  map<string, int32> built_in_ops = 2;
  // Counts of custom ops.
  map<string, int32> custom_ops = 3;
  // Counts of select ops.
  map<string, int32> select_ops = 4;
  // The signature of operators. Including ops input/output types and shapes,
  // op name and version.
  repeated string op_signatures = 5;
  // Input tensor types.
  repeated string input_tensor_types = 6;
  // Output tensor types.
  repeated string output_tensor_types = 7;
  // Log generation time in micro-seconds.
  optional int64 log_generation_ts = 8;
  // Total number of ops in the model.
  optional int32 model_size = 9;
  // Tensorflow Lite runtime version.
  optional string tf_lite_version = 10;
  // Operating System info.
  optional string os_version = 11;
  // Model hash string.
  optional string model_hash = 12;
  // Error messages emitted by TOCO during conversion.
  optional string toco_err_logs = 13;
}
