
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/python/tpu_driver/tpu_driver.proto', package='tpu_driver', syntax='proto2', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n:tensorflow/compiler/xla/python/tpu_driver/tpu_driver.proto\x12\ntpu_driver"1\n\x0eChipCoordinate\x12\t\n\x01x\x18\x01 \x02(\x05\x12\t\n\x01y\x18\x02 \x02(\x05\x12\t\n\x01z\x18\x03 \x02(\x05"\x8d\x01\n\x0bTpuCoreInfo\x12\n\n\x02id\x18\x01 \x02(\x05\x12\x1a\n\x12core_on_chip_index\x18\x02 \x01(\x05\x12\x1a\n\x12core_on_host_index\x18\x03 \x01(\x05\x12\x1b\n\x13hbm_bytes_available\x18d \x01(\x03\x12\x1d\n\x15hbm_bytes_allocatable\x18e \x01(\x03"u\n\x0bTpuChipInfo\x12%\n\x04core\x18\x01 \x03(\x0b2\x17.tpu_driver.TpuCoreInfo\x12\x0f\n\x07host_id\x18\x02 \x01(\x05\x12.\n\nchip_coord\x18\x03 \x01(\x0b2\x1a.tpu_driver.ChipCoordinate"u\n\x07CpuInfo\x12\x15\n\rnum_cpu_cores\x18\x01 \x02(\x05\x12\x1d\n\x15cpu_load_average_1min\x18\x02 \x02(\x02\x12\x17\n\x0fram_bytes_total\x18d \x02(\x03\x12\x1b\n\x13ram_bytes_available\x18e \x02(\x03"\xd3\x01\n\nSystemInfo\x12)\n\x08tpu_chip\x18\x01 \x03(\x0b2\x17.tpu_driver.TpuChipInfo\x12 \n\x03cpu\x18\x02 \x02(\x0b2\x13.tpu_driver.CpuInfo\x12+\n\nlocal_core\x18\x03 \x03(\x0b2\x17.tpu_driver.TpuCoreInfo\x12\x0f\n\x07host_id\x18\x04 \x01(\x05\x12\x12\n\nhost_count\x18\x05 \x01(\x05\x12\x12\n\nchip_count\x18\x06 \x01(\x05\x12\x12\n\ncore_count\x18\x07 \x01(\x05"\xae\x01\n\x0fTpuDriverConfig\x12\x0e\n\x06worker\x18\x01 \x01(\t\x124\n\x04grpc\x18\x02 \x01(\x0b2&.tpu_driver.TpuDriverConfig.GrpcConfig\x1aU\n\nGrpcConfig\x12#\n\x17connection_timeout_secs\x18\x01 \x01(\x03:\x0230\x12"\n\x16keepalive_timeout_secs\x18\x02 \x01(\x03:\x0230*\x17\n\x0cMemoryRegion\x12\x07\n\x03HBM\x10\x01')
_MEMORYREGION = _descriptor.EnumDescriptor(name='MemoryRegion', full_name='tpu_driver.MemoryRegion', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='HBM', index=0, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=898, serialized_end=921)
_sym_db.RegisterEnumDescriptor(_MEMORYREGION)
MemoryRegion = enum_type_wrapper.EnumTypeWrapper(_MEMORYREGION)
HBM = 1
_CHIPCOORDINATE = _descriptor.Descriptor(name='ChipCoordinate', full_name='tpu_driver.ChipCoordinate', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='x', full_name='tpu_driver.ChipCoordinate.x', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='y', full_name='tpu_driver.ChipCoordinate.y', index=1, number=2, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='z', full_name='tpu_driver.ChipCoordinate.z', index=2, number=3, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=74, serialized_end=123)
_TPUCOREINFO = _descriptor.Descriptor(name='TpuCoreInfo', full_name='tpu_driver.TpuCoreInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tpu_driver.TpuCoreInfo.id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_on_chip_index', full_name='tpu_driver.TpuCoreInfo.core_on_chip_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_on_host_index', full_name='tpu_driver.TpuCoreInfo.core_on_host_index', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hbm_bytes_available', full_name='tpu_driver.TpuCoreInfo.hbm_bytes_available', index=3, number=100, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hbm_bytes_allocatable', full_name='tpu_driver.TpuCoreInfo.hbm_bytes_allocatable', index=4, number=101, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=126, serialized_end=267)
_TPUCHIPINFO = _descriptor.Descriptor(name='TpuChipInfo', full_name='tpu_driver.TpuChipInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core', full_name='tpu_driver.TpuChipInfo.core', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_id', full_name='tpu_driver.TpuChipInfo.host_id', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chip_coord', full_name='tpu_driver.TpuChipInfo.chip_coord', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=269, serialized_end=386)
_CPUINFO = _descriptor.Descriptor(name='CpuInfo', full_name='tpu_driver.CpuInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_cpu_cores', full_name='tpu_driver.CpuInfo.num_cpu_cores', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_load_average_1min', full_name='tpu_driver.CpuInfo.cpu_load_average_1min', index=1, number=2, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ram_bytes_total', full_name='tpu_driver.CpuInfo.ram_bytes_total', index=2, number=100, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ram_bytes_available', full_name='tpu_driver.CpuInfo.ram_bytes_available', index=3, number=101, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=388, serialized_end=505)
_SYSTEMINFO = _descriptor.Descriptor(name='SystemInfo', full_name='tpu_driver.SystemInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tpu_chip', full_name='tpu_driver.SystemInfo.tpu_chip', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu', full_name='tpu_driver.SystemInfo.cpu', index=1, number=2, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='local_core', full_name='tpu_driver.SystemInfo.local_core', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_id', full_name='tpu_driver.SystemInfo.host_id', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_count', full_name='tpu_driver.SystemInfo.host_count', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chip_count', full_name='tpu_driver.SystemInfo.chip_count', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_count', full_name='tpu_driver.SystemInfo.core_count', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=508, serialized_end=719)
_TPUDRIVERCONFIG_GRPCCONFIG = _descriptor.Descriptor(name='GrpcConfig', full_name='tpu_driver.TpuDriverConfig.GrpcConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='connection_timeout_secs', full_name='tpu_driver.TpuDriverConfig.GrpcConfig.connection_timeout_secs', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=True, default_value=30, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='keepalive_timeout_secs', full_name='tpu_driver.TpuDriverConfig.GrpcConfig.keepalive_timeout_secs', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=True, default_value=30, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=811, serialized_end=896)
_TPUDRIVERCONFIG = _descriptor.Descriptor(name='TpuDriverConfig', full_name='tpu_driver.TpuDriverConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker', full_name='tpu_driver.TpuDriverConfig.worker', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='grpc', full_name='tpu_driver.TpuDriverConfig.grpc', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUDRIVERCONFIG_GRPCCONFIG], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=722, serialized_end=896)
_TPUCHIPINFO.fields_by_name['core'].message_type = _TPUCOREINFO
_TPUCHIPINFO.fields_by_name['chip_coord'].message_type = _CHIPCOORDINATE
_SYSTEMINFO.fields_by_name['tpu_chip'].message_type = _TPUCHIPINFO
_SYSTEMINFO.fields_by_name['cpu'].message_type = _CPUINFO
_SYSTEMINFO.fields_by_name['local_core'].message_type = _TPUCOREINFO
_TPUDRIVERCONFIG_GRPCCONFIG.containing_type = _TPUDRIVERCONFIG
_TPUDRIVERCONFIG.fields_by_name['grpc'].message_type = _TPUDRIVERCONFIG_GRPCCONFIG
DESCRIPTOR.message_types_by_name['ChipCoordinate'] = _CHIPCOORDINATE
DESCRIPTOR.message_types_by_name['TpuCoreInfo'] = _TPUCOREINFO
DESCRIPTOR.message_types_by_name['TpuChipInfo'] = _TPUCHIPINFO
DESCRIPTOR.message_types_by_name['CpuInfo'] = _CPUINFO
DESCRIPTOR.message_types_by_name['SystemInfo'] = _SYSTEMINFO
DESCRIPTOR.message_types_by_name['TpuDriverConfig'] = _TPUDRIVERCONFIG
DESCRIPTOR.enum_types_by_name['MemoryRegion'] = _MEMORYREGION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ChipCoordinate = _reflection.GeneratedProtocolMessageType('ChipCoordinate', (_message.Message,), {'DESCRIPTOR': _CHIPCOORDINATE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(ChipCoordinate)
TpuCoreInfo = _reflection.GeneratedProtocolMessageType('TpuCoreInfo', (_message.Message,), {'DESCRIPTOR': _TPUCOREINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(TpuCoreInfo)
TpuChipInfo = _reflection.GeneratedProtocolMessageType('TpuChipInfo', (_message.Message,), {'DESCRIPTOR': _TPUCHIPINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(TpuChipInfo)
CpuInfo = _reflection.GeneratedProtocolMessageType('CpuInfo', (_message.Message,), {'DESCRIPTOR': _CPUINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(CpuInfo)
SystemInfo = _reflection.GeneratedProtocolMessageType('SystemInfo', (_message.Message,), {'DESCRIPTOR': _SYSTEMINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(SystemInfo)
TpuDriverConfig = _reflection.GeneratedProtocolMessageType('TpuDriverConfig', (_message.Message,), {'GrpcConfig': _reflection.GeneratedProtocolMessageType('GrpcConfig', (_message.Message,), {'DESCRIPTOR': _TPUDRIVERCONFIG_GRPCCONFIG, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'}), 'DESCRIPTOR': _TPUDRIVERCONFIG, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(TpuDriverConfig)
_sym_db.RegisterMessage(TpuDriverConfig.GrpcConfig)
