
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/service/gpu/backend_configs.proto', package='xla.gpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n9tensorflow/compiler/xla/service/gpu/backend_configs.proto\x12\x07xla.gpu\x1a&tensorflow/compiler/xla/xla_data.proto"\x95\x01\n\x16CudnnConvBackendConfig\x12\x11\n\talgorithm\x18\x01 \x01(\x03\x12\x1a\n\x12tensor_ops_enabled\x18\x02 \x01(\x08\x12\x19\n\x11conv_result_scale\x18\x04 \x01(\x01\x12\x17\n\x0factivation_mode\x18\x03 \x01(\x03\x12\x18\n\x10side_input_scale\x18\x05 \x01(\x01"\xc1\x01\n\x11GemmBackendConfig\x12\x1c\n\x12selected_algorithm\x18\x01 \x01(\x03H\x00\x12\x12\n\nalpha_real\x18\x02 \x01(\x01\x12\x12\n\nalpha_imag\x18\t \x01(\x01\x12\x0c\n\x04beta\x18\x03 \x01(\x01\x127\n\x15dot_dimension_numbers\x18\x07 \x01(\x0b2\x18.xla.DotDimensionNumbers\x12\x12\n\nbatch_size\x18\x08 \x01(\x03B\x0b\n\talgorithm"h\n\x14BitcastBackendConfig\x12\'\n\rsource_layout\x18\x01 \x01(\x0b2\x10.xla.LayoutProto\x12\'\n\rresult_layout\x18\x02 \x01(\x0b2\x10.xla.LayoutProtob\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR])
_CUDNNCONVBACKENDCONFIG = _descriptor.Descriptor(name='CudnnConvBackendConfig', full_name='xla.gpu.CudnnConvBackendConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='xla.gpu.CudnnConvBackendConfig.algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_ops_enabled', full_name='xla.gpu.CudnnConvBackendConfig.tensor_ops_enabled', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='conv_result_scale', full_name='xla.gpu.CudnnConvBackendConfig.conv_result_scale', index=2, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='activation_mode', full_name='xla.gpu.CudnnConvBackendConfig.activation_mode', index=3, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='side_input_scale', full_name='xla.gpu.CudnnConvBackendConfig.side_input_scale', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=111, serialized_end=260)
_GEMMBACKENDCONFIG = _descriptor.Descriptor(name='GemmBackendConfig', full_name='xla.gpu.GemmBackendConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='selected_algorithm', full_name='xla.gpu.GemmBackendConfig.selected_algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alpha_real', full_name='xla.gpu.GemmBackendConfig.alpha_real', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alpha_imag', full_name='xla.gpu.GemmBackendConfig.alpha_imag', index=2, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='beta', full_name='xla.gpu.GemmBackendConfig.beta', index=3, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dot_dimension_numbers', full_name='xla.gpu.GemmBackendConfig.dot_dimension_numbers', index=4, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='batch_size', full_name='xla.gpu.GemmBackendConfig.batch_size', index=5, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='algorithm', full_name='xla.gpu.GemmBackendConfig.algorithm', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=263, serialized_end=456)
_BITCASTBACKENDCONFIG = _descriptor.Descriptor(name='BitcastBackendConfig', full_name='xla.gpu.BitcastBackendConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_layout', full_name='xla.gpu.BitcastBackendConfig.source_layout', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='result_layout', full_name='xla.gpu.BitcastBackendConfig.result_layout', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=458, serialized_end=562)
_GEMMBACKENDCONFIG.fields_by_name['dot_dimension_numbers'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DOTDIMENSIONNUMBERS
_GEMMBACKENDCONFIG.oneofs_by_name['algorithm'].fields.append(_GEMMBACKENDCONFIG.fields_by_name['selected_algorithm'])
_GEMMBACKENDCONFIG.fields_by_name['selected_algorithm'].containing_oneof = _GEMMBACKENDCONFIG.oneofs_by_name['algorithm']
_BITCASTBACKENDCONFIG.fields_by_name['source_layout'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LAYOUTPROTO
_BITCASTBACKENDCONFIG.fields_by_name['result_layout'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LAYOUTPROTO
DESCRIPTOR.message_types_by_name['CudnnConvBackendConfig'] = _CUDNNCONVBACKENDCONFIG
DESCRIPTOR.message_types_by_name['GemmBackendConfig'] = _GEMMBACKENDCONFIG
DESCRIPTOR.message_types_by_name['BitcastBackendConfig'] = _BITCASTBACKENDCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CudnnConvBackendConfig = _reflection.GeneratedProtocolMessageType('CudnnConvBackendConfig', (_message.Message,), {'DESCRIPTOR': _CUDNNCONVBACKENDCONFIG, '__module__': 'tensorflow.compiler.xla.service.gpu.backend_configs_pb2'})
_sym_db.RegisterMessage(CudnnConvBackendConfig)
GemmBackendConfig = _reflection.GeneratedProtocolMessageType('GemmBackendConfig', (_message.Message,), {'DESCRIPTOR': _GEMMBACKENDCONFIG, '__module__': 'tensorflow.compiler.xla.service.gpu.backend_configs_pb2'})
_sym_db.RegisterMessage(GemmBackendConfig)
BitcastBackendConfig = _reflection.GeneratedProtocolMessageType('BitcastBackendConfig', (_message.Message,), {'DESCRIPTOR': _BITCASTBACKENDCONFIG, '__module__': 'tensorflow.compiler.xla.service.gpu.backend_configs_pb2'})
_sym_db.RegisterMessage(BitcastBackendConfig)
